Package com.openai.errors
Class SubjectTokenProviderException
-
- All Implemented Interfaces:
-
java.io.Serializable
public final class SubjectTokenProviderException extends OpenAIException
Thrown when the workload identity authentication flow fails to obtain the subject token from the provider.
For example, this is thrown by com.openai.auth.K8sServiceAccountTokenProvider when the service account token file cannot be found at the configured path.
-
-
Constructor Summary
Constructors Constructor Description SubjectTokenProviderException(String provider, String message, Throwable cause)
-
Method Summary
-
Methods inherited from class kotlin.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-