Class CompoundFilter
-
- All Implemented Interfaces:
public final class CompoundFilterCombine multiple filters using
andoror.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCompoundFilter.BuilderA builder for CompoundFilter.
public final classCompoundFilter.FilterA filter used to compare a specified attribute key to a given value using a defined comparison operation.
public final classCompoundFilter.TypeType of operation:
andoror.
-
Method Summary
Modifier and Type Method Description final List<CompoundFilter.Filter>filters()Array of filters to combine. final CompoundFilter.Typetype()Type of operation: andoror.final JsonField<List<CompoundFilter.Filter>>_filters()Returns the raw JSON value of filters. final JsonField<CompoundFilter.Type>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final CompoundFilter.BuildertoBuilder()final CompoundFiltervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CompoundFilter.Builderbuilder()Returns a mutable builder for constructing an instance of CompoundFilter. -
-
Method Detail
-
filters
final List<CompoundFilter.Filter> filters()
Array of filters to combine. Items can be
ComparisonFilterorCompoundFilter.
-
type
final CompoundFilter.Type type()
Type of operation:
andoror.
-
_filters
final JsonField<List<CompoundFilter.Filter>> _filters()
Returns the raw JSON value of filters.
Unlike filters, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<CompoundFilter.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CompoundFilter.Builder toBuilder()
-
validate
final CompoundFilter validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CompoundFilter.Builder builder()
Returns a mutable builder for constructing an instance of CompoundFilter.
The following fields are required:
.filters() .type()
-
-
-
-