Class ErrorObject
-
- All Implemented Interfaces:
public final class ErrorObject
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classErrorObject.BuilderA builder for ErrorObject.
-
Method Summary
Modifier and Type Method Description final Optional<String>code()final Stringmessage()final Optional<String>param()final Stringtype()final JsonField<String>_code()Returns the raw JSON value of code. final JsonField<String>_message()Returns the raw JSON value of message. final JsonField<String>_param()Returns the raw JSON value of param. final JsonField<String>_type()Returns the raw JSON value of type. final Map<String, JsonValue>_additionalProperties()final ErrorObject.BuildertoBuilder()final ErrorObjectvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ErrorObject.Builderbuilder()Returns a mutable builder for constructing an instance of ErrorObject. -
-
Method Detail
-
_code
final JsonField<String> _code()
Returns the raw JSON value of code.
Unlike code, this method doesn't throw if the JSON field has an unexpected type.
-
_message
final JsonField<String> _message()
Returns the raw JSON value of message.
Unlike message, this method doesn't throw if the JSON field has an unexpected type.
-
_param
final JsonField<String> _param()
Returns the raw JSON value of param.
Unlike param, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<String> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ErrorObject.Builder toBuilder()
-
validate
final ErrorObject validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ErrorObject.Builder builder()
Returns a mutable builder for constructing an instance of ErrorObject.
The following fields are required:
.code() .message() .param() .type()
-
-
-
-