Class FunctionDefinition
-
- All Implemented Interfaces:
public final class FunctionDefinition
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFunctionDefinition.BuilderA builder for FunctionDefinition.
-
Method Summary
Modifier and Type Method Description final Stringname()The name of the function to be called. final Optional<String>description()A description of what the function does, used by the model to choose when and how to call the function. final Optional<FunctionParameters>parameters()The parameters the functions accepts, described as a JSON Schema object. final Optional<Boolean>strict()Whether to enable strict schema adherence when generating the function call. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<FunctionParameters>_parameters()Returns the raw JSON value of parameters. final JsonField<Boolean>_strict()Returns the raw JSON value of strict. final Map<String, JsonValue>_additionalProperties()final FunctionDefinition.BuildertoBuilder()final FunctionDefinitionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FunctionDefinition.Builderbuilder()Returns a mutable builder for constructing an instance of FunctionDefinition. -
-
Method Detail
-
name
final String name()
The name of the function to be called. Must be a-z, A-Z, 0-9, or contain underscores and dashes, with a maximum length of 64.
-
description
final Optional<String> description()
A description of what the function does, used by the model to choose when and how to call the function.
-
parameters
final Optional<FunctionParameters> parameters()
The parameters the functions accepts, described as a JSON Schema object. See the guide for examples, and the JSON Schema reference for documentation about the format.
Omitting
parametersdefines a function with an empty parameter list.
-
strict
final Optional<Boolean> strict()
Whether to enable strict schema adherence when generating the function call. If set to true, the model will follow the exact schema defined in the
parametersfield. Only a subset of JSON Schema is supported whenstrictistrue. Learn more about Structured Outputs in the function calling guide.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_parameters
final JsonField<FunctionParameters> _parameters()
Returns the raw JSON value of parameters.
Unlike parameters, this method doesn't throw if the JSON field has an unexpected type.
-
_strict
final JsonField<Boolean> _strict()
Returns the raw JSON value of strict.
Unlike strict, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FunctionDefinition.Builder toBuilder()
-
validate
final FunctionDefinition validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FunctionDefinition.Builder builder()
Returns a mutable builder for constructing an instance of FunctionDefinition.
The following fields are required:
.name()
-
-
-
-