Package com.openai.models
Class FunctionParameters
-
- All Implemented Interfaces:
public final class FunctionParametersThe parameters the functions accepts, described as a JSON Schema object. See the guide for examples, and the JSON Schema reference for documentation about the format.
Omitting
parametersdefines a function with an empty parameter list.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFunctionParameters.BuilderA builder for FunctionParameters.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final FunctionParameters.BuildertoBuilder()final FunctionParametersvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FunctionParameters.Builderbuilder()Returns a mutable builder for constructing an instance of FunctionParameters. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FunctionParameters.Builder toBuilder()
-
validate
final FunctionParameters validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FunctionParameters.Builder builder()
Returns a mutable builder for constructing an instance of FunctionParameters.
-
-
-
-