Package com.openai.models
Enum OAuthErrorCode.Known
-
- All Implemented Interfaces:
-
java.io.Serializable,kotlin.Comparable
public enum OAuthErrorCode.Known extends Enum<OAuthErrorCode.Known>
An enum containing OAuthErrorCode's known values.
-
-
Field Summary
Fields Modifier and Type Field Description private final Stringnameprivate final Integerordinalprivate final EnumEntries<OAuthErrorCode.Known>entries
-
Enum Constant Summary
Enum Constants Enum Constant Description INVALID_GRANTINVALID_SUBJECT_TOKEN
-
Method Summary
Modifier and Type Method Description final OAuthErrorCode.KnownvalueOf(String value)Returns the enum constant of this type with the specified name. final Array<OAuthErrorCode.Known>values()Returns an array containing the constants of this enum type, in the order they're declared. final EnumEntries<OAuthErrorCode.Known>getEntries()An enum containing OAuthErrorCode's known values. -
-
Method Detail
-
valueOf
final OAuthErrorCode.Known valueOf(String value)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)
-
values
final Array<OAuthErrorCode.Known> values()
Returns an array containing the constants of this enum type, in the order they're declared.
This method may be used to iterate over the constants.
-
getEntries
final EnumEntries<OAuthErrorCode.Known> getEntries()
An enum containing OAuthErrorCode's known values.
-
-
-
-