Class ResponseFormatJsonObject
-
- All Implemented Interfaces:
public final class ResponseFormatJsonObjectJSON object response format. An older method of generating JSON responses. Using
json_schemais recommended for models that support it. Note that the model will not generate JSON without a system or user message instructing it to do so.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classResponseFormatJsonObject.BuilderA builder for ResponseFormatJsonObject.
-
Method Summary
Modifier and Type Method Description final JsonValue_type()The type of response format being defined. final Map<String, JsonValue>_additionalProperties()final ResponseFormatJsonObject.BuildertoBuilder()final ResponseFormatJsonObjectvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ResponseFormatJsonObject.Builderbuilder()Returns a mutable builder for constructing an instance of ResponseFormatJsonObject. -
-
Method Detail
-
_type
final JsonValue _type()
The type of response format being defined. Always
json_object.Expected to always return the following:
JsonValue.from("json_object")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ResponseFormatJsonObject.Builder toBuilder()
-
validate
final ResponseFormatJsonObject validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ResponseFormatJsonObject.Builder builder()
Returns a mutable builder for constructing an instance of ResponseFormatJsonObject.
-
-
-
-