Package com.openai.models
Class ResponseFormatText
-
- All Implemented Interfaces:
public final class ResponseFormatTextDefault response format. Used to generate text responses.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classResponseFormatText.BuilderA builder for ResponseFormatText.
-
Method Summary
Modifier and Type Method Description final JsonValue_type()The type of response format being defined. final Map<String, JsonValue>_additionalProperties()final ResponseFormatText.BuildertoBuilder()final ResponseFormatTextvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ResponseFormatText.Builderbuilder()Returns a mutable builder for constructing an instance of ResponseFormatText. -
-
Method Detail
-
_type
final JsonValue _type()
The type of response format being defined. Always
text.Expected to always return the following:
JsonValue.from("text")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ResponseFormatText.Builder toBuilder()
-
validate
final ResponseFormatText validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ResponseFormatText.Builder builder()
Returns a mutable builder for constructing an instance of ResponseFormatText.
-
-
-
-