Package com.openai.models
Class ResponseFormatTextPython
-
- All Implemented Interfaces:
public final class ResponseFormatTextPythonConfigure the model to generate valid Python code. See the custom grammars guide for more details.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classResponseFormatTextPython.BuilderA builder for ResponseFormatTextPython.
-
Method Summary
Modifier and Type Method Description final JsonValue_type()The type of response format being defined. final Map<String, JsonValue>_additionalProperties()final ResponseFormatTextPython.BuildertoBuilder()final ResponseFormatTextPythonvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ResponseFormatTextPython.Builderbuilder()Returns a mutable builder for constructing an instance of ResponseFormatTextPython. -
-
Method Detail
-
_type
final JsonValue _type()
The type of response format being defined. Always
python.Expected to always return the following:
JsonValue.from("python")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ResponseFormatTextPython.Builder toBuilder()
-
validate
final ResponseFormatTextPython validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ResponseFormatTextPython.Builder builder()
Returns a mutable builder for constructing an instance of ResponseFormatTextPython.
-
-
-
-