Class ChatKitWorkflow
-
- All Implemented Interfaces:
public final class ChatKitWorkflowWorkflow metadata and state returned for the session.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatKitWorkflow.BuilderA builder for ChatKitWorkflow.
public final classChatKitWorkflow.StateVariablesState variable key-value pairs applied when invoking the workflow. Defaults to null when no overrides were provided.
public final classChatKitWorkflow.TracingTracing settings applied to the workflow.
-
Method Summary
Modifier and Type Method Description final Stringid()Identifier of the workflow backing the session. final Optional<ChatKitWorkflow.StateVariables>stateVariables()State variable key-value pairs applied when invoking the workflow. final ChatKitWorkflow.Tracingtracing()Tracing settings applied to the workflow. final Optional<String>version()Specific workflow version used for the session. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<ChatKitWorkflow.StateVariables>_stateVariables()Returns the raw JSON value of stateVariables. final JsonField<ChatKitWorkflow.Tracing>_tracing()Returns the raw JSON value of tracing. final JsonField<String>_version()Returns the raw JSON value of version. final Map<String, JsonValue>_additionalProperties()final ChatKitWorkflow.BuildertoBuilder()final ChatKitWorkflowvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatKitWorkflow.Builderbuilder()Returns a mutable builder for constructing an instance of ChatKitWorkflow. -
-
Method Detail
-
stateVariables
final Optional<ChatKitWorkflow.StateVariables> stateVariables()
State variable key-value pairs applied when invoking the workflow. Defaults to null when no overrides were provided.
-
tracing
final ChatKitWorkflow.Tracing tracing()
Tracing settings applied to the workflow.
-
version
final Optional<String> version()
Specific workflow version used for the session. Defaults to null when using the latest deployment.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_stateVariables
final JsonField<ChatKitWorkflow.StateVariables> _stateVariables()
Returns the raw JSON value of stateVariables.
Unlike stateVariables, this method doesn't throw if the JSON field has an unexpected type.
-
_tracing
final JsonField<ChatKitWorkflow.Tracing> _tracing()
Returns the raw JSON value of tracing.
Unlike tracing, this method doesn't throw if the JSON field has an unexpected type.
-
_version
final JsonField<String> _version()
Returns the raw JSON value of version.
Unlike version, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatKitWorkflow.Builder toBuilder()
-
validate
final ChatKitWorkflow validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatKitWorkflow.Builder builder()
Returns a mutable builder for constructing an instance of ChatKitWorkflow.
The following fields are required:
.id() .stateVariables() .tracing() .version()
-
-
-
-