Package com.openai.models.beta.chatkit
Class ChatKitWorkflow.StateVariables
-
- All Implemented Interfaces:
public final class ChatKitWorkflow.StateVariablesState variable key-value pairs applied when invoking the workflow. Defaults to null when no overrides were provided.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatKitWorkflow.StateVariables.BuilderA builder for StateVariables.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final ChatKitWorkflow.StateVariables.BuildertoBuilder()final ChatKitWorkflow.StateVariablesvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatKitWorkflow.StateVariables.Builderbuilder()Returns a mutable builder for constructing an instance of StateVariables. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatKitWorkflow.StateVariables.Builder toBuilder()
-
validate
final ChatKitWorkflow.StateVariables validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatKitWorkflow.StateVariables.Builder builder()
Returns a mutable builder for constructing an instance of StateVariables.
-
-
-
-