Class ChatKitResponseOutputText
-
- All Implemented Interfaces:
public final class ChatKitResponseOutputTextAssistant response text accompanied by optional annotations.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatKitResponseOutputText.BuilderA builder for ChatKitResponseOutputText.
public final classChatKitResponseOutputText.AnnotationAnnotation object describing a cited source.
-
Method Summary
Modifier and Type Method Description final List<ChatKitResponseOutputText.Annotation>annotations()Ordered list of annotations attached to the response text. final Stringtext()Assistant generated text. final JsonValue_type()Type discriminator that is always output_text.final JsonField<List<ChatKitResponseOutputText.Annotation>>_annotations()Returns the raw JSON value of annotations. final JsonField<String>_text()Returns the raw JSON value of text. final Map<String, JsonValue>_additionalProperties()final ChatKitResponseOutputText.BuildertoBuilder()final ChatKitResponseOutputTextvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatKitResponseOutputText.Builderbuilder()Returns a mutable builder for constructing an instance of ChatKitResponseOutputText. -
-
Method Detail
-
annotations
final List<ChatKitResponseOutputText.Annotation> annotations()
Ordered list of annotations attached to the response text.
-
_type
final JsonValue _type()
Type discriminator that is always
output_text.Expected to always return the following:
JsonValue.from("output_text")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_annotations
final JsonField<List<ChatKitResponseOutputText.Annotation>> _annotations()
Returns the raw JSON value of annotations.
Unlike annotations, this method doesn't throw if the JSON field has an unexpected type.
-
_text
final JsonField<String> _text()
Returns the raw JSON value of text.
Unlike text, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatKitResponseOutputText.Builder toBuilder()
-
validate
final ChatKitResponseOutputText validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatKitResponseOutputText.Builder builder()
Returns a mutable builder for constructing an instance of ChatKitResponseOutputText.
The following fields are required:
.annotations() .text()
-
-
-
-