Class ChatKitResponseOutputText.Annotation.File
-
- All Implemented Interfaces:
public final class ChatKitResponseOutputText.Annotation.FileAnnotation that references an uploaded file.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatKitResponseOutputText.Annotation.File.BuilderA builder for File.
public final classChatKitResponseOutputText.Annotation.File.SourceFile attachment referenced by the annotation.
-
Method Summary
Modifier and Type Method Description final ChatKitResponseOutputText.Annotation.File.Sourcesource()File attachment referenced by the annotation. final JsonValue_type()Type discriminator that is always filefor this annotation.final JsonField<ChatKitResponseOutputText.Annotation.File.Source>_source()Returns the raw JSON value of source. final Map<String, JsonValue>_additionalProperties()final ChatKitResponseOutputText.Annotation.File.BuildertoBuilder()final ChatKitResponseOutputText.Annotation.Filevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatKitResponseOutputText.Annotation.File.Builderbuilder()Returns a mutable builder for constructing an instance of File. -
-
Method Detail
-
source
final ChatKitResponseOutputText.Annotation.File.Source source()
File attachment referenced by the annotation.
-
_type
final JsonValue _type()
Type discriminator that is always
filefor this annotation.Expected to always return the following:
JsonValue.from("file")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_source
final JsonField<ChatKitResponseOutputText.Annotation.File.Source> _source()
Returns the raw JSON value of source.
Unlike source, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatKitResponseOutputText.Annotation.File.Builder toBuilder()
-
validate
final ChatKitResponseOutputText.Annotation.File validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatKitResponseOutputText.Annotation.File.Builder builder()
Returns a mutable builder for constructing an instance of File.
The following fields are required:
.source()
-
-
-
-