Class ChatKitResponseOutputText.Annotation.File.Source
-
- All Implemented Interfaces:
public final class ChatKitResponseOutputText.Annotation.File.SourceFile attachment referenced by the annotation.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatKitResponseOutputText.Annotation.File.Source.BuilderA builder for Source.
-
Method Summary
Modifier and Type Method Description final Stringfilename()Filename referenced by the annotation. final JsonValue_type()Type discriminator that is always file.final JsonField<String>_filename()Returns the raw JSON value of filename. final Map<String, JsonValue>_additionalProperties()final ChatKitResponseOutputText.Annotation.File.Source.BuildertoBuilder()final ChatKitResponseOutputText.Annotation.File.Sourcevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatKitResponseOutputText.Annotation.File.Source.Builderbuilder()Returns a mutable builder for constructing an instance of Source. -
-
Method Detail
-
_type
final JsonValue _type()
Type discriminator that is always
file.Expected to always return the following:
JsonValue.from("file")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_filename
final JsonField<String> _filename()
Returns the raw JSON value of filename.
Unlike filename, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatKitResponseOutputText.Annotation.File.Source.Builder toBuilder()
-
validate
final ChatKitResponseOutputText.Annotation.File.Source validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatKitResponseOutputText.Annotation.File.Source.Builder builder()
Returns a mutable builder for constructing an instance of Source.
The following fields are required:
.filename()
-
-
-
-