Class ChatKitResponseOutputText.Annotation.Url
-
- All Implemented Interfaces:
public final class ChatKitResponseOutputText.Annotation.UrlAnnotation that references a URL.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatKitResponseOutputText.Annotation.Url.BuilderA builder for Url.
public final classChatKitResponseOutputText.Annotation.Url.SourceURL referenced by the annotation.
-
Method Summary
Modifier and Type Method Description final ChatKitResponseOutputText.Annotation.Url.Sourcesource()URL referenced by the annotation. final JsonValue_type()Type discriminator that is always urlfor this annotation.final JsonField<ChatKitResponseOutputText.Annotation.Url.Source>_source()Returns the raw JSON value of source. final Map<String, JsonValue>_additionalProperties()final ChatKitResponseOutputText.Annotation.Url.BuildertoBuilder()final ChatKitResponseOutputText.Annotation.Urlvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatKitResponseOutputText.Annotation.Url.Builderbuilder()Returns a mutable builder for constructing an instance of Url. -
-
Method Detail
-
source
final ChatKitResponseOutputText.Annotation.Url.Source source()
URL referenced by the annotation.
-
_type
final JsonValue _type()
Type discriminator that is always
urlfor this annotation.Expected to always return the following:
JsonValue.from("url")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_source
final JsonField<ChatKitResponseOutputText.Annotation.Url.Source> _source()
Returns the raw JSON value of source.
Unlike source, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatKitResponseOutputText.Annotation.Url.Builder toBuilder()
-
validate
final ChatKitResponseOutputText.Annotation.Url validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatKitResponseOutputText.Annotation.Url.Builder builder()
Returns a mutable builder for constructing an instance of Url.
The following fields are required:
.source()
-
-
-
-