Class ChatKitResponseOutputText.Annotation.Url.Source
-
- All Implemented Interfaces:
public final class ChatKitResponseOutputText.Annotation.Url.SourceURL referenced by the annotation.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatKitResponseOutputText.Annotation.Url.Source.BuilderA builder for Source.
-
Method Summary
Modifier and Type Method Description final JsonValue_type()Type discriminator that is always url.final Stringurl()URL referenced by the annotation. final JsonField<String>_url()Returns the raw JSON value of url. final Map<String, JsonValue>_additionalProperties()final ChatKitResponseOutputText.Annotation.Url.Source.BuildertoBuilder()final ChatKitResponseOutputText.Annotation.Url.Sourcevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatKitResponseOutputText.Annotation.Url.Source.Builderbuilder()Returns a mutable builder for constructing an instance of Source. -
-
Method Detail
-
_type
final JsonValue _type()
Type discriminator that is always
url.Expected to always return the following:
JsonValue.from("url")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatKitResponseOutputText.Annotation.Url.Source.Builder toBuilder()
-
validate
final ChatKitResponseOutputText.Annotation.Url.Source validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatKitResponseOutputText.Annotation.Url.Source.Builder builder()
Returns a mutable builder for constructing an instance of Source.
The following fields are required:
.url()
-
-
-
-