Class ChatKitThread
-
- All Implemented Interfaces:
public final class ChatKitThreadRepresents a ChatKit thread and its current status.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatKitThread.BuilderA builder for ChatKitThread.
public final classChatKitThread.StatusCurrent status for the thread. Defaults to
activefor newly created threads.
-
Method Summary
Modifier and Type Method Description final Stringid()Identifier of the thread. final LongcreatedAt()Unix timestamp (in seconds) for when the thread was created. final JsonValue_object_()Type discriminator that is always chatkit.thread.final ChatKitThread.Statusstatus()Current status for the thread. final Optional<String>title()Optional human-readable title for the thread. final Stringuser()Free-form string that identifies your end user who owns the thread. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Long>_createdAt()Returns the raw JSON value of createdAt. final JsonField<ChatKitThread.Status>_status()Returns the raw JSON value of status. final JsonField<String>_title()Returns the raw JSON value of title. final JsonField<String>_user()Returns the raw JSON value of user. final Map<String, JsonValue>_additionalProperties()final ChatKitThread.BuildertoBuilder()final ChatKitThreadvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatKitThread.Builderbuilder()Returns a mutable builder for constructing an instance of ChatKitThread. -
-
Method Detail
-
_object_
final JsonValue _object_()
Type discriminator that is always
chatkit.thread.Expected to always return the following:
JsonValue.from("chatkit.thread")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
status
final ChatKitThread.Status status()
Current status for the thread. Defaults to
activefor newly created threads.
-
title
final Optional<String> title()
Optional human-readable title for the thread. Defaults to null when no title has been generated.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<Long> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<ChatKitThread.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_title
final JsonField<String> _title()
Returns the raw JSON value of title.
Unlike title, this method doesn't throw if the JSON field has an unexpected type.
-
_user
final JsonField<String> _user()
Returns the raw JSON value of user.
Unlike user, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatKitThread.Builder toBuilder()
-
validate
final ChatKitThread validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatKitThread.Builder builder()
Returns a mutable builder for constructing an instance of ChatKitThread.
The following fields are required:
.id() .createdAt() .status() .title() .user()
-
-
-
-