Class ChatKitThread.Status.Closed
-
- All Implemented Interfaces:
public final class ChatKitThread.Status.ClosedIndicates that a thread has been closed.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatKitThread.Status.Closed.BuilderA builder for Closed.
-
Method Summary
Modifier and Type Method Description final Optional<String>reason()Reason that the thread was closed. final JsonValue_type()Status discriminator that is always closed.final JsonField<String>_reason()Returns the raw JSON value of reason. final Map<String, JsonValue>_additionalProperties()final ChatKitThread.Status.Closed.BuildertoBuilder()final ChatKitThread.Status.Closedvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatKitThread.Status.Closed.Builderbuilder()Returns a mutable builder for constructing an instance of Closed. -
-
Method Detail
-
reason
final Optional<String> reason()
Reason that the thread was closed. Defaults to null when no reason is recorded.
-
_type
final JsonValue _type()
Status discriminator that is always
closed.Expected to always return the following:
JsonValue.from("closed")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_reason
final JsonField<String> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatKitThread.Status.Closed.Builder toBuilder()
-
validate
final ChatKitThread.Status.Closed validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatKitThread.Status.Closed.Builder builder()
Returns a mutable builder for constructing an instance of Closed.
The following fields are required:
.reason()
-
-
-
-