Class ChatKitThread.Status.Locked
-
- All Implemented Interfaces:
public final class ChatKitThread.Status.LockedIndicates that a thread is locked and cannot accept new input.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatKitThread.Status.Locked.BuilderA builder for Locked.
-
Method Summary
Modifier and Type Method Description final Optional<String>reason()Reason that the thread was locked. final JsonValue_type()Status discriminator that is always locked.final JsonField<String>_reason()Returns the raw JSON value of reason. final Map<String, JsonValue>_additionalProperties()final ChatKitThread.Status.Locked.BuildertoBuilder()final ChatKitThread.Status.Lockedvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatKitThread.Status.Locked.Builderbuilder()Returns a mutable builder for constructing an instance of Locked. -
-
Method Detail
-
reason
final Optional<String> reason()
Reason that the thread was locked. Defaults to null when no reason is recorded.
-
_type
final JsonValue _type()
Status discriminator that is always
locked.Expected to always return the following:
JsonValue.from("locked")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_reason
final JsonField<String> _reason()
Returns the raw JSON value of reason.
Unlike reason, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatKitThread.Status.Locked.Builder toBuilder()
-
validate
final ChatKitThread.Status.Locked validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatKitThread.Status.Locked.Builder builder()
Returns a mutable builder for constructing an instance of Locked.
The following fields are required:
.reason()
-
-
-
-