Class ChatKitThreadAssistantMessageItem
-
- All Implemented Interfaces:
public final class ChatKitThreadAssistantMessageItemAssistant-authored message within a thread.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatKitThreadAssistantMessageItem.BuilderA builder for ChatKitThreadAssistantMessageItem.
-
Method Summary
Modifier and Type Method Description final Stringid()Identifier of the thread item. final List<ChatKitResponseOutputText>content()Ordered assistant response segments. final LongcreatedAt()Unix timestamp (in seconds) for when the item was created. final JsonValue_object_()Type discriminator that is always chatkit.thread_item.final StringthreadId()Identifier of the parent thread. final JsonValue_type()Type discriminator that is always chatkit.assistant_message.final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<List<ChatKitResponseOutputText>>_content()Returns the raw JSON value of content. final JsonField<Long>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_threadId()Returns the raw JSON value of threadId. final Map<String, JsonValue>_additionalProperties()final ChatKitThreadAssistantMessageItem.BuildertoBuilder()final ChatKitThreadAssistantMessageItemvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatKitThreadAssistantMessageItem.Builderbuilder()Returns a mutable builder for constructing an instance of ChatKitThreadAssistantMessageItem. -
-
Method Detail
-
content
final List<ChatKitResponseOutputText> content()
Ordered assistant response segments.
-
_object_
final JsonValue _object_()
Type discriminator that is always
chatkit.thread_item.Expected to always return the following:
JsonValue.from("chatkit.thread_item")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_type
final JsonValue _type()
Type discriminator that is always
chatkit.assistant_message.Expected to always return the following:
JsonValue.from("chatkit.assistant_message")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_content
final JsonField<List<ChatKitResponseOutputText>> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<Long> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_threadId
final JsonField<String> _threadId()
Returns the raw JSON value of threadId.
Unlike threadId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatKitThreadAssistantMessageItem.Builder toBuilder()
-
validate
final ChatKitThreadAssistantMessageItem validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatKitThreadAssistantMessageItem.Builder builder()
Returns a mutable builder for constructing an instance of ChatKitThreadAssistantMessageItem.
The following fields are required:
.id() .content() .createdAt() .threadId()
-
-
-
-