Class ChatKitThreadItemList
-
- All Implemented Interfaces:
public final class ChatKitThreadItemListA paginated list of thread items rendered for the ChatKit API.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatKitThreadItemList.BuilderA builder for ChatKitThreadItemList.
public final classChatKitThreadItemList.DataUser-authored messages within a thread.
-
Method Summary
Modifier and Type Method Description final List<ChatKitThreadItemList.Data>data()A list of items final Optional<String>firstId()The ID of the first item in the list. final BooleanhasMore()Whether there are more items available. final Optional<String>lastId()The ID of the last item in the list. final JsonValue_object_()The type of object returned, must be list.final JsonField<List<ChatKitThreadItemList.Data>>_data()Returns the raw JSON value of data. final JsonField<String>_firstId()Returns the raw JSON value of firstId. final JsonField<Boolean>_hasMore()Returns the raw JSON value of hasMore. final JsonField<String>_lastId()Returns the raw JSON value of lastId. final Map<String, JsonValue>_additionalProperties()final ChatKitThreadItemList.BuildertoBuilder()final ChatKitThreadItemListvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatKitThreadItemList.Builderbuilder()Returns a mutable builder for constructing an instance of ChatKitThreadItemList. -
-
Method Detail
-
data
final List<ChatKitThreadItemList.Data> data()
A list of items
-
_object_
final JsonValue _object_()
The type of object returned, must be
list.Expected to always return the following:
JsonValue.from("list")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_data
final JsonField<List<ChatKitThreadItemList.Data>> _data()
Returns the raw JSON value of data.
Unlike data, this method doesn't throw if the JSON field has an unexpected type.
-
_firstId
final JsonField<String> _firstId()
Returns the raw JSON value of firstId.
Unlike firstId, this method doesn't throw if the JSON field has an unexpected type.
-
_hasMore
final JsonField<Boolean> _hasMore()
Returns the raw JSON value of hasMore.
Unlike hasMore, this method doesn't throw if the JSON field has an unexpected type.
-
_lastId
final JsonField<String> _lastId()
Returns the raw JSON value of lastId.
Unlike lastId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatKitThreadItemList.Builder toBuilder()
-
validate
final ChatKitThreadItemList validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatKitThreadItemList.Builder builder()
Returns a mutable builder for constructing an instance of ChatKitThreadItemList.
The following fields are required:
.data() .firstId() .hasMore() .lastId()
-
-
-
-