Class ChatKitThreadItemList.Data.ChatKitTask
-
- All Implemented Interfaces:
public final class ChatKitThreadItemList.Data.ChatKitTaskTask emitted by the workflow to show progress and status updates.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatKitThreadItemList.Data.ChatKitTask.BuilderA builder for ChatKitTask.
public final classChatKitThreadItemList.Data.ChatKitTask.TaskTypeSubtype for the task.
-
Method Summary
Modifier and Type Method Description final Stringid()Identifier of the thread item. final LongcreatedAt()Unix timestamp (in seconds) for when the item was created. final Optional<String>heading()Optional heading for the task. final JsonValue_object_()Type discriminator that is always chatkit.thread_item.final Optional<String>summary()Optional summary that describes the task. final ChatKitThreadItemList.Data.ChatKitTask.TaskTypetaskType()Subtype for the task. final StringthreadId()Identifier of the parent thread. final JsonValue_type()Type discriminator that is always chatkit.task.final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Long>_createdAt()Returns the raw JSON value of createdAt. final JsonField<String>_heading()Returns the raw JSON value of heading. final JsonField<String>_summary()Returns the raw JSON value of summary. final JsonField<ChatKitThreadItemList.Data.ChatKitTask.TaskType>_taskType()Returns the raw JSON value of taskType. final JsonField<String>_threadId()Returns the raw JSON value of threadId. final Map<String, JsonValue>_additionalProperties()final ChatKitThreadItemList.Data.ChatKitTask.BuildertoBuilder()final ChatKitThreadItemList.Data.ChatKitTaskvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatKitThreadItemList.Data.ChatKitTask.Builderbuilder()Returns a mutable builder for constructing an instance of ChatKitTask. -
-
Method Detail
-
heading
final Optional<String> heading()
Optional heading for the task. Defaults to null when not provided.
-
_object_
final JsonValue _object_()
Type discriminator that is always
chatkit.thread_item.Expected to always return the following:
JsonValue.from("chatkit.thread_item")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
summary
final Optional<String> summary()
Optional summary that describes the task. Defaults to null when omitted.
-
taskType
final ChatKitThreadItemList.Data.ChatKitTask.TaskType taskType()
Subtype for the task.
-
_type
final JsonValue _type()
Type discriminator that is always
chatkit.task.Expected to always return the following:
JsonValue.from("chatkit.task")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<Long> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_heading
final JsonField<String> _heading()
Returns the raw JSON value of heading.
Unlike heading, this method doesn't throw if the JSON field has an unexpected type.
-
_summary
final JsonField<String> _summary()
Returns the raw JSON value of summary.
Unlike summary, this method doesn't throw if the JSON field has an unexpected type.
-
_taskType
final JsonField<ChatKitThreadItemList.Data.ChatKitTask.TaskType> _taskType()
Returns the raw JSON value of taskType.
Unlike taskType, this method doesn't throw if the JSON field has an unexpected type.
-
_threadId
final JsonField<String> _threadId()
Returns the raw JSON value of threadId.
Unlike threadId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatKitThreadItemList.Data.ChatKitTask.Builder toBuilder()
-
validate
final ChatKitThreadItemList.Data.ChatKitTask validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatKitThreadItemList.Data.ChatKitTask.Builder builder()
Returns a mutable builder for constructing an instance of ChatKitTask.
The following fields are required:
.id() .createdAt() .heading() .summary() .taskType() .threadId()
-
-
-
-