Class ChatKitThreadUserMessageItem
-
- All Implemented Interfaces:
public final class ChatKitThreadUserMessageItemUser-authored messages within a thread.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatKitThreadUserMessageItem.BuilderA builder for ChatKitThreadUserMessageItem.
public final classChatKitThreadUserMessageItem.ContentContent blocks that comprise a user message.
public final classChatKitThreadUserMessageItem.InferenceOptionsInference overrides applied to the message. Defaults to null when unset.
-
Method Summary
Modifier and Type Method Description final Stringid()Identifier of the thread item. final List<ChatKitAttachment>attachments()Attachments associated with the user message. final List<ChatKitThreadUserMessageItem.Content>content()Ordered content elements supplied by the user. final LongcreatedAt()Unix timestamp (in seconds) for when the item was created. final Optional<ChatKitThreadUserMessageItem.InferenceOptions>inferenceOptions()Inference overrides applied to the message. final JsonValue_object_()Type discriminator that is always chatkit.thread_item.final StringthreadId()Identifier of the parent thread. final JsonValue_type()Expected to always return the following:
However, this method can be useful for debugging and logging (e.g.JsonValue.from("chatkit.user_message")final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<List<ChatKitAttachment>>_attachments()Returns the raw JSON value of attachments. final JsonField<List<ChatKitThreadUserMessageItem.Content>>_content()Returns the raw JSON value of content. final JsonField<Long>_createdAt()Returns the raw JSON value of createdAt. final JsonField<ChatKitThreadUserMessageItem.InferenceOptions>_inferenceOptions()Returns the raw JSON value of inferenceOptions. final JsonField<String>_threadId()Returns the raw JSON value of threadId. final Map<String, JsonValue>_additionalProperties()final ChatKitThreadUserMessageItem.BuildertoBuilder()final ChatKitThreadUserMessageItemvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatKitThreadUserMessageItem.Builderbuilder()Returns a mutable builder for constructing an instance of ChatKitThreadUserMessageItem. -
-
Method Detail
-
attachments
final List<ChatKitAttachment> attachments()
Attachments associated with the user message. Defaults to an empty list.
-
content
final List<ChatKitThreadUserMessageItem.Content> content()
Ordered content elements supplied by the user.
-
inferenceOptions
final Optional<ChatKitThreadUserMessageItem.InferenceOptions> inferenceOptions()
Inference overrides applied to the message. Defaults to null when unset.
-
_object_
final JsonValue _object_()
Type discriminator that is always
chatkit.thread_item.Expected to always return the following:
JsonValue.from("chatkit.thread_item")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_type
final JsonValue _type()
Expected to always return the following:
JsonValue.from("chatkit.user_message")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_attachments
final JsonField<List<ChatKitAttachment>> _attachments()
Returns the raw JSON value of attachments.
Unlike attachments, this method doesn't throw if the JSON field has an unexpected type.
-
_content
final JsonField<List<ChatKitThreadUserMessageItem.Content>> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_createdAt
final JsonField<Long> _createdAt()
Returns the raw JSON value of createdAt.
Unlike createdAt, this method doesn't throw if the JSON field has an unexpected type.
-
_inferenceOptions
final JsonField<ChatKitThreadUserMessageItem.InferenceOptions> _inferenceOptions()
Returns the raw JSON value of inferenceOptions.
Unlike inferenceOptions, this method doesn't throw if the JSON field has an unexpected type.
-
_threadId
final JsonField<String> _threadId()
Returns the raw JSON value of threadId.
Unlike threadId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatKitThreadUserMessageItem.Builder toBuilder()
-
validate
final ChatKitThreadUserMessageItem validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatKitThreadUserMessageItem.Builder builder()
Returns a mutable builder for constructing an instance of ChatKitThreadUserMessageItem.
The following fields are required:
.id() .attachments() .content() .createdAt() .inferenceOptions() .threadId()
-
-
-
-