Class ChatKitThreadUserMessageItem.Content.QuotedText
-
- All Implemented Interfaces:
public final class ChatKitThreadUserMessageItem.Content.QuotedTextQuoted snippet that the user referenced in their message.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatKitThreadUserMessageItem.Content.QuotedText.BuilderA builder for QuotedText.
-
Method Summary
Modifier and Type Method Description final Stringtext()Quoted text content. final JsonValue_type()Type discriminator that is always quoted_text.final JsonField<String>_text()Returns the raw JSON value of text. final Map<String, JsonValue>_additionalProperties()final ChatKitThreadUserMessageItem.Content.QuotedText.BuildertoBuilder()final ChatKitThreadUserMessageItem.Content.QuotedTextvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatKitThreadUserMessageItem.Content.QuotedText.Builderbuilder()Returns a mutable builder for constructing an instance of QuotedText. -
-
Method Detail
-
_type
final JsonValue _type()
Type discriminator that is always
quoted_text.Expected to always return the following:
JsonValue.from("quoted_text")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_text
final JsonField<String> _text()
Returns the raw JSON value of text.
Unlike text, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatKitThreadUserMessageItem.Content.QuotedText.Builder toBuilder()
-
validate
final ChatKitThreadUserMessageItem.Content.QuotedText validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatKitThreadUserMessageItem.Content.QuotedText.Builder builder()
Returns a mutable builder for constructing an instance of QuotedText.
The following fields are required:
.text()
-
-
-
-