Class ChatKitThreadUserMessageItem.InferenceOptions
-
- All Implemented Interfaces:
public final class ChatKitThreadUserMessageItem.InferenceOptionsInference overrides applied to the message. Defaults to null when unset.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatKitThreadUserMessageItem.InferenceOptions.BuilderA builder for InferenceOptions.
public final classChatKitThreadUserMessageItem.InferenceOptions.ToolChoicePreferred tool to invoke. Defaults to null when ChatKit should auto-select.
-
Method Summary
Modifier and Type Method Description final Optional<String>model()Model name that generated the response. final Optional<ChatKitThreadUserMessageItem.InferenceOptions.ToolChoice>toolChoice()Preferred tool to invoke. final JsonField<String>_model()Returns the raw JSON value of model. final JsonField<ChatKitThreadUserMessageItem.InferenceOptions.ToolChoice>_toolChoice()Returns the raw JSON value of toolChoice. final Map<String, JsonValue>_additionalProperties()final ChatKitThreadUserMessageItem.InferenceOptions.BuildertoBuilder()final ChatKitThreadUserMessageItem.InferenceOptionsvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatKitThreadUserMessageItem.InferenceOptions.Builderbuilder()Returns a mutable builder for constructing an instance of InferenceOptions. -
-
Method Detail
-
model
final Optional<String> model()
Model name that generated the response. Defaults to null when using the session default.
-
toolChoice
final Optional<ChatKitThreadUserMessageItem.InferenceOptions.ToolChoice> toolChoice()
Preferred tool to invoke. Defaults to null when ChatKit should auto-select.
-
_model
final JsonField<String> _model()
Returns the raw JSON value of model.
Unlike model, this method doesn't throw if the JSON field has an unexpected type.
-
_toolChoice
final JsonField<ChatKitThreadUserMessageItem.InferenceOptions.ToolChoice> _toolChoice()
Returns the raw JSON value of toolChoice.
Unlike toolChoice, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatKitThreadUserMessageItem.InferenceOptions.Builder toBuilder()
-
validate
final ChatKitThreadUserMessageItem.InferenceOptions validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatKitThreadUserMessageItem.InferenceOptions.Builder builder()
Returns a mutable builder for constructing an instance of InferenceOptions.
The following fields are required:
.model() .toolChoice()
-
-
-
-