Class ChatKitThreadUserMessageItem.InferenceOptions.ToolChoice
-
- All Implemented Interfaces:
public final class ChatKitThreadUserMessageItem.InferenceOptions.ToolChoicePreferred tool to invoke. Defaults to null when ChatKit should auto-select.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatKitThreadUserMessageItem.InferenceOptions.ToolChoice.BuilderA builder for ToolChoice.
-
Method Summary
Modifier and Type Method Description final Stringid()Identifier of the requested tool. final JsonField<String>_id()Returns the raw JSON value of id. final Map<String, JsonValue>_additionalProperties()final ChatKitThreadUserMessageItem.InferenceOptions.ToolChoice.BuildertoBuilder()final ChatKitThreadUserMessageItem.InferenceOptions.ToolChoicevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatKitThreadUserMessageItem.InferenceOptions.ToolChoice.Builderbuilder()Returns a mutable builder for constructing an instance of ToolChoice. -
-
Method Detail
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatKitThreadUserMessageItem.InferenceOptions.ToolChoice.Builder toBuilder()
-
validate
final ChatKitThreadUserMessageItem.InferenceOptions.ToolChoice validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatKitThreadUserMessageItem.InferenceOptions.ToolChoice.Builder builder()
Returns a mutable builder for constructing an instance of ToolChoice.
The following fields are required:
.id()
-
-
-
-