Class ChatSessionAutomaticThreadTitling
-
- All Implemented Interfaces:
public final class ChatSessionAutomaticThreadTitlingAutomatic thread title preferences for the session.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatSessionAutomaticThreadTitling.BuilderA builder for ChatSessionAutomaticThreadTitling.
-
Method Summary
Modifier and Type Method Description final Booleanenabled()Whether automatic thread titling is enabled. final JsonField<Boolean>_enabled()Returns the raw JSON value of enabled. final Map<String, JsonValue>_additionalProperties()final ChatSessionAutomaticThreadTitling.BuildertoBuilder()final ChatSessionAutomaticThreadTitlingvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatSessionAutomaticThreadTitling.Builderbuilder()Returns a mutable builder for constructing an instance of ChatSessionAutomaticThreadTitling. -
-
Method Detail
-
_enabled
final JsonField<Boolean> _enabled()
Returns the raw JSON value of enabled.
Unlike enabled, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatSessionAutomaticThreadTitling.Builder toBuilder()
-
validate
final ChatSessionAutomaticThreadTitling validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatSessionAutomaticThreadTitling.Builder builder()
Returns a mutable builder for constructing an instance of ChatSessionAutomaticThreadTitling.
The following fields are required:
.enabled()
-
-
-
-