Class ChatSessionChatKitConfigurationParam
-
- All Implemented Interfaces:
public final class ChatSessionChatKitConfigurationParamOptional per-session configuration settings for ChatKit behavior.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatSessionChatKitConfigurationParam.BuilderA builder for ChatSessionChatKitConfigurationParam.
public final classChatSessionChatKitConfigurationParam.AutomaticThreadTitlingConfiguration for automatic thread titling. When omitted, automatic thread titling is enabled by default.
public final classChatSessionChatKitConfigurationParam.FileUploadConfiguration for upload enablement and limits. When omitted, uploads are disabled by default (max_files 10, max_file_size 512 MB).
public final classChatSessionChatKitConfigurationParam.HistoryConfiguration for chat history retention. When omitted, history is enabled by default with no limit on recent_threads (null).
-
Method Summary
-
-
Method Detail
-
automaticThreadTitling
final Optional<ChatSessionChatKitConfigurationParam.AutomaticThreadTitling> automaticThreadTitling()
Configuration for automatic thread titling. When omitted, automatic thread titling is enabled by default.
-
fileUpload
final Optional<ChatSessionChatKitConfigurationParam.FileUpload> fileUpload()
Configuration for upload enablement and limits. When omitted, uploads are disabled by default (max_files 10, max_file_size 512 MB).
-
history
final Optional<ChatSessionChatKitConfigurationParam.History> history()
Configuration for chat history retention. When omitted, history is enabled by default with no limit on recent_threads (null).
-
_automaticThreadTitling
final JsonField<ChatSessionChatKitConfigurationParam.AutomaticThreadTitling> _automaticThreadTitling()
Returns the raw JSON value of automaticThreadTitling.
Unlike automaticThreadTitling, this method doesn't throw if the JSON field has an unexpected type.
-
_fileUpload
final JsonField<ChatSessionChatKitConfigurationParam.FileUpload> _fileUpload()
Returns the raw JSON value of fileUpload.
Unlike fileUpload, this method doesn't throw if the JSON field has an unexpected type.
-
_history
final JsonField<ChatSessionChatKitConfigurationParam.History> _history()
Returns the raw JSON value of history.
Unlike history, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatSessionChatKitConfigurationParam.Builder toBuilder()
-
validate
final ChatSessionChatKitConfigurationParam validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatSessionChatKitConfigurationParam.Builder builder()
Returns a mutable builder for constructing an instance of ChatSessionChatKitConfigurationParam.
-
-
-
-