Class ChatSessionChatKitConfigurationParam.AutomaticThreadTitling
-
- All Implemented Interfaces:
public final class ChatSessionChatKitConfigurationParam.AutomaticThreadTitlingConfiguration for automatic thread titling. When omitted, automatic thread titling is enabled by default.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatSessionChatKitConfigurationParam.AutomaticThreadTitling.BuilderA builder for AutomaticThreadTitling.
-
Method Summary
Modifier and Type Method Description final Optional<Boolean>enabled()Enable automatic thread title generation. final JsonField<Boolean>_enabled()Returns the raw JSON value of enabled. final Map<String, JsonValue>_additionalProperties()final ChatSessionChatKitConfigurationParam.AutomaticThreadTitling.BuildertoBuilder()final ChatSessionChatKitConfigurationParam.AutomaticThreadTitlingvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatSessionChatKitConfigurationParam.AutomaticThreadTitling.Builderbuilder()Returns a mutable builder for constructing an instance of AutomaticThreadTitling. -
-
Method Detail
-
enabled
final Optional<Boolean> enabled()
Enable automatic thread title generation. Defaults to true.
-
_enabled
final JsonField<Boolean> _enabled()
Returns the raw JSON value of enabled.
Unlike enabled, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatSessionChatKitConfigurationParam.AutomaticThreadTitling.Builder toBuilder()
-
validate
final ChatSessionChatKitConfigurationParam.AutomaticThreadTitling validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatSessionChatKitConfigurationParam.AutomaticThreadTitling.Builder builder()
Returns a mutable builder for constructing an instance of AutomaticThreadTitling.
-
-
-
-