Class ChatSessionFileUpload
-
- All Implemented Interfaces:
public final class ChatSessionFileUploadUpload permissions and limits applied to the session.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatSessionFileUpload.BuilderA builder for ChatSessionFileUpload.
-
Method Summary
Modifier and Type Method Description final Booleanenabled()Indicates if uploads are enabled for the session. final Optional<Long>maxFileSize()Maximum upload size in megabytes. final Optional<Long>maxFiles()Maximum number of uploads allowed during the session. final JsonField<Boolean>_enabled()Returns the raw JSON value of enabled. final JsonField<Long>_maxFileSize()Returns the raw JSON value of maxFileSize. final JsonField<Long>_maxFiles()Returns the raw JSON value of maxFiles. final Map<String, JsonValue>_additionalProperties()final ChatSessionFileUpload.BuildertoBuilder()final ChatSessionFileUploadvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatSessionFileUpload.Builderbuilder()Returns a mutable builder for constructing an instance of ChatSessionFileUpload. -
-
Method Detail
-
maxFileSize
final Optional<Long> maxFileSize()
Maximum upload size in megabytes.
-
_enabled
final JsonField<Boolean> _enabled()
Returns the raw JSON value of enabled.
Unlike enabled, this method doesn't throw if the JSON field has an unexpected type.
-
_maxFileSize
final JsonField<Long> _maxFileSize()
Returns the raw JSON value of maxFileSize.
Unlike maxFileSize, this method doesn't throw if the JSON field has an unexpected type.
-
_maxFiles
final JsonField<Long> _maxFiles()
Returns the raw JSON value of maxFiles.
Unlike maxFiles, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatSessionFileUpload.Builder toBuilder()
-
validate
final ChatSessionFileUpload validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatSessionFileUpload.Builder builder()
Returns a mutable builder for constructing an instance of ChatSessionFileUpload.
The following fields are required:
.enabled() .maxFileSize() .maxFiles()
-
-
-
-