Class ChatSessionWorkflowParam.StateVariables
-
- All Implemented Interfaces:
public final class ChatSessionWorkflowParam.StateVariablesState variables forwarded to the workflow. Keys may be up to 64 characters, values must be primitive types, and the map defaults to an empty object.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classChatSessionWorkflowParam.StateVariables.BuilderA builder for StateVariables.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final ChatSessionWorkflowParam.StateVariables.BuildertoBuilder()final ChatSessionWorkflowParam.StateVariablesvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ChatSessionWorkflowParam.StateVariables.Builderbuilder()Returns a mutable builder for constructing an instance of StateVariables. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ChatSessionWorkflowParam.StateVariables.Builder toBuilder()
-
validate
final ChatSessionWorkflowParam.StateVariables validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ChatSessionWorkflowParam.StateVariables.Builder builder()
Returns a mutable builder for constructing an instance of StateVariables.
-
-
-
-