Class ThreadDeleteResponse
-
- All Implemented Interfaces:
public final class ThreadDeleteResponseConfirmation payload returned after deleting a thread.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classThreadDeleteResponse.BuilderA builder for ThreadDeleteResponse.
-
Method Summary
Modifier and Type Method Description final Stringid()Identifier of the deleted thread. final Booleandeleted()Indicates that the thread has been deleted. final JsonValue_object_()Type discriminator that is always chatkit.thread.deleted.final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Boolean>_deleted()Returns the raw JSON value of deleted. final Map<String, JsonValue>_additionalProperties()final ThreadDeleteResponse.BuildertoBuilder()final ThreadDeleteResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ThreadDeleteResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ThreadDeleteResponse. -
-
Method Detail
-
_object_
final JsonValue _object_()
Type discriminator that is always
chatkit.thread.deleted.Expected to always return the following:
JsonValue.from("chatkit.thread.deleted")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_deleted
final JsonField<Boolean> _deleted()
Returns the raw JSON value of deleted.
Unlike deleted, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ThreadDeleteResponse.Builder toBuilder()
-
validate
final ThreadDeleteResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ThreadDeleteResponse.Builder builder()
Returns a mutable builder for constructing an instance of ThreadDeleteResponse.
The following fields are required:
.id() .deleted()
-
-
-
-