Class BetaFunctionShellTool
-
- All Implemented Interfaces:
public final class BetaFunctionShellToolA tool that allows the model to execute shell commands.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBetaFunctionShellTool.BuilderA builder for BetaFunctionShellTool.
public final classBetaFunctionShellTool.AllowedCallerpublic final classBetaFunctionShellTool.Environment
-
Method Summary
Modifier and Type Method Description final JsonValue_type()The type of the shell tool. final Optional<List<BetaFunctionShellTool.AllowedCaller>>allowedCallers()The tool invocation context(s). final Optional<BetaFunctionShellTool.Environment>environment()final JsonField<List<BetaFunctionShellTool.AllowedCaller>>_allowedCallers()Returns the raw JSON value of allowedCallers. final JsonField<BetaFunctionShellTool.Environment>_environment()Returns the raw JSON value of environment. final Map<String, JsonValue>_additionalProperties()final BetaFunctionShellTool.BuildertoBuilder()final BetaFunctionShellToolvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BetaFunctionShellTool.Builderbuilder()Returns a mutable builder for constructing an instance of BetaFunctionShellTool. -
-
Method Detail
-
_type
final JsonValue _type()
The type of the shell tool. Always
shell.Expected to always return the following:
JsonValue.from("shell")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
allowedCallers
final Optional<List<BetaFunctionShellTool.AllowedCaller>> allowedCallers()
The tool invocation context(s).
-
environment
final Optional<BetaFunctionShellTool.Environment> environment()
-
_allowedCallers
final JsonField<List<BetaFunctionShellTool.AllowedCaller>> _allowedCallers()
Returns the raw JSON value of allowedCallers.
Unlike allowedCallers, this method doesn't throw if the JSON field has an unexpected type.
-
_environment
final JsonField<BetaFunctionShellTool.Environment> _environment()
Returns the raw JSON value of environment.
Unlike environment, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BetaFunctionShellTool.Builder toBuilder()
-
validate
final BetaFunctionShellTool validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BetaFunctionShellTool.Builder builder()
Returns a mutable builder for constructing an instance of BetaFunctionShellTool.
-
-
-
-