Class BetaFunctionShellTool.Builder
-
- All Implemented Interfaces:
public final class BetaFunctionShellTool.BuilderA builder for BetaFunctionShellTool.
-
-
Method Summary
-
-
Method Detail
-
type
final BetaFunctionShellTool.Builder type(JsonValue type)
Sets the field to an arbitrary JSON value.
It is usually unnecessary to call this method because the field defaults to the following:
JsonValue.from("shell")This method is primarily for setting the field to an undocumented or not yet supported value.
-
allowedCallers
final BetaFunctionShellTool.Builder allowedCallers(List<BetaFunctionShellTool.AllowedCaller> allowedCallers)
The tool invocation context(s).
-
allowedCallers
final BetaFunctionShellTool.Builder allowedCallers(Optional<List<BetaFunctionShellTool.AllowedCaller>> allowedCallers)
Alias for calling Builder.allowedCallers with
allowedCallers.orElse(null).
-
allowedCallers
final BetaFunctionShellTool.Builder allowedCallers(JsonField<List<BetaFunctionShellTool.AllowedCaller>> allowedCallers)
Sets Builder.allowedCallers to an arbitrary JSON value.
You should usually call Builder.allowedCallers with a well-typed
List<AllowedCaller>value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
addAllowedCaller
final BetaFunctionShellTool.Builder addAllowedCaller(BetaFunctionShellTool.AllowedCaller allowedCaller)
Adds a single AllowedCaller to allowedCallers.
-
environment
final BetaFunctionShellTool.Builder environment(BetaFunctionShellTool.Environment environment)
-
environment
final BetaFunctionShellTool.Builder environment(Optional<BetaFunctionShellTool.Environment> environment)
Alias for calling Builder.environment with
environment.orElse(null).
-
environment
final BetaFunctionShellTool.Builder environment(JsonField<BetaFunctionShellTool.Environment> environment)
Sets Builder.environment to an arbitrary JSON value.
You should usually call Builder.environment with a well-typed Environment value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
environment
final BetaFunctionShellTool.Builder environment(BetaContainerAuto containerAuto)
Alias for calling environment with
Environment.ofContainerAuto(containerAuto).
-
environment
final BetaFunctionShellTool.Builder environment(BetaLocalEnvironment local)
Alias for calling environment with
Environment.ofLocal(local).
-
environment
final BetaFunctionShellTool.Builder environment(BetaContainerReference containerReference)
Alias for calling environment with
Environment.ofContainerReference(containerReference).
-
containerReferenceEnvironment
final BetaFunctionShellTool.Builder containerReferenceEnvironment(String containerId)
Alias for calling environment with the following:
BetaContainerReference.builder() .containerId(containerId) .build()
-
additionalProperties
final BetaFunctionShellTool.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BetaFunctionShellTool.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BetaFunctionShellTool.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BetaFunctionShellTool.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BetaFunctionShellTool.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BetaFunctionShellTool build()
Returns an immutable instance of BetaFunctionShellTool.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-