Package com.openai.models.beta.responses
Interface BetaFunctionShellTool.Environment.Visitor
-
- All Implemented Interfaces:
public interface BetaFunctionShellTool.Environment.Visitor<T extends Object>An interface that defines how to map each variant of Environment to a value of type T.
-
-
Method Summary
Modifier and Type Method Description abstract TvisitContainerAuto(BetaContainerAuto containerAuto)abstract TvisitLocal(BetaLocalEnvironment local)abstract TvisitContainerReference(BetaContainerReference containerReference)Tunknown(JsonValue json)Maps an unknown variant of Environment to a value of type T. -
-
Method Detail
-
visitContainerAuto
abstract T visitContainerAuto(BetaContainerAuto containerAuto)
-
visitLocal
abstract T visitLocal(BetaLocalEnvironment local)
-
visitContainerReference
abstract T visitContainerReference(BetaContainerReference containerReference)
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of Environment to a value of type T.
An instance of Environment can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-