Class BetaResponseAudioTranscriptDeltaEvent.Builder
-
- All Implemented Interfaces:
public final class BetaResponseAudioTranscriptDeltaEvent.BuilderA builder for BetaResponseAudioTranscriptDeltaEvent.
-
-
Method Summary
-
-
Method Detail
-
delta
final BetaResponseAudioTranscriptDeltaEvent.Builder delta(String delta)
The partial transcript of the audio response.
-
delta
final BetaResponseAudioTranscriptDeltaEvent.Builder delta(JsonField<String> delta)
Sets Builder.delta to an arbitrary JSON value.
You should usually call Builder.delta with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sequenceNumber
final BetaResponseAudioTranscriptDeltaEvent.Builder sequenceNumber(Long sequenceNumber)
The sequence number of this event.
-
sequenceNumber
final BetaResponseAudioTranscriptDeltaEvent.Builder sequenceNumber(JsonField<Long> sequenceNumber)
Sets Builder.sequenceNumber to an arbitrary JSON value.
You should usually call Builder.sequenceNumber with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final BetaResponseAudioTranscriptDeltaEvent.Builder type(JsonValue type)
Sets the field to an arbitrary JSON value.
It is usually unnecessary to call this method because the field defaults to the following:
JsonValue.from("response.audio.transcript.delta")This method is primarily for setting the field to an undocumented or not yet supported value.
-
agent
final BetaResponseAudioTranscriptDeltaEvent.Builder agent(BetaResponseAudioTranscriptDeltaEvent.Agent agent)
The agent that owns this multi-agent streaming event.
-
agent
final BetaResponseAudioTranscriptDeltaEvent.Builder agent(Optional<BetaResponseAudioTranscriptDeltaEvent.Agent> agent)
Alias for calling Builder.agent with
agent.orElse(null).
-
agent
final BetaResponseAudioTranscriptDeltaEvent.Builder agent(JsonField<BetaResponseAudioTranscriptDeltaEvent.Agent> agent)
Sets Builder.agent to an arbitrary JSON value.
You should usually call Builder.agent with a well-typed Agent value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BetaResponseAudioTranscriptDeltaEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BetaResponseAudioTranscriptDeltaEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BetaResponseAudioTranscriptDeltaEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BetaResponseAudioTranscriptDeltaEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BetaResponseAudioTranscriptDeltaEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BetaResponseAudioTranscriptDeltaEvent build()
Returns an immutable instance of BetaResponseAudioTranscriptDeltaEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.delta() .sequenceNumber()
-
-
-
-