Class BetaResponseAudioTranscriptDoneEvent
-
- All Implemented Interfaces:
public final class BetaResponseAudioTranscriptDoneEventEmitted when the full audio transcript is completed.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBetaResponseAudioTranscriptDoneEvent.BuilderA builder for BetaResponseAudioTranscriptDoneEvent.
public final classBetaResponseAudioTranscriptDoneEvent.AgentThe agent that owns this multi-agent streaming event.
-
Method Summary
Modifier and Type Method Description final LongsequenceNumber()The sequence number of this event. final JsonValue_type()The type of the event. final Optional<BetaResponseAudioTranscriptDoneEvent.Agent>agent()The agent that owns this multi-agent streaming event. final JsonField<Long>_sequenceNumber()Returns the raw JSON value of sequenceNumber. final JsonField<BetaResponseAudioTranscriptDoneEvent.Agent>_agent()Returns the raw JSON value of agent. final Map<String, JsonValue>_additionalProperties()final BetaResponseAudioTranscriptDoneEvent.BuildertoBuilder()final BetaResponseAudioTranscriptDoneEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BetaResponseAudioTranscriptDoneEvent.Builderbuilder()Returns a mutable builder for constructing an instance of BetaResponseAudioTranscriptDoneEvent. -
-
Method Detail
-
sequenceNumber
final Long sequenceNumber()
The sequence number of this event.
-
_type
final JsonValue _type()
The type of the event. Always
response.audio.transcript.done.Expected to always return the following:
JsonValue.from("response.audio.transcript.done")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
agent
final Optional<BetaResponseAudioTranscriptDoneEvent.Agent> agent()
The agent that owns this multi-agent streaming event.
-
_sequenceNumber
final JsonField<Long> _sequenceNumber()
Returns the raw JSON value of sequenceNumber.
Unlike sequenceNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_agent
final JsonField<BetaResponseAudioTranscriptDoneEvent.Agent> _agent()
Returns the raw JSON value of agent.
Unlike agent, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BetaResponseAudioTranscriptDoneEvent.Builder toBuilder()
-
validate
final BetaResponseAudioTranscriptDoneEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BetaResponseAudioTranscriptDoneEvent.Builder builder()
Returns a mutable builder for constructing an instance of BetaResponseAudioTranscriptDoneEvent.
The following fields are required:
.sequenceNumber()
-
-
-
-