Package com.openai.models.beta.responses
Class BetaResponseCodeInterpreterCallCodeDoneEvent.Agent
-
- All Implemented Interfaces:
public final class BetaResponseCodeInterpreterCallCodeDoneEvent.AgentThe agent that owns this multi-agent streaming event.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBetaResponseCodeInterpreterCallCodeDoneEvent.Agent.BuilderA builder for Agent.
-
Method Summary
Modifier and Type Method Description final StringagentName()The canonical name of the agent that produced this item. final JsonField<String>_agentName()Returns the raw JSON value of agentName. final Map<String, JsonValue>_additionalProperties()final BetaResponseCodeInterpreterCallCodeDoneEvent.Agent.BuildertoBuilder()final BetaResponseCodeInterpreterCallCodeDoneEvent.Agentvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BetaResponseCodeInterpreterCallCodeDoneEvent.Agent.Builderbuilder()Returns a mutable builder for constructing an instance of Agent. -
-
Method Detail
-
_agentName
final JsonField<String> _agentName()
Returns the raw JSON value of agentName.
Unlike agentName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BetaResponseCodeInterpreterCallCodeDoneEvent.Agent.Builder toBuilder()
-
validate
final BetaResponseCodeInterpreterCallCodeDoneEvent.Agent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BetaResponseCodeInterpreterCallCodeDoneEvent.Agent.Builder builder()
Returns a mutable builder for constructing an instance of Agent.
The following fields are required:
.agentName()
-
-
-
-