Class BetaResponseCodeInterpreterCallCodeDoneEvent.Builder
-
- All Implemented Interfaces:
public final class BetaResponseCodeInterpreterCallCodeDoneEvent.BuilderA builder for BetaResponseCodeInterpreterCallCodeDoneEvent.
-
-
Method Summary
-
-
Method Detail
-
code
final BetaResponseCodeInterpreterCallCodeDoneEvent.Builder code(String code)
The final code snippet output by the code interpreter.
-
code
final BetaResponseCodeInterpreterCallCodeDoneEvent.Builder code(JsonField<String> code)
Sets Builder.code to an arbitrary JSON value.
You should usually call Builder.code with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
itemId
final BetaResponseCodeInterpreterCallCodeDoneEvent.Builder itemId(String itemId)
The unique identifier of the code interpreter tool call item.
-
itemId
final BetaResponseCodeInterpreterCallCodeDoneEvent.Builder itemId(JsonField<String> itemId)
Sets Builder.itemId to an arbitrary JSON value.
You should usually call Builder.itemId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
outputIndex
final BetaResponseCodeInterpreterCallCodeDoneEvent.Builder outputIndex(Long outputIndex)
The index of the output item in the response for which the code is finalized.
-
outputIndex
final BetaResponseCodeInterpreterCallCodeDoneEvent.Builder outputIndex(JsonField<Long> outputIndex)
Sets Builder.outputIndex to an arbitrary JSON value.
You should usually call Builder.outputIndex with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
sequenceNumber
final BetaResponseCodeInterpreterCallCodeDoneEvent.Builder sequenceNumber(Long sequenceNumber)
The sequence number of this event, used to order streaming events.
-
sequenceNumber
final BetaResponseCodeInterpreterCallCodeDoneEvent.Builder sequenceNumber(JsonField<Long> sequenceNumber)
Sets Builder.sequenceNumber to an arbitrary JSON value.
You should usually call Builder.sequenceNumber with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final BetaResponseCodeInterpreterCallCodeDoneEvent.Builder type(JsonValue type)
Sets the field to an arbitrary JSON value.
It is usually unnecessary to call this method because the field defaults to the following:
JsonValue.from("response.code_interpreter_call_code.done")This method is primarily for setting the field to an undocumented or not yet supported value.
-
agent
final BetaResponseCodeInterpreterCallCodeDoneEvent.Builder agent(BetaResponseCodeInterpreterCallCodeDoneEvent.Agent agent)
The agent that owns this multi-agent streaming event.
-
agent
final BetaResponseCodeInterpreterCallCodeDoneEvent.Builder agent(Optional<BetaResponseCodeInterpreterCallCodeDoneEvent.Agent> agent)
Alias for calling Builder.agent with
agent.orElse(null).
-
agent
final BetaResponseCodeInterpreterCallCodeDoneEvent.Builder agent(JsonField<BetaResponseCodeInterpreterCallCodeDoneEvent.Agent> agent)
Sets Builder.agent to an arbitrary JSON value.
You should usually call Builder.agent with a well-typed Agent value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BetaResponseCodeInterpreterCallCodeDoneEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BetaResponseCodeInterpreterCallCodeDoneEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BetaResponseCodeInterpreterCallCodeDoneEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BetaResponseCodeInterpreterCallCodeDoneEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BetaResponseCodeInterpreterCallCodeDoneEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BetaResponseCodeInterpreterCallCodeDoneEvent build()
Returns an immutable instance of BetaResponseCodeInterpreterCallCodeDoneEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.code() .itemId() .outputIndex() .sequenceNumber()
-
-
-
-