Class BetaResponseCodeInterpreterCallInProgressEvent
-
- All Implemented Interfaces:
public final class BetaResponseCodeInterpreterCallInProgressEventEmitted when a code interpreter call is in progress.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBetaResponseCodeInterpreterCallInProgressEvent.BuilderA builder for BetaResponseCodeInterpreterCallInProgressEvent.
public final classBetaResponseCodeInterpreterCallInProgressEvent.AgentThe agent that owns this multi-agent streaming event.
-
Method Summary
Modifier and Type Method Description final StringitemId()The unique identifier of the code interpreter tool call item. final LongoutputIndex()The index of the output item in the response for which the code interpreter call is in progress. final LongsequenceNumber()The sequence number of this event, used to order streaming events. final JsonValue_type()The type of the event. final Optional<BetaResponseCodeInterpreterCallInProgressEvent.Agent>agent()The agent that owns this multi-agent streaming event. final JsonField<String>_itemId()Returns the raw JSON value of itemId. final JsonField<Long>_outputIndex()Returns the raw JSON value of outputIndex. final JsonField<Long>_sequenceNumber()Returns the raw JSON value of sequenceNumber. final JsonField<BetaResponseCodeInterpreterCallInProgressEvent.Agent>_agent()Returns the raw JSON value of agent. final Map<String, JsonValue>_additionalProperties()final BetaResponseCodeInterpreterCallInProgressEvent.BuildertoBuilder()final BetaResponseCodeInterpreterCallInProgressEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BetaResponseCodeInterpreterCallInProgressEvent.Builderbuilder()Returns a mutable builder for constructing an instance of BetaResponseCodeInterpreterCallInProgressEvent. -
-
Method Detail
-
outputIndex
final Long outputIndex()
The index of the output item in the response for which the code interpreter call is in progress.
-
sequenceNumber
final Long sequenceNumber()
The sequence number of this event, used to order streaming events.
-
_type
final JsonValue _type()
The type of the event. Always
response.code_interpreter_call.in_progress.Expected to always return the following:
JsonValue.from("response.code_interpreter_call.in_progress")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
agent
final Optional<BetaResponseCodeInterpreterCallInProgressEvent.Agent> agent()
The agent that owns this multi-agent streaming event.
-
_itemId
final JsonField<String> _itemId()
Returns the raw JSON value of itemId.
Unlike itemId, this method doesn't throw if the JSON field has an unexpected type.
-
_outputIndex
final JsonField<Long> _outputIndex()
Returns the raw JSON value of outputIndex.
Unlike outputIndex, this method doesn't throw if the JSON field has an unexpected type.
-
_sequenceNumber
final JsonField<Long> _sequenceNumber()
Returns the raw JSON value of sequenceNumber.
Unlike sequenceNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_agent
final JsonField<BetaResponseCodeInterpreterCallInProgressEvent.Agent> _agent()
Returns the raw JSON value of agent.
Unlike agent, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BetaResponseCodeInterpreterCallInProgressEvent.Builder toBuilder()
-
validate
final BetaResponseCodeInterpreterCallInProgressEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BetaResponseCodeInterpreterCallInProgressEvent.Builder builder()
Returns a mutable builder for constructing an instance of BetaResponseCodeInterpreterCallInProgressEvent.
The following fields are required:
.itemId() .outputIndex() .sequenceNumber()
-
-
-
-