Class BetaResponseComputerToolCall
-
- All Implemented Interfaces:
public final class BetaResponseComputerToolCallA tool call to a computer use tool. See the computer use guide for more information.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBetaResponseComputerToolCall.BuilderA builder for BetaResponseComputerToolCall.
public final classBetaResponseComputerToolCall.PendingSafetyCheckA pending safety check for the computer call.
public final classBetaResponseComputerToolCall.StatusThe status of the item. One of
in_progress,completed, orincomplete. Populated when items are returned via API.public final classBetaResponseComputerToolCall.TypeThe type of the computer call. Always
computer_call.public final classBetaResponseComputerToolCall.AgentThe agent that produced this item.
-
Method Summary
Modifier and Type Method Description final Stringid()The unique ID of the computer call. final StringcallId()An identifier used when responding to the tool call with output. final List<BetaResponseComputerToolCall.PendingSafetyCheck>pendingSafetyChecks()The pending safety checks for the computer call. final BetaResponseComputerToolCall.Statusstatus()The status of the item. final BetaResponseComputerToolCall.Typetype()The type of the computer call. final Optional<BetaComputerAction>action()A click action. final Optional<List<BetaComputerAction>>actions()Flattened batched actions for computer_use.final Optional<BetaResponseComputerToolCall.Agent>agent()The agent that produced this item. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_callId()Returns the raw JSON value of callId. final JsonField<List<BetaResponseComputerToolCall.PendingSafetyCheck>>_pendingSafetyChecks()Returns the raw JSON value of pendingSafetyChecks. final JsonField<BetaResponseComputerToolCall.Status>_status()Returns the raw JSON value of status. final JsonField<BetaResponseComputerToolCall.Type>_type()Returns the raw JSON value of type. final JsonField<BetaComputerAction>_action()Returns the raw JSON value of action. final JsonField<List<BetaComputerAction>>_actions()Returns the raw JSON value of actions. final JsonField<BetaResponseComputerToolCall.Agent>_agent()Returns the raw JSON value of agent. final Map<String, JsonValue>_additionalProperties()final BetaResponseComputerToolCall.BuildertoBuilder()final BetaResponseComputerToolCallvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BetaResponseComputerToolCall.Builderbuilder()Returns a mutable builder for constructing an instance of BetaResponseComputerToolCall. -
-
Method Detail
-
pendingSafetyChecks
final List<BetaResponseComputerToolCall.PendingSafetyCheck> pendingSafetyChecks()
The pending safety checks for the computer call.
-
status
final BetaResponseComputerToolCall.Status status()
The status of the item. One of
in_progress,completed, orincomplete. Populated when items are returned via API.
-
type
final BetaResponseComputerToolCall.Type type()
The type of the computer call. Always
computer_call.
-
action
final Optional<BetaComputerAction> action()
A click action.
-
actions
final Optional<List<BetaComputerAction>> actions()
Flattened batched actions for
computer_use. Each action includes antypediscriminator and action-specific fields.
-
agent
final Optional<BetaResponseComputerToolCall.Agent> agent()
The agent that produced this item.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_callId
final JsonField<String> _callId()
Returns the raw JSON value of callId.
Unlike callId, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingSafetyChecks
final JsonField<List<BetaResponseComputerToolCall.PendingSafetyCheck>> _pendingSafetyChecks()
Returns the raw JSON value of pendingSafetyChecks.
Unlike pendingSafetyChecks, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<BetaResponseComputerToolCall.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<BetaResponseComputerToolCall.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_action
final JsonField<BetaComputerAction> _action()
Returns the raw JSON value of action.
Unlike action, this method doesn't throw if the JSON field has an unexpected type.
-
_actions
final JsonField<List<BetaComputerAction>> _actions()
Returns the raw JSON value of actions.
Unlike actions, this method doesn't throw if the JSON field has an unexpected type.
-
_agent
final JsonField<BetaResponseComputerToolCall.Agent> _agent()
Returns the raw JSON value of agent.
Unlike agent, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BetaResponseComputerToolCall.Builder toBuilder()
-
validate
final BetaResponseComputerToolCall validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BetaResponseComputerToolCall.Builder builder()
Returns a mutable builder for constructing an instance of BetaResponseComputerToolCall.
The following fields are required:
.id() .callId() .pendingSafetyChecks() .status() .type()
-
-
-
-