Package com.openai.models.beta.responses
Class BetaResponseComputerToolCall.Agent
-
- All Implemented Interfaces:
public final class BetaResponseComputerToolCall.AgentThe agent that produced this item.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBetaResponseComputerToolCall.Agent.BuilderA builder for Agent.
-
Method Summary
Modifier and Type Method Description final StringagentName()The canonical name of the agent that produced this item. final JsonField<String>_agentName()Returns the raw JSON value of agentName. final Map<String, JsonValue>_additionalProperties()final BetaResponseComputerToolCall.Agent.BuildertoBuilder()final BetaResponseComputerToolCall.Agentvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BetaResponseComputerToolCall.Agent.Builderbuilder()Returns a mutable builder for constructing an instance of Agent. -
-
Method Detail
-
_agentName
final JsonField<String> _agentName()
Returns the raw JSON value of agentName.
Unlike agentName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BetaResponseComputerToolCall.Agent.Builder toBuilder()
-
validate
final BetaResponseComputerToolCall.Agent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BetaResponseComputerToolCall.Agent.Builder builder()
Returns a mutable builder for constructing an instance of Agent.
The following fields are required:
.agentName()
-
-
-
-