Class BetaResponseComputerToolCallOutputItem
-
- All Implemented Interfaces:
public final class BetaResponseComputerToolCallOutputItem
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBetaResponseComputerToolCallOutputItem.BuilderA builder for BetaResponseComputerToolCallOutputItem.
public final classBetaResponseComputerToolCallOutputItem.StatusThe status of the message input. One of
in_progress,completed, orincomplete. Populated when input items are returned via API.public final classBetaResponseComputerToolCallOutputItem.AcknowledgedSafetyCheckA pending safety check for the computer call.
public final classBetaResponseComputerToolCallOutputItem.AgentThe agent that produced this item.
-
Method Summary
Modifier and Type Method Description final Stringid()The unique ID of the computer call tool output. final StringcallId()The ID of the computer tool call that produced the output. final BetaResponseComputerToolCallOutputScreenshotoutput()A computer screenshot image used with the computer use tool. final BetaResponseComputerToolCallOutputItem.Statusstatus()The status of the message input. final JsonValue_type()The type of the computer tool call output. final Optional<List<BetaResponseComputerToolCallOutputItem.AcknowledgedSafetyCheck>>acknowledgedSafetyChecks()The safety checks reported by the API that have been acknowledged by the developer. final Optional<BetaResponseComputerToolCallOutputItem.Agent>agent()The agent that produced this item. final Optional<String>createdBy()The identifier of the actor that created the item. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_callId()Returns the raw JSON value of callId. final JsonField<BetaResponseComputerToolCallOutputScreenshot>_output()Returns the raw JSON value of output. final JsonField<BetaResponseComputerToolCallOutputItem.Status>_status()Returns the raw JSON value of status. final JsonField<List<BetaResponseComputerToolCallOutputItem.AcknowledgedSafetyCheck>>_acknowledgedSafetyChecks()Returns the raw JSON value of acknowledgedSafetyChecks. final JsonField<BetaResponseComputerToolCallOutputItem.Agent>_agent()Returns the raw JSON value of agent. final JsonField<String>_createdBy()Returns the raw JSON value of createdBy. final Map<String, JsonValue>_additionalProperties()final BetaResponseComputerToolCallOutputItem.BuildertoBuilder()final BetaResponseComputerToolCallOutputItemvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BetaResponseComputerToolCallOutputItem.Builderbuilder()Returns a mutable builder for constructing an instance of BetaResponseComputerToolCallOutputItem. -
-
Method Detail
-
output
final BetaResponseComputerToolCallOutputScreenshot output()
A computer screenshot image used with the computer use tool.
-
status
final BetaResponseComputerToolCallOutputItem.Status status()
The status of the message input. One of
in_progress,completed, orincomplete. Populated when input items are returned via API.
-
_type
final JsonValue _type()
The type of the computer tool call output. Always
computer_call_output.Expected to always return the following:
JsonValue.from("computer_call_output")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
acknowledgedSafetyChecks
final Optional<List<BetaResponseComputerToolCallOutputItem.AcknowledgedSafetyCheck>> acknowledgedSafetyChecks()
The safety checks reported by the API that have been acknowledged by the developer.
-
agent
final Optional<BetaResponseComputerToolCallOutputItem.Agent> agent()
The agent that produced this item.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_callId
final JsonField<String> _callId()
Returns the raw JSON value of callId.
Unlike callId, this method doesn't throw if the JSON field has an unexpected type.
-
_output
final JsonField<BetaResponseComputerToolCallOutputScreenshot> _output()
Returns the raw JSON value of output.
Unlike output, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<BetaResponseComputerToolCallOutputItem.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_acknowledgedSafetyChecks
final JsonField<List<BetaResponseComputerToolCallOutputItem.AcknowledgedSafetyCheck>> _acknowledgedSafetyChecks()
Returns the raw JSON value of acknowledgedSafetyChecks.
Unlike acknowledgedSafetyChecks, this method doesn't throw if the JSON field has an unexpected type.
-
_agent
final JsonField<BetaResponseComputerToolCallOutputItem.Agent> _agent()
Returns the raw JSON value of agent.
Unlike agent, this method doesn't throw if the JSON field has an unexpected type.
-
_createdBy
final JsonField<String> _createdBy()
Returns the raw JSON value of createdBy.
Unlike createdBy, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BetaResponseComputerToolCallOutputItem.Builder toBuilder()
-
validate
final BetaResponseComputerToolCallOutputItem validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BetaResponseComputerToolCallOutputItem.Builder builder()
Returns a mutable builder for constructing an instance of BetaResponseComputerToolCallOutputItem.
The following fields are required:
.id() .callId() .output() .status()
-
-
-
-