Class BetaResponseFunctionCallArgumentsDoneEvent
-
- All Implemented Interfaces:
public final class BetaResponseFunctionCallArgumentsDoneEventEmitted when function-call arguments are finalized.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBetaResponseFunctionCallArgumentsDoneEvent.BuilderA builder for BetaResponseFunctionCallArgumentsDoneEvent.
public final classBetaResponseFunctionCallArgumentsDoneEvent.AgentThe agent that owns this multi-agent streaming event.
-
Method Summary
Modifier and Type Method Description final Stringarguments()The function-call arguments. final StringitemId()The ID of the item. final Stringname()The name of the function that was called. final LongoutputIndex()The index of the output item. final LongsequenceNumber()The sequence number of this event. final JsonValue_type()Expected to always return the following:
However, this method can be useful for debugging and logging (e.g.JsonValue.from("response.function_call_arguments.done")final Optional<BetaResponseFunctionCallArgumentsDoneEvent.Agent>agent()The agent that owns this multi-agent streaming event. final JsonField<String>_arguments()Returns the raw JSON value of arguments. final JsonField<String>_itemId()Returns the raw JSON value of itemId. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<Long>_outputIndex()Returns the raw JSON value of outputIndex. final JsonField<Long>_sequenceNumber()Returns the raw JSON value of sequenceNumber. final JsonField<BetaResponseFunctionCallArgumentsDoneEvent.Agent>_agent()Returns the raw JSON value of agent. final Map<String, JsonValue>_additionalProperties()final BetaResponseFunctionCallArgumentsDoneEvent.BuildertoBuilder()final BetaResponseFunctionCallArgumentsDoneEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BetaResponseFunctionCallArgumentsDoneEvent.Builderbuilder()Returns a mutable builder for constructing an instance of BetaResponseFunctionCallArgumentsDoneEvent. -
-
Method Detail
-
outputIndex
final Long outputIndex()
The index of the output item.
-
sequenceNumber
final Long sequenceNumber()
The sequence number of this event.
-
_type
final JsonValue _type()
Expected to always return the following:
JsonValue.from("response.function_call_arguments.done")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
agent
final Optional<BetaResponseFunctionCallArgumentsDoneEvent.Agent> agent()
The agent that owns this multi-agent streaming event.
-
_arguments
final JsonField<String> _arguments()
Returns the raw JSON value of arguments.
Unlike arguments, this method doesn't throw if the JSON field has an unexpected type.
-
_itemId
final JsonField<String> _itemId()
Returns the raw JSON value of itemId.
Unlike itemId, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_outputIndex
final JsonField<Long> _outputIndex()
Returns the raw JSON value of outputIndex.
Unlike outputIndex, this method doesn't throw if the JSON field has an unexpected type.
-
_sequenceNumber
final JsonField<Long> _sequenceNumber()
Returns the raw JSON value of sequenceNumber.
Unlike sequenceNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_agent
final JsonField<BetaResponseFunctionCallArgumentsDoneEvent.Agent> _agent()
Returns the raw JSON value of agent.
Unlike agent, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BetaResponseFunctionCallArgumentsDoneEvent.Builder toBuilder()
-
validate
final BetaResponseFunctionCallArgumentsDoneEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BetaResponseFunctionCallArgumentsDoneEvent.Builder builder()
Returns a mutable builder for constructing an instance of BetaResponseFunctionCallArgumentsDoneEvent.
The following fields are required:
.arguments() .itemId() .name() .outputIndex() .sequenceNumber()
-
-
-
-