Class BetaResponseFunctionShellCallOutputContent
-
- All Implemented Interfaces:
public final class BetaResponseFunctionShellCallOutputContentCaptured stdout and stderr for a portion of a shell tool call output.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBetaResponseFunctionShellCallOutputContent.BuilderA builder for BetaResponseFunctionShellCallOutputContent.
public final classBetaResponseFunctionShellCallOutputContent.OutcomeThe exit or timeout outcome associated with this shell call.
-
Method Summary
Modifier and Type Method Description final BetaResponseFunctionShellCallOutputContent.Outcomeoutcome()The exit or timeout outcome associated with this shell call. final Stringstderr()Captured stderr output for the shell call. final Stringstdout()Captured stdout output for the shell call. final JsonField<BetaResponseFunctionShellCallOutputContent.Outcome>_outcome()Returns the raw JSON value of outcome. final JsonField<String>_stderr()Returns the raw JSON value of stderr. final JsonField<String>_stdout()Returns the raw JSON value of stdout. final Map<String, JsonValue>_additionalProperties()final BetaResponseFunctionShellCallOutputContent.BuildertoBuilder()final BetaResponseFunctionShellCallOutputContentvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BetaResponseFunctionShellCallOutputContent.Builderbuilder()Returns a mutable builder for constructing an instance of BetaResponseFunctionShellCallOutputContent. -
-
Method Detail
-
outcome
final BetaResponseFunctionShellCallOutputContent.Outcome outcome()
The exit or timeout outcome associated with this shell call.
-
_outcome
final JsonField<BetaResponseFunctionShellCallOutputContent.Outcome> _outcome()
Returns the raw JSON value of outcome.
Unlike outcome, this method doesn't throw if the JSON field has an unexpected type.
-
_stderr
final JsonField<String> _stderr()
Returns the raw JSON value of stderr.
Unlike stderr, this method doesn't throw if the JSON field has an unexpected type.
-
_stdout
final JsonField<String> _stdout()
Returns the raw JSON value of stdout.
Unlike stdout, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BetaResponseFunctionShellCallOutputContent.Builder toBuilder()
-
validate
final BetaResponseFunctionShellCallOutputContent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BetaResponseFunctionShellCallOutputContent.Builder builder()
Returns a mutable builder for constructing an instance of BetaResponseFunctionShellCallOutputContent.
The following fields are required:
.outcome() .stderr() .stdout()
-
-
-
-