Class BetaResponseFunctionShellToolCall
-
- All Implemented Interfaces:
public final class BetaResponseFunctionShellToolCallA tool call that executes one or more shell commands in a managed environment.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBetaResponseFunctionShellToolCall.BuilderA builder for BetaResponseFunctionShellToolCall.
public final classBetaResponseFunctionShellToolCall.ActionThe shell commands and limits that describe how to run the tool call.
public final classBetaResponseFunctionShellToolCall.EnvironmentRepresents the use of a local environment to perform shell actions.
public final classBetaResponseFunctionShellToolCall.StatusThe status of the shell call. One of
in_progress,completed, orincomplete.public final classBetaResponseFunctionShellToolCall.AgentThe agent that produced this item.
public final classBetaResponseFunctionShellToolCall.CallerThe execution context that produced this tool call.
-
Method Summary
Modifier and Type Method Description final Stringid()The unique ID of the shell tool call. final BetaResponseFunctionShellToolCall.Actionaction()The shell commands and limits that describe how to run the tool call. final StringcallId()The unique ID of the shell tool call generated by the model. final Optional<BetaResponseFunctionShellToolCall.Environment>environment()Represents the use of a local environment to perform shell actions. final BetaResponseFunctionShellToolCall.Statusstatus()The status of the shell call. final JsonValue_type()The type of the item. final Optional<BetaResponseFunctionShellToolCall.Agent>agent()The agent that produced this item. final Optional<BetaResponseFunctionShellToolCall.Caller>caller()The execution context that produced this tool call. final Optional<String>createdBy()The ID of the entity that created this tool call. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<BetaResponseFunctionShellToolCall.Action>_action()Returns the raw JSON value of action. final JsonField<String>_callId()Returns the raw JSON value of callId. final JsonField<BetaResponseFunctionShellToolCall.Environment>_environment()Returns the raw JSON value of environment. final JsonField<BetaResponseFunctionShellToolCall.Status>_status()Returns the raw JSON value of status. final JsonField<BetaResponseFunctionShellToolCall.Agent>_agent()Returns the raw JSON value of agent. final JsonField<BetaResponseFunctionShellToolCall.Caller>_caller()Returns the raw JSON value of caller. final JsonField<String>_createdBy()Returns the raw JSON value of createdBy. final Map<String, JsonValue>_additionalProperties()final BetaResponseFunctionShellToolCall.BuildertoBuilder()final BetaResponseFunctionShellToolCallvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BetaResponseFunctionShellToolCall.Builderbuilder()Returns a mutable builder for constructing an instance of BetaResponseFunctionShellToolCall. -
-
Method Detail
-
id
final String id()
The unique ID of the shell tool call. Populated when this item is returned via API.
-
action
final BetaResponseFunctionShellToolCall.Action action()
The shell commands and limits that describe how to run the tool call.
-
environment
final Optional<BetaResponseFunctionShellToolCall.Environment> environment()
Represents the use of a local environment to perform shell actions.
-
status
final BetaResponseFunctionShellToolCall.Status status()
The status of the shell call. One of
in_progress,completed, orincomplete.
-
_type
final JsonValue _type()
The type of the item. Always
shell_call.Expected to always return the following:
JsonValue.from("shell_call")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
agent
final Optional<BetaResponseFunctionShellToolCall.Agent> agent()
The agent that produced this item.
-
caller
final Optional<BetaResponseFunctionShellToolCall.Caller> caller()
The execution context that produced this tool call.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_action
final JsonField<BetaResponseFunctionShellToolCall.Action> _action()
Returns the raw JSON value of action.
Unlike action, this method doesn't throw if the JSON field has an unexpected type.
-
_callId
final JsonField<String> _callId()
Returns the raw JSON value of callId.
Unlike callId, this method doesn't throw if the JSON field has an unexpected type.
-
_environment
final JsonField<BetaResponseFunctionShellToolCall.Environment> _environment()
Returns the raw JSON value of environment.
Unlike environment, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<BetaResponseFunctionShellToolCall.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_agent
final JsonField<BetaResponseFunctionShellToolCall.Agent> _agent()
Returns the raw JSON value of agent.
Unlike agent, this method doesn't throw if the JSON field has an unexpected type.
-
_caller
final JsonField<BetaResponseFunctionShellToolCall.Caller> _caller()
Returns the raw JSON value of caller.
Unlike caller, this method doesn't throw if the JSON field has an unexpected type.
-
_createdBy
final JsonField<String> _createdBy()
Returns the raw JSON value of createdBy.
Unlike createdBy, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BetaResponseFunctionShellToolCall.Builder toBuilder()
-
validate
final BetaResponseFunctionShellToolCall validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BetaResponseFunctionShellToolCall.Builder builder()
Returns a mutable builder for constructing an instance of BetaResponseFunctionShellToolCall.
The following fields are required:
.id() .action() .callId() .environment() .status()
-
-
-
-