Package com.openai.models.beta.responses
Interface BetaResponseFunctionShellToolCall.Environment.Visitor
-
- All Implemented Interfaces:
public interface BetaResponseFunctionShellToolCall.Environment.Visitor<T extends Object>An interface that defines how to map each variant of Environment to a value of type T.
-
-
Method Summary
Modifier and Type Method Description abstract TvisitLocal(BetaResponseLocalEnvironment local)Represents the use of a local environment to perform shell actions. abstract TvisitContainerReference(BetaResponseContainerReference containerReference)Represents a container created with /v1/containers. Tunknown(JsonValue json)Maps an unknown variant of Environment to a value of type T. -
-
Method Detail
-
visitLocal
abstract T visitLocal(BetaResponseLocalEnvironment local)
Represents the use of a local environment to perform shell actions.
-
visitContainerReference
abstract T visitContainerReference(BetaResponseContainerReference containerReference)
Represents a container created with /v1/containers.
-
unknown
T unknown(JsonValue json)
Maps an unknown variant of Environment to a value of type T.
An instance of Environment can contain an unknown variant if it was deserialized from data that doesn't match any known variant. For example, if the SDK is on an older version than the API, then the API may respond with new variants that the SDK is unaware of.
-
-
-
-