Class BetaResponseFunctionShellToolCallOutput
-
- All Implemented Interfaces:
public final class BetaResponseFunctionShellToolCallOutputThe output of a shell tool call that was emitted.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBetaResponseFunctionShellToolCallOutput.BuilderA builder for BetaResponseFunctionShellToolCallOutput.
public final classBetaResponseFunctionShellToolCallOutput.OutputThe content of a shell tool call output that was emitted.
public final classBetaResponseFunctionShellToolCallOutput.StatusThe status of the shell call output. One of
in_progress,completed, orincomplete.public final classBetaResponseFunctionShellToolCallOutput.AgentThe agent that produced this item.
public final classBetaResponseFunctionShellToolCallOutput.CallerThe execution context that produced this tool call.
-
Method Summary
Modifier and Type Method Description final Stringid()The unique ID of the shell call output. final StringcallId()The unique ID of the shell tool call generated by the model. final Optional<Long>maxOutputLength()The maximum length of the shell command output. final List<BetaResponseFunctionShellToolCallOutput.Output>output()An array of shell call output contents final BetaResponseFunctionShellToolCallOutput.Statusstatus()The status of the shell call output. final JsonValue_type()The type of the shell call output. final Optional<BetaResponseFunctionShellToolCallOutput.Agent>agent()The agent that produced this item. final Optional<BetaResponseFunctionShellToolCallOutput.Caller>caller()The execution context that produced this tool call. final Optional<String>createdBy()The identifier of the actor that created the item. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_callId()Returns the raw JSON value of callId. final JsonField<Long>_maxOutputLength()Returns the raw JSON value of maxOutputLength. final JsonField<List<BetaResponseFunctionShellToolCallOutput.Output>>_output()Returns the raw JSON value of output. final JsonField<BetaResponseFunctionShellToolCallOutput.Status>_status()Returns the raw JSON value of status. final JsonField<BetaResponseFunctionShellToolCallOutput.Agent>_agent()Returns the raw JSON value of agent. final JsonField<BetaResponseFunctionShellToolCallOutput.Caller>_caller()Returns the raw JSON value of caller. final JsonField<String>_createdBy()Returns the raw JSON value of createdBy. final Map<String, JsonValue>_additionalProperties()final BetaResponseFunctionShellToolCallOutput.BuildertoBuilder()final BetaResponseFunctionShellToolCallOutputvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BetaResponseFunctionShellToolCallOutput.Builderbuilder()Returns a mutable builder for constructing an instance of BetaResponseFunctionShellToolCallOutput. -
-
Method Detail
-
id
final String id()
The unique ID of the shell call output. Populated when this item is returned via API.
-
maxOutputLength
final Optional<Long> maxOutputLength()
The maximum length of the shell command output. This is generated by the model and should be passed back with the raw output.
-
output
final List<BetaResponseFunctionShellToolCallOutput.Output> output()
An array of shell call output contents
-
status
final BetaResponseFunctionShellToolCallOutput.Status status()
The status of the shell call output. One of
in_progress,completed, orincomplete.
-
_type
final JsonValue _type()
The type of the shell call output. Always
shell_call_output.Expected to always return the following:
JsonValue.from("shell_call_output")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
agent
final Optional<BetaResponseFunctionShellToolCallOutput.Agent> agent()
The agent that produced this item.
-
caller
final Optional<BetaResponseFunctionShellToolCallOutput.Caller> caller()
The execution context that produced this tool call.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_callId
final JsonField<String> _callId()
Returns the raw JSON value of callId.
Unlike callId, this method doesn't throw if the JSON field has an unexpected type.
-
_maxOutputLength
final JsonField<Long> _maxOutputLength()
Returns the raw JSON value of maxOutputLength.
Unlike maxOutputLength, this method doesn't throw if the JSON field has an unexpected type.
-
_output
final JsonField<List<BetaResponseFunctionShellToolCallOutput.Output>> _output()
Returns the raw JSON value of output.
Unlike output, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<BetaResponseFunctionShellToolCallOutput.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_agent
final JsonField<BetaResponseFunctionShellToolCallOutput.Agent> _agent()
Returns the raw JSON value of agent.
Unlike agent, this method doesn't throw if the JSON field has an unexpected type.
-
_caller
final JsonField<BetaResponseFunctionShellToolCallOutput.Caller> _caller()
Returns the raw JSON value of caller.
Unlike caller, this method doesn't throw if the JSON field has an unexpected type.
-
_createdBy
final JsonField<String> _createdBy()
Returns the raw JSON value of createdBy.
Unlike createdBy, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BetaResponseFunctionShellToolCallOutput.Builder toBuilder()
-
validate
final BetaResponseFunctionShellToolCallOutput validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BetaResponseFunctionShellToolCallOutput.Builder builder()
Returns a mutable builder for constructing an instance of BetaResponseFunctionShellToolCallOutput.
The following fields are required:
.id() .callId() .maxOutputLength() .output() .status()
-
-
-
-