Class BetaResponseFunctionShellToolCallOutput.Output
-
- All Implemented Interfaces:
public final class BetaResponseFunctionShellToolCallOutput.OutputThe content of a shell tool call output that was emitted.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBetaResponseFunctionShellToolCallOutput.Output.BuilderA builder for Output.
public final classBetaResponseFunctionShellToolCallOutput.Output.OutcomeRepresents either an exit outcome (with an exit code) or a timeout outcome for a shell call output chunk.
-
Method Summary
Modifier and Type Method Description final BetaResponseFunctionShellToolCallOutput.Output.Outcomeoutcome()Represents either an exit outcome (with an exit code) or a timeout outcome for a shell call output chunk. final Stringstderr()The standard error output that was captured. final Stringstdout()The standard output that was captured. final Optional<String>createdBy()The identifier of the actor that created the item. final JsonField<BetaResponseFunctionShellToolCallOutput.Output.Outcome>_outcome()Returns the raw JSON value of outcome. final JsonField<String>_stderr()Returns the raw JSON value of stderr. final JsonField<String>_stdout()Returns the raw JSON value of stdout. final JsonField<String>_createdBy()Returns the raw JSON value of createdBy. final Map<String, JsonValue>_additionalProperties()final BetaResponseFunctionShellToolCallOutput.Output.BuildertoBuilder()final BetaResponseFunctionShellToolCallOutput.Outputvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BetaResponseFunctionShellToolCallOutput.Output.Builderbuilder()Returns a mutable builder for constructing an instance of Output. -
-
Method Detail
-
outcome
final BetaResponseFunctionShellToolCallOutput.Output.Outcome outcome()
Represents either an exit outcome (with an exit code) or a timeout outcome for a shell call output chunk.
-
_outcome
final JsonField<BetaResponseFunctionShellToolCallOutput.Output.Outcome> _outcome()
Returns the raw JSON value of outcome.
Unlike outcome, this method doesn't throw if the JSON field has an unexpected type.
-
_stderr
final JsonField<String> _stderr()
Returns the raw JSON value of stderr.
Unlike stderr, this method doesn't throw if the JSON field has an unexpected type.
-
_stdout
final JsonField<String> _stdout()
Returns the raw JSON value of stdout.
Unlike stdout, this method doesn't throw if the JSON field has an unexpected type.
-
_createdBy
final JsonField<String> _createdBy()
Returns the raw JSON value of createdBy.
Unlike createdBy, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BetaResponseFunctionShellToolCallOutput.Output.Builder toBuilder()
-
validate
final BetaResponseFunctionShellToolCallOutput.Output validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BetaResponseFunctionShellToolCallOutput.Output.Builder builder()
Returns a mutable builder for constructing an instance of Output.
The following fields are required:
.outcome() .stderr() .stdout()
-
-
-
-