Class BetaResponseImageGenCallGeneratingEvent
-
- All Implemented Interfaces:
public final class BetaResponseImageGenCallGeneratingEventEmitted when an image generation tool call is actively generating an image (intermediate state).
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBetaResponseImageGenCallGeneratingEvent.BuilderA builder for BetaResponseImageGenCallGeneratingEvent.
public final classBetaResponseImageGenCallGeneratingEvent.AgentThe agent that owns this multi-agent streaming event.
-
Method Summary
Modifier and Type Method Description final StringitemId()The unique identifier of the image generation item being processed. final LongoutputIndex()The index of the output item in the response's output array. final LongsequenceNumber()The sequence number of the image generation item being processed. final JsonValue_type()The type of the event. final Optional<BetaResponseImageGenCallGeneratingEvent.Agent>agent()The agent that owns this multi-agent streaming event. final JsonField<String>_itemId()Returns the raw JSON value of itemId. final JsonField<Long>_outputIndex()Returns the raw JSON value of outputIndex. final JsonField<Long>_sequenceNumber()Returns the raw JSON value of sequenceNumber. final JsonField<BetaResponseImageGenCallGeneratingEvent.Agent>_agent()Returns the raw JSON value of agent. final Map<String, JsonValue>_additionalProperties()final BetaResponseImageGenCallGeneratingEvent.BuildertoBuilder()final BetaResponseImageGenCallGeneratingEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BetaResponseImageGenCallGeneratingEvent.Builderbuilder()Returns a mutable builder for constructing an instance of BetaResponseImageGenCallGeneratingEvent. -
-
Method Detail
-
outputIndex
final Long outputIndex()
The index of the output item in the response's output array.
-
sequenceNumber
final Long sequenceNumber()
The sequence number of the image generation item being processed.
-
_type
final JsonValue _type()
The type of the event. Always 'response.image_generation_call.generating'.
Expected to always return the following:
JsonValue.from("response.image_generation_call.generating")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
agent
final Optional<BetaResponseImageGenCallGeneratingEvent.Agent> agent()
The agent that owns this multi-agent streaming event.
-
_itemId
final JsonField<String> _itemId()
Returns the raw JSON value of itemId.
Unlike itemId, this method doesn't throw if the JSON field has an unexpected type.
-
_outputIndex
final JsonField<Long> _outputIndex()
Returns the raw JSON value of outputIndex.
Unlike outputIndex, this method doesn't throw if the JSON field has an unexpected type.
-
_sequenceNumber
final JsonField<Long> _sequenceNumber()
Returns the raw JSON value of sequenceNumber.
Unlike sequenceNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_agent
final JsonField<BetaResponseImageGenCallGeneratingEvent.Agent> _agent()
Returns the raw JSON value of agent.
Unlike agent, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BetaResponseImageGenCallGeneratingEvent.Builder toBuilder()
-
validate
final BetaResponseImageGenCallGeneratingEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BetaResponseImageGenCallGeneratingEvent.Builder builder()
Returns a mutable builder for constructing an instance of BetaResponseImageGenCallGeneratingEvent.
The following fields are required:
.itemId() .outputIndex() .sequenceNumber()
-
-
-
-