Package com.openai.models.beta.responses
Class BetaResponseImageGenCallInProgressEvent.Agent
-
- All Implemented Interfaces:
public final class BetaResponseImageGenCallInProgressEvent.AgentThe agent that owns this multi-agent streaming event.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBetaResponseImageGenCallInProgressEvent.Agent.BuilderA builder for Agent.
-
Method Summary
Modifier and Type Method Description final StringagentName()The canonical name of the agent that produced this item. final JsonField<String>_agentName()Returns the raw JSON value of agentName. final Map<String, JsonValue>_additionalProperties()final BetaResponseImageGenCallInProgressEvent.Agent.BuildertoBuilder()final BetaResponseImageGenCallInProgressEvent.Agentvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BetaResponseImageGenCallInProgressEvent.Agent.Builderbuilder()Returns a mutable builder for constructing an instance of Agent. -
-
Method Detail
-
_agentName
final JsonField<String> _agentName()
Returns the raw JSON value of agentName.
Unlike agentName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BetaResponseImageGenCallInProgressEvent.Agent.Builder toBuilder()
-
validate
final BetaResponseImageGenCallInProgressEvent.Agent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BetaResponseImageGenCallInProgressEvent.Agent.Builder builder()
Returns a mutable builder for constructing an instance of Agent.
The following fields are required:
.agentName()
-
-
-
-