Package com.openai.models.beta.responses
Class BetaResponseImageGenCallInProgressEvent.Agent.Builder
-
- All Implemented Interfaces:
public final class BetaResponseImageGenCallInProgressEvent.Agent.BuilderA builder for Agent.
-
-
Method Summary
-
-
Method Detail
-
agentName
final BetaResponseImageGenCallInProgressEvent.Agent.Builder agentName(String agentName)
The canonical name of the agent that produced this item.
-
agentName
final BetaResponseImageGenCallInProgressEvent.Agent.Builder agentName(JsonField<String> agentName)
Sets Builder.agentName to an arbitrary JSON value.
You should usually call Builder.agentName with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final BetaResponseImageGenCallInProgressEvent.Agent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final BetaResponseImageGenCallInProgressEvent.Agent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final BetaResponseImageGenCallInProgressEvent.Agent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final BetaResponseImageGenCallInProgressEvent.Agent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final BetaResponseImageGenCallInProgressEvent.Agent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final BetaResponseImageGenCallInProgressEvent.Agent build()
Returns an immutable instance of Agent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.agentName()
-
-
-
-