Class BetaResponseInputFile
-
- All Implemented Interfaces:
public final class BetaResponseInputFileA file input to the model.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBetaResponseInputFile.BuilderA builder for BetaResponseInputFile.
public final classBetaResponseInputFile.DetailThe detail level of the file to be sent to the model. Use
autoto let the system select the detail level; for GPT-5.6 and later models,autouses high-quality rendering, which may increase input token usage. Uselowfor lower-cost rendering, orhighto render the file at higher quality. Defaults toauto.public final classBetaResponseInputFile.PromptCacheBreakpointMarks the exact end of a reusable prompt prefix. The breakpoint inherits its TTL from the request's
prompt_cache_options.ttl; the boundary is not rounded to a token block.
-
Method Summary
Modifier and Type Method Description final JsonValue_type()The type of the input item. final Optional<BetaResponseInputFile.Detail>detail()The detail level of the file to be sent to the model. final Optional<String>fileData()The content of the file to be sent to the model. final Optional<String>fileId()The ID of the file to be sent to the model. final Optional<String>fileUrl()The URL of the file to be sent to the model. final Optional<String>filename()The name of the file to be sent to the model. final Optional<BetaResponseInputFile.PromptCacheBreakpoint>promptCacheBreakpoint()Marks the exact end of a reusable prompt prefix. final JsonField<BetaResponseInputFile.Detail>_detail()Returns the raw JSON value of detail. final JsonField<String>_fileData()Returns the raw JSON value of fileData. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final JsonField<String>_fileUrl()Returns the raw JSON value of fileUrl. final JsonField<String>_filename()Returns the raw JSON value of filename. final JsonField<BetaResponseInputFile.PromptCacheBreakpoint>_promptCacheBreakpoint()Returns the raw JSON value of promptCacheBreakpoint. final Map<String, JsonValue>_additionalProperties()final BetaResponseInputFile.BuildertoBuilder()final BetaResponseInputFilevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BetaResponseInputFile.Builderbuilder()Returns a mutable builder for constructing an instance of BetaResponseInputFile. -
-
Method Detail
-
_type
final JsonValue _type()
The type of the input item. Always
input_file.Expected to always return the following:
JsonValue.from("input_file")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
detail
final Optional<BetaResponseInputFile.Detail> detail()
The detail level of the file to be sent to the model. Use
autoto let the system select the detail level; for GPT-5.6 and later models,autouses high-quality rendering, which may increase input token usage. Uselowfor lower-cost rendering, orhighto render the file at higher quality. Defaults toauto.
-
promptCacheBreakpoint
final Optional<BetaResponseInputFile.PromptCacheBreakpoint> promptCacheBreakpoint()
Marks the exact end of a reusable prompt prefix. The breakpoint inherits its TTL from the request's
prompt_cache_options.ttl; the boundary is not rounded to a token block.
-
_detail
final JsonField<BetaResponseInputFile.Detail> _detail()
Returns the raw JSON value of detail.
Unlike detail, this method doesn't throw if the JSON field has an unexpected type.
-
_fileData
final JsonField<String> _fileData()
Returns the raw JSON value of fileData.
Unlike fileData, this method doesn't throw if the JSON field has an unexpected type.
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_fileUrl
final JsonField<String> _fileUrl()
Returns the raw JSON value of fileUrl.
Unlike fileUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_filename
final JsonField<String> _filename()
Returns the raw JSON value of filename.
Unlike filename, this method doesn't throw if the JSON field has an unexpected type.
-
_promptCacheBreakpoint
final JsonField<BetaResponseInputFile.PromptCacheBreakpoint> _promptCacheBreakpoint()
Returns the raw JSON value of promptCacheBreakpoint.
Unlike promptCacheBreakpoint, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BetaResponseInputFile.Builder toBuilder()
-
validate
final BetaResponseInputFile validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BetaResponseInputFile.Builder builder()
Returns a mutable builder for constructing an instance of BetaResponseInputFile.
-
-
-
-