Package com.openai.models.beta.responses
Class BetaResponseInputFile.PromptCacheBreakpoint
-
- All Implemented Interfaces:
public final class BetaResponseInputFile.PromptCacheBreakpointMarks the exact end of a reusable prompt prefix. The breakpoint inherits its TTL from the request's
prompt_cache_options.ttl; the boundary is not rounded to a token block.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBetaResponseInputFile.PromptCacheBreakpoint.BuilderA builder for PromptCacheBreakpoint.
-
Method Summary
Modifier and Type Method Description final JsonValue_mode()The breakpoint mode. final Map<String, JsonValue>_additionalProperties()final BetaResponseInputFile.PromptCacheBreakpoint.BuildertoBuilder()final BetaResponseInputFile.PromptCacheBreakpointvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BetaResponseInputFile.PromptCacheBreakpoint.Builderbuilder()Returns a mutable builder for constructing an instance of PromptCacheBreakpoint. -
-
Method Detail
-
_mode
final JsonValue _mode()
The breakpoint mode. Always
explicit.Expected to always return the following:
JsonValue.from("explicit")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BetaResponseInputFile.PromptCacheBreakpoint.Builder toBuilder()
-
validate
final BetaResponseInputFile.PromptCacheBreakpoint validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BetaResponseInputFile.PromptCacheBreakpoint.Builder builder()
Returns a mutable builder for constructing an instance of PromptCacheBreakpoint.
-
-
-
-