Class BetaResponseOutputTextAnnotationAddedEvent
-
- All Implemented Interfaces:
public final class BetaResponseOutputTextAnnotationAddedEventEmitted when an annotation is added to output text content.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classBetaResponseOutputTextAnnotationAddedEvent.BuilderA builder for BetaResponseOutputTextAnnotationAddedEvent.
public final classBetaResponseOutputTextAnnotationAddedEvent.AgentThe agent that owns this multi-agent streaming event.
-
Method Summary
Modifier and Type Method Description final JsonValue_annotation()The annotation object being added. final LongannotationIndex()The index of the annotation within the content part. final LongcontentIndex()The index of the content part within the output item. final StringitemId()The unique identifier of the item to which the annotation is being added. final LongoutputIndex()The index of the output item in the response's output array. final LongsequenceNumber()The sequence number of this event. final JsonValue_type()The type of the event. final Optional<BetaResponseOutputTextAnnotationAddedEvent.Agent>agent()The agent that owns this multi-agent streaming event. final JsonField<Long>_annotationIndex()Returns the raw JSON value of annotationIndex. final JsonField<Long>_contentIndex()Returns the raw JSON value of contentIndex. final JsonField<String>_itemId()Returns the raw JSON value of itemId. final JsonField<Long>_outputIndex()Returns the raw JSON value of outputIndex. final JsonField<Long>_sequenceNumber()Returns the raw JSON value of sequenceNumber. final JsonField<BetaResponseOutputTextAnnotationAddedEvent.Agent>_agent()Returns the raw JSON value of agent. final Map<String, JsonValue>_additionalProperties()final BetaResponseOutputTextAnnotationAddedEvent.BuildertoBuilder()final BetaResponseOutputTextAnnotationAddedEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static BetaResponseOutputTextAnnotationAddedEvent.Builderbuilder()Returns a mutable builder for constructing an instance of BetaResponseOutputTextAnnotationAddedEvent. -
-
Method Detail
-
_annotation
final JsonValue _annotation()
The annotation object being added. (See annotation schema for details.)
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = betaResponseOutputTextAnnotationAddedEvent.annotation().convert(MyClass.class);
-
annotationIndex
final Long annotationIndex()
The index of the annotation within the content part.
-
contentIndex
final Long contentIndex()
The index of the content part within the output item.
-
itemId
final String itemId()
The unique identifier of the item to which the annotation is being added.
-
outputIndex
final Long outputIndex()
The index of the output item in the response's output array.
-
sequenceNumber
final Long sequenceNumber()
The sequence number of this event.
-
_type
final JsonValue _type()
The type of the event. Always 'response.output_text.annotation.added'.
Expected to always return the following:
JsonValue.from("response.output_text.annotation.added")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
agent
final Optional<BetaResponseOutputTextAnnotationAddedEvent.Agent> agent()
The agent that owns this multi-agent streaming event.
-
_annotationIndex
final JsonField<Long> _annotationIndex()
Returns the raw JSON value of annotationIndex.
Unlike annotationIndex, this method doesn't throw if the JSON field has an unexpected type.
-
_contentIndex
final JsonField<Long> _contentIndex()
Returns the raw JSON value of contentIndex.
Unlike contentIndex, this method doesn't throw if the JSON field has an unexpected type.
-
_itemId
final JsonField<String> _itemId()
Returns the raw JSON value of itemId.
Unlike itemId, this method doesn't throw if the JSON field has an unexpected type.
-
_outputIndex
final JsonField<Long> _outputIndex()
Returns the raw JSON value of outputIndex.
Unlike outputIndex, this method doesn't throw if the JSON field has an unexpected type.
-
_sequenceNumber
final JsonField<Long> _sequenceNumber()
Returns the raw JSON value of sequenceNumber.
Unlike sequenceNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_agent
final JsonField<BetaResponseOutputTextAnnotationAddedEvent.Agent> _agent()
Returns the raw JSON value of agent.
Unlike agent, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final BetaResponseOutputTextAnnotationAddedEvent.Builder toBuilder()
-
validate
final BetaResponseOutputTextAnnotationAddedEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static BetaResponseOutputTextAnnotationAddedEvent.Builder builder()
Returns a mutable builder for constructing an instance of BetaResponseOutputTextAnnotationAddedEvent.
The following fields are required:
.annotation() .annotationIndex() .contentIndex() .itemId() .outputIndex() .sequenceNumber()
-
-
-
-