Class Thread

  • All Implemented Interfaces:

    
    public final class Thread
    
                        

    Represents a thread that contains messages.

    • Constructor Detail

    • Method Detail

      • id

         final String id()

        The identifier, which can be referenced in API endpoints.

      • createdAt

         final Long createdAt()

        The Unix timestamp (in seconds) for when the thread was created.

      • metadata

         final Optional<Thread.Metadata> metadata()

        Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.

        Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.

      • _object_

         final JsonValue _object_()

        The object type, which is always thread.

        Expected to always return the following:

        JsonValue.from("thread")

        However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).

      • toolResources

         final Optional<Thread.ToolResources> toolResources()

        A set of resources that are made available to the assistant's tools in this thread. The resources are specific to the type of tool. For example, the code_interpreter tool requires a list of file IDs, while the file_search tool requires a list of vector store IDs.

      • _id

         final JsonField<String> _id()

        Returns the raw JSON value of id.

        Unlike id, this method doesn't throw if the JSON field has an unexpected type.

      • validate

         final Thread validate()

        Validates that the types of all values in this object match their expected types recursively.

        This method is not forwards compatible with new types from the API for existing fields.

      • builder

         final static Thread.Builder builder()

        Returns a mutable builder for constructing an instance of Thread.

        The following fields are required:

        .id()
        .createdAt()
        .metadata()
        .toolResources()