Class ThreadCreateAndRunParams.Thread.Message
-
- All Implemented Interfaces:
public final class ThreadCreateAndRunParams.Thread.Message
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classThreadCreateAndRunParams.Thread.Message.BuilderA builder for Message.
public final classThreadCreateAndRunParams.Thread.Message.ContentThe text contents of the message.
public final classThreadCreateAndRunParams.Thread.Message.RoleThe role of the entity that is creating the message. Allowed values include:
user: Indicates the message is sent by an actual user and should be used in most cases to represent user-generated messages.assistant: Indicates the message is generated by the assistant. Use this value to insert messages from the assistant into the conversation.
public final classThreadCreateAndRunParams.Thread.Message.Attachmentpublic final classThreadCreateAndRunParams.Thread.Message.MetadataSet of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.
Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.
-
Method Summary
-
-
Method Detail
-
content
final ThreadCreateAndRunParams.Thread.Message.Content content()
The text contents of the message.
-
role
final ThreadCreateAndRunParams.Thread.Message.Role role()
The role of the entity that is creating the message. Allowed values include:
user: Indicates the message is sent by an actual user and should be used in most cases to represent user-generated messages.assistant: Indicates the message is generated by the assistant. Use this value to insert messages from the assistant into the conversation.
-
attachments
final Optional<List<ThreadCreateAndRunParams.Thread.Message.Attachment>> attachments()
A list of files attached to the message, and the tools they should be added to.
-
metadata
final Optional<ThreadCreateAndRunParams.Thread.Message.Metadata> metadata()
Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.
Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.
-
_content
final JsonField<ThreadCreateAndRunParams.Thread.Message.Content> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_role
final JsonField<ThreadCreateAndRunParams.Thread.Message.Role> _role()
Returns the raw JSON value of role.
Unlike role, this method doesn't throw if the JSON field has an unexpected type.
-
_attachments
final JsonField<List<ThreadCreateAndRunParams.Thread.Message.Attachment>> _attachments()
Returns the raw JSON value of attachments.
Unlike attachments, this method doesn't throw if the JSON field has an unexpected type.
-
_metadata
final JsonField<ThreadCreateAndRunParams.Thread.Message.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ThreadCreateAndRunParams.Thread.Message.Builder toBuilder()
-
validate
final ThreadCreateAndRunParams.Thread.Message validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ThreadCreateAndRunParams.Thread.Message.Builder builder()
Returns a mutable builder for constructing an instance of Message.
The following fields are required:
.content() .role()
-
-
-
-