Class ThreadCreateAndRunParams.Thread.ToolResources
-
- All Implemented Interfaces:
public final class ThreadCreateAndRunParams.Thread.ToolResourcesA set of resources that are made available to the assistant's tools in this thread. The resources are specific to the type of tool. For example, the
code_interpretertool requires a list of file IDs, while thefile_searchtool requires a list of vector store IDs.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classThreadCreateAndRunParams.Thread.ToolResources.BuilderA builder for ToolResources.
public final classThreadCreateAndRunParams.Thread.ToolResources.CodeInterpreterpublic final classThreadCreateAndRunParams.Thread.ToolResources.FileSearch
-
Method Summary
-
-
Method Detail
-
codeInterpreter
final Optional<ThreadCreateAndRunParams.Thread.ToolResources.CodeInterpreter> codeInterpreter()
-
fileSearch
final Optional<ThreadCreateAndRunParams.Thread.ToolResources.FileSearch> fileSearch()
-
_codeInterpreter
final JsonField<ThreadCreateAndRunParams.Thread.ToolResources.CodeInterpreter> _codeInterpreter()
Returns the raw JSON value of codeInterpreter.
Unlike codeInterpreter, this method doesn't throw if the JSON field has an unexpected type.
-
_fileSearch
final JsonField<ThreadCreateAndRunParams.Thread.ToolResources.FileSearch> _fileSearch()
Returns the raw JSON value of fileSearch.
Unlike fileSearch, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ThreadCreateAndRunParams.Thread.ToolResources.Builder toBuilder()
-
validate
final ThreadCreateAndRunParams.Thread.ToolResources validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ThreadCreateAndRunParams.Thread.ToolResources.Builder builder()
Returns a mutable builder for constructing an instance of ToolResources.
-
-
-
-