Package com.openai.models.beta.threads
Class ThreadCreateAndRunParams.Thread.ToolResources.CodeInterpreter
-
- All Implemented Interfaces:
public final class ThreadCreateAndRunParams.Thread.ToolResources.CodeInterpreter
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classThreadCreateAndRunParams.Thread.ToolResources.CodeInterpreter.BuilderA builder for CodeInterpreter.
-
Method Summary
Modifier and Type Method Description final Optional<List<String>>fileIds()A list of file IDs made available to the code_interpretertool.final JsonField<List<String>>_fileIds()Returns the raw JSON value of fileIds. final Map<String, JsonValue>_additionalProperties()final ThreadCreateAndRunParams.Thread.ToolResources.CodeInterpreter.BuildertoBuilder()final ThreadCreateAndRunParams.Thread.ToolResources.CodeInterpretervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ThreadCreateAndRunParams.Thread.ToolResources.CodeInterpreter.Builderbuilder()Returns a mutable builder for constructing an instance of CodeInterpreter. -
-
Method Detail
-
fileIds
final Optional<List<String>> fileIds()
A list of file IDs made available to the
code_interpretertool. There can be a maximum of 20 files associated with the tool.
-
_fileIds
final JsonField<List<String>> _fileIds()
Returns the raw JSON value of fileIds.
Unlike fileIds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final ThreadCreateAndRunParams.Thread.ToolResources.CodeInterpreter validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ThreadCreateAndRunParams.Thread.ToolResources.CodeInterpreter.Builder builder()
Returns a mutable builder for constructing an instance of CodeInterpreter.
-
-
-
-