Class ThreadCreateAndRunParams.Thread.ToolResources.FileSearch
-
- All Implemented Interfaces:
public final class ThreadCreateAndRunParams.Thread.ToolResources.FileSearch
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classThreadCreateAndRunParams.Thread.ToolResources.FileSearch.BuilderA builder for FileSearch.
public final classThreadCreateAndRunParams.Thread.ToolResources.FileSearch.VectorStore
-
Method Summary
-
-
Method Detail
-
vectorStoreIds
final Optional<List<String>> vectorStoreIds()
The vector store attached to this thread. There can be a maximum of 1 vector store attached to the thread.
-
vectorStores
final Optional<List<ThreadCreateAndRunParams.Thread.ToolResources.FileSearch.VectorStore>> vectorStores()
A helper to create a vector store with file_ids and attach it to this thread. There can be a maximum of 1 vector store attached to the thread.
-
_vectorStoreIds
final JsonField<List<String>> _vectorStoreIds()
Returns the raw JSON value of vectorStoreIds.
Unlike vectorStoreIds, this method doesn't throw if the JSON field has an unexpected type.
-
_vectorStores
final JsonField<List<ThreadCreateAndRunParams.Thread.ToolResources.FileSearch.VectorStore>> _vectorStores()
Returns the raw JSON value of vectorStores.
Unlike vectorStores, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ThreadCreateAndRunParams.Thread.ToolResources.FileSearch.Builder toBuilder()
-
validate
final ThreadCreateAndRunParams.Thread.ToolResources.FileSearch validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ThreadCreateAndRunParams.Thread.ToolResources.FileSearch.Builder builder()
Returns a mutable builder for constructing an instance of FileSearch.
-
-
-
-