Class ThreadCreateAndRunParams.Thread.ToolResources.FileSearch.VectorStore
-
- All Implemented Interfaces:
public final class ThreadCreateAndRunParams.Thread.ToolResources.FileSearch.VectorStore
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classThreadCreateAndRunParams.Thread.ToolResources.FileSearch.VectorStore.BuilderA builder for VectorStore.
public final classThreadCreateAndRunParams.Thread.ToolResources.FileSearch.VectorStore.ChunkingStrategyThe chunking strategy used to chunk the file(s). If not set, will use the
autostrategy.public final classThreadCreateAndRunParams.Thread.ToolResources.FileSearch.VectorStore.MetadataSet of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.
Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.
-
Method Summary
-
-
Method Detail
-
chunkingStrategy
final Optional<ThreadCreateAndRunParams.Thread.ToolResources.FileSearch.VectorStore.ChunkingStrategy> chunkingStrategy()
The chunking strategy used to chunk the file(s). If not set, will use the
autostrategy.
-
fileIds
final Optional<List<String>> fileIds()
A list of file IDs to add to the vector store. For vector stores created before Nov 2025, there can be a maximum of 10,000 files in a vector store. For vector stores created starting in Nov 2025, the limit is 100,000,000 files.
-
metadata
final Optional<ThreadCreateAndRunParams.Thread.ToolResources.FileSearch.VectorStore.Metadata> metadata()
Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.
Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.
-
_chunkingStrategy
final JsonField<ThreadCreateAndRunParams.Thread.ToolResources.FileSearch.VectorStore.ChunkingStrategy> _chunkingStrategy()
Returns the raw JSON value of chunkingStrategy.
Unlike chunkingStrategy, this method doesn't throw if the JSON field has an unexpected type.
-
_fileIds
final JsonField<List<String>> _fileIds()
Returns the raw JSON value of fileIds.
Unlike fileIds, this method doesn't throw if the JSON field has an unexpected type.
-
_metadata
final JsonField<ThreadCreateAndRunParams.Thread.ToolResources.FileSearch.VectorStore.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ThreadCreateAndRunParams.Thread.ToolResources.FileSearch.VectorStore.Builder toBuilder()
-
validate
final ThreadCreateAndRunParams.Thread.ToolResources.FileSearch.VectorStore validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ThreadCreateAndRunParams.Thread.ToolResources.FileSearch.VectorStore.Builder builder()
Returns a mutable builder for constructing an instance of VectorStore.
-
-
-
-