Package com.openai.models.beta.threads
Class ThreadCreateAndRunParams.Thread.ToolResources.FileSearch.VectorStore.ChunkingStrategy.Static
-
- All Implemented Interfaces:
public final class ThreadCreateAndRunParams.Thread.ToolResources.FileSearch.VectorStore.ChunkingStrategy.Static
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classThreadCreateAndRunParams.Thread.ToolResources.FileSearch.VectorStore.ChunkingStrategy.Static.BuilderA builder for Static.
public final classThreadCreateAndRunParams.Thread.ToolResources.FileSearch.VectorStore.ChunkingStrategy.Static.InnerStatic
-
Method Summary
-
-
Method Detail
-
static_
final ThreadCreateAndRunParams.Thread.ToolResources.FileSearch.VectorStore.ChunkingStrategy.Static.InnerStatic static_()
-
_type
final JsonValue _type()
Always
static.Expected to always return the following:
JsonValue.from("static")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_static_
final JsonField<ThreadCreateAndRunParams.Thread.ToolResources.FileSearch.VectorStore.ChunkingStrategy.Static.InnerStatic> _static_()
Returns the raw JSON value of static_.
Unlike static_, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ThreadCreateAndRunParams.Thread.ToolResources.FileSearch.VectorStore.ChunkingStrategy.Static.Builder toBuilder()
-
validate
final ThreadCreateAndRunParams.Thread.ToolResources.FileSearch.VectorStore.ChunkingStrategy.Static validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ThreadCreateAndRunParams.Thread.ToolResources.FileSearch.VectorStore.ChunkingStrategy.Static.Builder builder()
Returns a mutable builder for constructing an instance of Static.
The following fields are required:
.static_()
-
-
-
-