Class ThreadCreateParams.Body
-
- All Implemented Interfaces:
public final class ThreadCreateParams.BodyOptions to create a new thread. If no thread is provided when running a request, an empty thread will be created.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classThreadCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<List<ThreadCreateParams.Message>>messages()A list of messages to start the thread with. final Optional<ThreadCreateParams.Metadata>metadata()Set of 16 key-value pairs that can be attached to an object. final Optional<ThreadCreateParams.ToolResources>toolResources()A set of resources that are made available to the assistant's tools in this thread. final JsonField<List<ThreadCreateParams.Message>>_messages()Returns the raw JSON value of messages. final JsonField<ThreadCreateParams.Metadata>_metadata()Returns the raw JSON value of metadata. final JsonField<ThreadCreateParams.ToolResources>_toolResources()Returns the raw JSON value of toolResources. final Map<String, JsonValue>_additionalProperties()final ThreadCreateParams.Body.BuildertoBuilder()final ThreadCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ThreadCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
messages
final Optional<List<ThreadCreateParams.Message>> messages()
A list of messages to start the thread with.
-
metadata
final Optional<ThreadCreateParams.Metadata> metadata()
Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.
Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.
-
toolResources
final Optional<ThreadCreateParams.ToolResources> toolResources()
A set of resources that are made available to the assistant's tools in this thread. The resources are specific to the type of tool. For example, the
code_interpretertool requires a list of file IDs, while thefile_searchtool requires a list of vector store IDs.
-
_messages
final JsonField<List<ThreadCreateParams.Message>> _messages()
Returns the raw JSON value of messages.
Unlike messages, this method doesn't throw if the JSON field has an unexpected type.
-
_metadata
final JsonField<ThreadCreateParams.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_toolResources
final JsonField<ThreadCreateParams.ToolResources> _toolResources()
Returns the raw JSON value of toolResources.
Unlike toolResources, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ThreadCreateParams.Body.Builder toBuilder()
-
validate
final ThreadCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ThreadCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-