Package com.openai.models.beta.threads
Class ThreadCreateParams.Message.Attachment
-
- All Implemented Interfaces:
public final class ThreadCreateParams.Message.Attachment
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classThreadCreateParams.Message.Attachment.BuilderA builder for Attachment.
public final classThreadCreateParams.Message.Attachment.Tool
-
Method Summary
Modifier and Type Method Description final Optional<String>fileId()The ID of the file to attach to the message. final Optional<List<ThreadCreateParams.Message.Attachment.Tool>>tools()The tools to add this file to. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final JsonField<List<ThreadCreateParams.Message.Attachment.Tool>>_tools()Returns the raw JSON value of tools. final Map<String, JsonValue>_additionalProperties()final ThreadCreateParams.Message.Attachment.BuildertoBuilder()final ThreadCreateParams.Message.Attachmentvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ThreadCreateParams.Message.Attachment.Builderbuilder()Returns a mutable builder for constructing an instance of Attachment. -
-
Method Detail
-
tools
final Optional<List<ThreadCreateParams.Message.Attachment.Tool>> tools()
The tools to add this file to.
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_tools
final JsonField<List<ThreadCreateParams.Message.Attachment.Tool>> _tools()
Returns the raw JSON value of tools.
Unlike tools, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ThreadCreateParams.Message.Attachment.Builder toBuilder()
-
validate
final ThreadCreateParams.Message.Attachment validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ThreadCreateParams.Message.Attachment.Builder builder()
Returns a mutable builder for constructing an instance of Attachment.
-
-
-
-