Class ThreadUpdateParams.Body
-
- All Implemented Interfaces:
public final class ThreadUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classThreadUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<ThreadUpdateParams.Metadata>metadata()Set of 16 key-value pairs that can be attached to an object. final Optional<ThreadUpdateParams.ToolResources>toolResources()A set of resources that are made available to the assistant's tools in this thread. final JsonField<ThreadUpdateParams.Metadata>_metadata()Returns the raw JSON value of metadata. final JsonField<ThreadUpdateParams.ToolResources>_toolResources()Returns the raw JSON value of toolResources. final Map<String, JsonValue>_additionalProperties()final ThreadUpdateParams.Body.BuildertoBuilder()final ThreadUpdateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ThreadUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
metadata
final Optional<ThreadUpdateParams.Metadata> metadata()
Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.
Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.
-
toolResources
final Optional<ThreadUpdateParams.ToolResources> toolResources()
A set of resources that are made available to the assistant's tools in this thread. The resources are specific to the type of tool. For example, the
code_interpretertool requires a list of file IDs, while thefile_searchtool requires a list of vector store IDs.
-
_metadata
final JsonField<ThreadUpdateParams.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_toolResources
final JsonField<ThreadUpdateParams.ToolResources> _toolResources()
Returns the raw JSON value of toolResources.
Unlike toolResources, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ThreadUpdateParams.Body.Builder toBuilder()
-
validate
final ThreadUpdateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ThreadUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-