Package com.openai.models.beta.threads
Class ThreadUpdateParams.Metadata
-
- All Implemented Interfaces:
public final class ThreadUpdateParams.MetadataSet of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.
Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classThreadUpdateParams.Metadata.BuilderA builder for Metadata.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final ThreadUpdateParams.Metadata.BuildertoBuilder()final ThreadUpdateParams.Metadatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ThreadUpdateParams.Metadata.Builderbuilder()Returns a mutable builder for constructing an instance of Metadata. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ThreadUpdateParams.Metadata.Builder toBuilder()
-
validate
final ThreadUpdateParams.Metadata validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ThreadUpdateParams.Metadata.Builder builder()
Returns a mutable builder for constructing an instance of Metadata.
-
-
-
-