Class FilePathAnnotation
-
- All Implemented Interfaces:
public final class FilePathAnnotationA URL for the file that's generated when the assistant used the
code_interpretertool to generate a file.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFilePathAnnotation.BuilderA builder for FilePathAnnotation.
public final classFilePathAnnotation.FilePath
-
Method Summary
Modifier and Type Method Description final LongendIndex()final FilePathAnnotation.FilePathfilePath()final LongstartIndex()final Stringtext()The text in the message content that needs to be replaced. final JsonValue_type()Always file_path.final JsonField<Long>_endIndex()Returns the raw JSON value of endIndex. final JsonField<FilePathAnnotation.FilePath>_filePath()Returns the raw JSON value of filePath. final JsonField<Long>_startIndex()Returns the raw JSON value of startIndex. final JsonField<String>_text()Returns the raw JSON value of text. final Map<String, JsonValue>_additionalProperties()final FilePathAnnotation.BuildertoBuilder()final FilePathAnnotationvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FilePathAnnotation.Builderbuilder()Returns a mutable builder for constructing an instance of FilePathAnnotation. -
-
Method Detail
-
filePath
final FilePathAnnotation.FilePath filePath()
-
startIndex
final Long startIndex()
-
_type
final JsonValue _type()
Always
file_path.Expected to always return the following:
JsonValue.from("file_path")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_endIndex
final JsonField<Long> _endIndex()
Returns the raw JSON value of endIndex.
Unlike endIndex, this method doesn't throw if the JSON field has an unexpected type.
-
_filePath
final JsonField<FilePathAnnotation.FilePath> _filePath()
Returns the raw JSON value of filePath.
Unlike filePath, this method doesn't throw if the JSON field has an unexpected type.
-
_startIndex
final JsonField<Long> _startIndex()
Returns the raw JSON value of startIndex.
Unlike startIndex, this method doesn't throw if the JSON field has an unexpected type.
-
_text
final JsonField<String> _text()
Returns the raw JSON value of text.
Unlike text, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FilePathAnnotation.Builder toBuilder()
-
validate
final FilePathAnnotation validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FilePathAnnotation.Builder builder()
Returns a mutable builder for constructing an instance of FilePathAnnotation.
The following fields are required:
.endIndex() .filePath() .startIndex() .text()
-
-
-
-