Class FilePathAnnotation.FilePath
-
- All Implemented Interfaces:
public final class FilePathAnnotation.FilePath
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFilePathAnnotation.FilePath.BuilderA builder for FilePath.
-
Method Summary
Modifier and Type Method Description final StringfileId()The ID of the file that was generated. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final Map<String, JsonValue>_additionalProperties()final FilePathAnnotation.FilePath.BuildertoBuilder()final FilePathAnnotation.FilePathvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FilePathAnnotation.FilePath.Builderbuilder()Returns a mutable builder for constructing an instance of FilePath. -
-
Method Detail
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FilePathAnnotation.FilePath.Builder toBuilder()
-
validate
final FilePathAnnotation.FilePath validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FilePathAnnotation.FilePath.Builder builder()
Returns a mutable builder for constructing an instance of FilePath.
The following fields are required:
.fileId()
-
-
-
-