Class FilePathDeltaAnnotation
-
- All Implemented Interfaces:
public final class FilePathDeltaAnnotationA URL for the file that's generated when the assistant used the
code_interpretertool to generate a file.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFilePathDeltaAnnotation.BuilderA builder for FilePathDeltaAnnotation.
public final classFilePathDeltaAnnotation.FilePath
-
Method Summary
Modifier and Type Method Description final Longindex()The index of the annotation in the text content part. final JsonValue_type()Always file_path.final Optional<Long>endIndex()final Optional<FilePathDeltaAnnotation.FilePath>filePath()final Optional<Long>startIndex()final Optional<String>text()The text in the message content that needs to be replaced. final JsonField<Long>_index()Returns the raw JSON value of index. final JsonField<Long>_endIndex()Returns the raw JSON value of endIndex. final JsonField<FilePathDeltaAnnotation.FilePath>_filePath()Returns the raw JSON value of filePath. final JsonField<Long>_startIndex()Returns the raw JSON value of startIndex. final JsonField<String>_text()Returns the raw JSON value of text. final Map<String, JsonValue>_additionalProperties()final FilePathDeltaAnnotation.BuildertoBuilder()final FilePathDeltaAnnotationvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FilePathDeltaAnnotation.Builderbuilder()Returns a mutable builder for constructing an instance of FilePathDeltaAnnotation. -
-
Method Detail
-
_type
final JsonValue _type()
Always
file_path.Expected to always return the following:
JsonValue.from("file_path")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
filePath
final Optional<FilePathDeltaAnnotation.FilePath> filePath()
-
startIndex
final Optional<Long> startIndex()
-
_index
final JsonField<Long> _index()
Returns the raw JSON value of index.
Unlike index, this method doesn't throw if the JSON field has an unexpected type.
-
_endIndex
final JsonField<Long> _endIndex()
Returns the raw JSON value of endIndex.
Unlike endIndex, this method doesn't throw if the JSON field has an unexpected type.
-
_filePath
final JsonField<FilePathDeltaAnnotation.FilePath> _filePath()
Returns the raw JSON value of filePath.
Unlike filePath, this method doesn't throw if the JSON field has an unexpected type.
-
_startIndex
final JsonField<Long> _startIndex()
Returns the raw JSON value of startIndex.
Unlike startIndex, this method doesn't throw if the JSON field has an unexpected type.
-
_text
final JsonField<String> _text()
Returns the raw JSON value of text.
Unlike text, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FilePathDeltaAnnotation.Builder toBuilder()
-
validate
final FilePathDeltaAnnotation validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FilePathDeltaAnnotation.Builder builder()
Returns a mutable builder for constructing an instance of FilePathDeltaAnnotation.
The following fields are required:
.index()
-
-
-
-