Class ComputerScreenshotContent
-
- All Implemented Interfaces:
public final class ComputerScreenshotContentA screenshot of a computer.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classComputerScreenshotContent.BuilderA builder for ComputerScreenshotContent.
public final classComputerScreenshotContent.DetailThe detail level of the screenshot image to be sent to the model. One of
high,low,auto, ororiginal. Defaults toauto.
-
Method Summary
Modifier and Type Method Description final ComputerScreenshotContent.Detaildetail()The detail level of the screenshot image to be sent to the model. final Optional<String>fileId()The identifier of an uploaded file that contains the screenshot. final Optional<String>imageUrl()The URL of the screenshot image. final JsonValue_type()Specifies the event type. final JsonField<ComputerScreenshotContent.Detail>_detail()Returns the raw JSON value of detail. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final JsonField<String>_imageUrl()Returns the raw JSON value of imageUrl. final Map<String, JsonValue>_additionalProperties()final ComputerScreenshotContent.BuildertoBuilder()final ComputerScreenshotContentvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ComputerScreenshotContent.Builderbuilder()Returns a mutable builder for constructing an instance of ComputerScreenshotContent. -
-
Method Detail
-
detail
final ComputerScreenshotContent.Detail detail()
The detail level of the screenshot image to be sent to the model. One of
high,low,auto, ororiginal. Defaults toauto.
-
fileId
final Optional<String> fileId()
The identifier of an uploaded file that contains the screenshot.
-
_type
final JsonValue _type()
Specifies the event type. For a computer screenshot, this property is always set to
computer_screenshot.Expected to always return the following:
JsonValue.from("computer_screenshot")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_detail
final JsonField<ComputerScreenshotContent.Detail> _detail()
Returns the raw JSON value of detail.
Unlike detail, this method doesn't throw if the JSON field has an unexpected type.
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_imageUrl
final JsonField<String> _imageUrl()
Returns the raw JSON value of imageUrl.
Unlike imageUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ComputerScreenshotContent.Builder toBuilder()
-
validate
final ComputerScreenshotContent validate()
-
builder
final static ComputerScreenshotContent.Builder builder()
Returns a mutable builder for constructing an instance of ComputerScreenshotContent.
The following fields are required:
.detail() .fileId() .imageUrl()
-
-
-
-