Class FileCreateParams

  • All Implemented Interfaces:
    com.openai.core.Params

    
    public final class FileCreateParams
     implements Params
                        

    Upload a file that can be used across various endpoints. Individual files can be up to 512 MB, and each project can store up to 2.5 TB of files in total. There is no organization-wide storage limit. Uploads to this endpoint are rate-limited to 2,000 files per minute per organization.

    • The Assistants API supports files up to 2 million tokens and of specific file types. See the Assistants Tools guide for details.

    • The Fine-tuning API only supports .jsonl files. The input also has certain required formats for fine-tuning chat or completions models.

    • The Batch API only supports .jsonl files up to 200 MB in size. The input also has a specific required format.

    • For Retrieval or file_search ingestion, upload files here first. If you need to attach multiple uploaded files to the same vector store, use /vector_stores/{vector_store_id}/file_batches instead of attaching them one by one.

    Please contact us if you need to increase these storage limits.