Class SupervisedMethod
-
- All Implemented Interfaces:
public final class SupervisedMethodConfiguration for the supervised fine-tuning method.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classSupervisedMethod.BuilderA builder for SupervisedMethod.
-
Method Summary
Modifier and Type Method Description final Optional<SupervisedHyperparameters>hyperparameters()The hyperparameters used for the fine-tuning job. final JsonField<SupervisedHyperparameters>_hyperparameters()Returns the raw JSON value of hyperparameters. final Map<String, JsonValue>_additionalProperties()final SupervisedMethod.BuildertoBuilder()final SupervisedMethodvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static SupervisedMethod.Builderbuilder()Returns a mutable builder for constructing an instance of SupervisedMethod. -
-
Method Detail
-
hyperparameters
final Optional<SupervisedHyperparameters> hyperparameters()
The hyperparameters used for the fine-tuning job.
-
_hyperparameters
final JsonField<SupervisedHyperparameters> _hyperparameters()
Returns the raw JSON value of hyperparameters.
Unlike hyperparameters, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final SupervisedMethod.Builder toBuilder()
-
validate
final SupervisedMethod validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static SupervisedMethod.Builder builder()
Returns a mutable builder for constructing an instance of SupervisedMethod.
-
-
-
-