Package com.openai.models.moderations
Class ModerationTextInput
-
- All Implemented Interfaces:
public final class ModerationTextInputAn object describing text to classify.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classModerationTextInput.BuilderA builder for ModerationTextInput.
-
Method Summary
Modifier and Type Method Description final Stringtext()A string of text to classify. final JsonValue_type()Always text.final JsonField<String>_text()Returns the raw JSON value of text. final Map<String, JsonValue>_additionalProperties()final ModerationTextInput.BuildertoBuilder()final ModerationTextInputvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ModerationTextInput.Builderbuilder()Returns a mutable builder for constructing an instance of ModerationTextInput. -
-
Method Detail
-
_type
final JsonValue _type()
Always
text.Expected to always return the following:
JsonValue.from("text")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_text
final JsonField<String> _text()
Returns the raw JSON value of text.
Unlike text, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ModerationTextInput.Builder toBuilder()
-
validate
final ModerationTextInput validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ModerationTextInput.Builder builder()
Returns a mutable builder for constructing an instance of ModerationTextInput.
The following fields are required:
.text()
-
-
-
-