Class RealtimeTranslationClientSecretCreateRequest
-
- All Implemented Interfaces:
public final class RealtimeTranslationClientSecretCreateRequestCreate a translation session and client secret for the Realtime API.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealtimeTranslationClientSecretCreateRequest.BuilderA builder for RealtimeTranslationClientSecretCreateRequest.
public final classRealtimeTranslationClientSecretCreateRequest.ExpiresAfterConfiguration for the client secret expiration. Expiration refers to the time after which a client secret will no longer be valid for creating sessions. The session itself may continue after that time once started. A secret can be used to create multiple sessions until it expires.
-
Method Summary
-
-
Method Detail
-
session
final RealtimeTranslationSessionCreateRequest session()
Realtime translation session configuration. Translation sessions stream source audio in and translated audio plus transcript deltas out continuously.
-
expiresAfter
final Optional<RealtimeTranslationClientSecretCreateRequest.ExpiresAfter> expiresAfter()
Configuration for the client secret expiration. Expiration refers to the time after which a client secret will no longer be valid for creating sessions. The session itself may continue after that time once started. A secret can be used to create multiple sessions until it expires.
-
_session
final JsonField<RealtimeTranslationSessionCreateRequest> _session()
Returns the raw JSON value of session.
Unlike session, this method doesn't throw if the JSON field has an unexpected type.
-
_expiresAfter
final JsonField<RealtimeTranslationClientSecretCreateRequest.ExpiresAfter> _expiresAfter()
Returns the raw JSON value of expiresAfter.
Unlike expiresAfter, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RealtimeTranslationClientSecretCreateRequest.Builder toBuilder()
-
validate
final RealtimeTranslationClientSecretCreateRequest validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RealtimeTranslationClientSecretCreateRequest.Builder builder()
Returns a mutable builder for constructing an instance of RealtimeTranslationClientSecretCreateRequest.
The following fields are required:
.session()
-
-
-
-