Class RealtimeTranslationInputTranscriptDeltaEvent
-
- All Implemented Interfaces:
public final class RealtimeTranslationInputTranscriptDeltaEventReturned when optional source-language transcript text is available. This event is emitted only when
audio.input.transcriptionis configured.Transcript deltas are append-only text fragments. Clients should not insert unconditional spaces between deltas.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRealtimeTranslationInputTranscriptDeltaEvent.BuilderA builder for RealtimeTranslationInputTranscriptDeltaEvent.
-
Method Summary
Modifier and Type Method Description final Stringdelta()Append-only source-language transcript text. final StringeventId()The unique ID of the server event. final JsonValue_type()The event type, must be session.input_transcript.delta.final Optional<Long>elapsedMs()Timing metadata for stream alignment, derived from the translation frame when available. final JsonField<String>_delta()Returns the raw JSON value of delta. final JsonField<String>_eventId()Returns the raw JSON value of eventId. final JsonField<Long>_elapsedMs()Returns the raw JSON value of elapsedMs. final Map<String, JsonValue>_additionalProperties()final RealtimeTranslationInputTranscriptDeltaEvent.BuildertoBuilder()final RealtimeTranslationInputTranscriptDeltaEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RealtimeTranslationInputTranscriptDeltaEvent.Builderbuilder()Returns a mutable builder for constructing an instance of RealtimeTranslationInputTranscriptDeltaEvent. -
-
Method Detail
-
_type
final JsonValue _type()
The event type, must be
session.input_transcript.delta.Expected to always return the following:
JsonValue.from("session.input_transcript.delta")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
elapsedMs
final Optional<Long> elapsedMs()
Timing metadata for stream alignment, derived from the translation frame when available. It advances in 200 ms increments, but multiple transcript deltas may share the same
elapsed_ms. Treat it as alignment metadata, not a unique transcript-delta identifier.
-
_delta
final JsonField<String> _delta()
Returns the raw JSON value of delta.
Unlike delta, this method doesn't throw if the JSON field has an unexpected type.
-
_eventId
final JsonField<String> _eventId()
Returns the raw JSON value of eventId.
Unlike eventId, this method doesn't throw if the JSON field has an unexpected type.
-
_elapsedMs
final JsonField<Long> _elapsedMs()
Returns the raw JSON value of elapsedMs.
Unlike elapsedMs, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RealtimeTranslationInputTranscriptDeltaEvent.Builder toBuilder()
-
validate
final RealtimeTranslationInputTranscriptDeltaEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RealtimeTranslationInputTranscriptDeltaEvent.Builder builder()
Returns a mutable builder for constructing an instance of RealtimeTranslationInputTranscriptDeltaEvent.
The following fields are required:
.delta() .eventId()
-
-
-
-