Class RealtimeTranslationOutputTranscriptDeltaEvent.Builder
-
- All Implemented Interfaces:
public final class RealtimeTranslationOutputTranscriptDeltaEvent.BuilderA builder for RealtimeTranslationOutputTranscriptDeltaEvent.
-
-
Method Summary
-
-
Method Detail
-
delta
final RealtimeTranslationOutputTranscriptDeltaEvent.Builder delta(String delta)
Append-only transcript text for the translated output audio.
-
delta
final RealtimeTranslationOutputTranscriptDeltaEvent.Builder delta(JsonField<String> delta)
Sets Builder.delta to an arbitrary JSON value.
You should usually call Builder.delta with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
eventId
final RealtimeTranslationOutputTranscriptDeltaEvent.Builder eventId(String eventId)
The unique ID of the server event.
-
eventId
final RealtimeTranslationOutputTranscriptDeltaEvent.Builder eventId(JsonField<String> eventId)
Sets Builder.eventId to an arbitrary JSON value.
You should usually call Builder.eventId with a well-typed String value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
type
final RealtimeTranslationOutputTranscriptDeltaEvent.Builder type(JsonValue type)
Sets the field to an arbitrary JSON value.
It is usually unnecessary to call this method because the field defaults to the following:
JsonValue.from("session.output_transcript.delta")This method is primarily for setting the field to an undocumented or not yet supported value.
-
elapsedMs
final RealtimeTranslationOutputTranscriptDeltaEvent.Builder elapsedMs(Long elapsedMs)
Timing metadata for stream alignment, derived from the translation frame when available. It advances in 200 ms increments, but multiple transcript deltas may share the same
elapsed_ms. Treat it as alignment metadata, not a unique transcript-delta identifier.
-
elapsedMs
final RealtimeTranslationOutputTranscriptDeltaEvent.Builder elapsedMs(Long elapsedMs)
Alias for Builder.elapsedMs.
This unboxed primitive overload exists for backwards compatibility.
-
elapsedMs
final RealtimeTranslationOutputTranscriptDeltaEvent.Builder elapsedMs(Optional<Long> elapsedMs)
Alias for calling Builder.elapsedMs with
elapsedMs.orElse(null).
-
elapsedMs
final RealtimeTranslationOutputTranscriptDeltaEvent.Builder elapsedMs(JsonField<Long> elapsedMs)
Sets Builder.elapsedMs to an arbitrary JSON value.
You should usually call Builder.elapsedMs with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RealtimeTranslationOutputTranscriptDeltaEvent.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RealtimeTranslationOutputTranscriptDeltaEvent.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RealtimeTranslationOutputTranscriptDeltaEvent.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RealtimeTranslationOutputTranscriptDeltaEvent.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RealtimeTranslationOutputTranscriptDeltaEvent.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RealtimeTranslationOutputTranscriptDeltaEvent build()
Returns an immutable instance of RealtimeTranslationOutputTranscriptDeltaEvent.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.delta() .eventId()
-
-
-
-