Class ComputerAction
-
- All Implemented Interfaces:
public final class ComputerActionA click action.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceComputerAction.VisitorAn interface that defines how to map each variant of ComputerAction to a value of type T.
public final classComputerAction.ClickA click action.
public final classComputerAction.DoubleClickA double click action.
public final classComputerAction.DragA drag action.
public final classComputerAction.KeypressA collection of keypresses the model would like to perform.
public final classComputerAction.MoveA mouse move action.
public final classComputerAction.ScrollA scroll action.
public final classComputerAction.TypeAn action to type in text.
-
Method Summary
Modifier and Type Method Description final Optional<ComputerAction.Click>click()A click action. final Optional<ComputerAction.DoubleClick>doubleClick()A double click action. final Optional<ComputerAction.Drag>drag()A drag action. final Optional<ComputerAction.Keypress>keypress()A collection of keypresses the model would like to perform. final Optional<ComputerAction.Move>move()A mouse move action. final Optional<JsonValue>screenshot()A screenshot action. final Optional<ComputerAction.Scroll>scroll()A scroll action. final Optional<ComputerAction.Type>type()An action to type in text. final Optional<JsonValue>wait()A wait action. final BooleanisClick()final BooleanisDoubleClick()final BooleanisDrag()final BooleanisKeypress()final BooleanisMove()final BooleanisScreenshot()final BooleanisScroll()final BooleanisType()final BooleanisWait()final ComputerAction.ClickasClick()A click action. final ComputerAction.DoubleClickasDoubleClick()A double click action. final ComputerAction.DragasDrag()A drag action. final ComputerAction.KeypressasKeypress()A collection of keypresses the model would like to perform. final ComputerAction.MoveasMove()A mouse move action. final JsonValueasScreenshot()A screenshot action. final ComputerAction.ScrollasScroll()A scroll action. final ComputerAction.TypeasType()An action to type in text. final JsonValueasWait()A wait action. final Optional<JsonValue>_json()final <T extends Any> Taccept(ComputerAction.Visitor<T> visitor)final ComputerActionvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ComputerActionofClick(ComputerAction.Click click)A click action. final static ComputerActionofDoubleClick(ComputerAction.DoubleClick doubleClick)A double click action. final static ComputerActionofDrag(ComputerAction.Drag drag)A drag action. final static ComputerActionofKeypress(ComputerAction.Keypress keypress)A collection of keypresses the model would like to perform. final static ComputerActionofMove(ComputerAction.Move move)A mouse move action. final static ComputerActionofScreenshot()A screenshot action. final static ComputerActionofScroll(ComputerAction.Scroll scroll)A scroll action. final static ComputerActionofType(ComputerAction.Type type)An action to type in text. final static ComputerActionofWait()A wait action. -
-
Method Detail
-
click
final Optional<ComputerAction.Click> click()
A click action.
-
doubleClick
final Optional<ComputerAction.DoubleClick> doubleClick()
A double click action.
-
drag
final Optional<ComputerAction.Drag> drag()
A drag action.
-
keypress
final Optional<ComputerAction.Keypress> keypress()
A collection of keypresses the model would like to perform.
-
move
final Optional<ComputerAction.Move> move()
A mouse move action.
-
screenshot
final Optional<JsonValue> screenshot()
A screenshot action.
-
scroll
final Optional<ComputerAction.Scroll> scroll()
A scroll action.
-
type
final Optional<ComputerAction.Type> type()
An action to type in text.
-
isDoubleClick
final Boolean isDoubleClick()
-
isKeypress
final Boolean isKeypress()
-
isScreenshot
final Boolean isScreenshot()
-
asClick
final ComputerAction.Click asClick()
A click action.
-
asDoubleClick
final ComputerAction.DoubleClick asDoubleClick()
A double click action.
-
asDrag
final ComputerAction.Drag asDrag()
A drag action.
-
asKeypress
final ComputerAction.Keypress asKeypress()
A collection of keypresses the model would like to perform.
-
asMove
final ComputerAction.Move asMove()
A mouse move action.
-
asScreenshot
final JsonValue asScreenshot()
A screenshot action.
-
asScroll
final ComputerAction.Scroll asScroll()
A scroll action.
-
asType
final ComputerAction.Type asType()
An action to type in text.
-
accept
final <T extends Any> T accept(ComputerAction.Visitor<T> visitor)
-
validate
final ComputerAction validate()
-
ofClick
final static ComputerAction ofClick(ComputerAction.Click click)
A click action.
-
ofDoubleClick
final static ComputerAction ofDoubleClick(ComputerAction.DoubleClick doubleClick)
A double click action.
-
ofDrag
final static ComputerAction ofDrag(ComputerAction.Drag drag)
A drag action.
-
ofKeypress
final static ComputerAction ofKeypress(ComputerAction.Keypress keypress)
A collection of keypresses the model would like to perform.
-
ofMove
final static ComputerAction ofMove(ComputerAction.Move move)
A mouse move action.
-
ofScreenshot
final static ComputerAction ofScreenshot()
A screenshot action.
-
ofScroll
final static ComputerAction ofScroll(ComputerAction.Scroll scroll)
A scroll action.
-
ofType
final static ComputerAction ofType(ComputerAction.Type type)
An action to type in text.
-
ofWait
final static ComputerAction ofWait()
A wait action.
-
-
-
-