Class ComputerAction.Click
-
- All Implemented Interfaces:
public final class ComputerAction.ClickA click action.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classComputerAction.Click.BuilderA builder for Click.
public final classComputerAction.Click.ButtonIndicates which mouse button was pressed during the click. One of
left,right,wheel,back, orforward.
-
Method Summary
Modifier and Type Method Description final ComputerAction.Click.Buttonbutton()Indicates which mouse button was pressed during the click. final JsonValue_type()Specifies the event type. final Longx()The x-coordinate where the click occurred. final Longy()The y-coordinate where the click occurred. final Optional<List<String>>keys()The keys being held while clicking. final JsonField<ComputerAction.Click.Button>_button()Returns the raw JSON value of button. final JsonField<Long>_x()Returns the raw JSON value of x. final JsonField<Long>_y()Returns the raw JSON value of y. final JsonField<List<String>>_keys()Returns the raw JSON value of keys. final Map<String, JsonValue>_additionalProperties()final ComputerAction.Click.BuildertoBuilder()final ComputerAction.Clickvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ComputerAction.Click.Builderbuilder()Returns a mutable builder for constructing an instance of Click. -
-
Method Detail
-
button
final ComputerAction.Click.Button button()
Indicates which mouse button was pressed during the click. One of
left,right,wheel,back, orforward.
-
_type
final JsonValue _type()
Specifies the event type. For a click action, this property is always
click.Expected to always return the following:
JsonValue.from("click")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_button
final JsonField<ComputerAction.Click.Button> _button()
Returns the raw JSON value of button.
Unlike button, this method doesn't throw if the JSON field has an unexpected type.
-
_x
final JsonField<Long> _x()
Returns the raw JSON value of x.
Unlike x, this method doesn't throw if the JSON field has an unexpected type.
-
_y
final JsonField<Long> _y()
Returns the raw JSON value of y.
Unlike y, this method doesn't throw if the JSON field has an unexpected type.
-
_keys
final JsonField<List<String>> _keys()
Returns the raw JSON value of keys.
Unlike keys, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ComputerAction.Click.Builder toBuilder()
-
validate
final ComputerAction.Click validate()
-
builder
final static ComputerAction.Click.Builder builder()
Returns a mutable builder for constructing an instance of Click.
The following fields are required:
.button() .x() .y()
-
-
-
-