Class ComputerUsePreviewTool
-
- All Implemented Interfaces:
public final class ComputerUsePreviewToolA tool that controls a virtual computer. Learn more about the computer tool.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classComputerUsePreviewTool.BuilderA builder for ComputerUsePreviewTool.
public final classComputerUsePreviewTool.EnvironmentThe type of computer environment to control.
-
Method Summary
Modifier and Type Method Description final LongdisplayHeight()The height of the computer display. final LongdisplayWidth()The width of the computer display. final ComputerUsePreviewTool.Environmentenvironment()The type of computer environment to control. final JsonValue_type()The type of the computer use tool. final JsonField<Long>_displayHeight()Returns the raw JSON value of displayHeight. final JsonField<Long>_displayWidth()Returns the raw JSON value of displayWidth. final JsonField<ComputerUsePreviewTool.Environment>_environment()Returns the raw JSON value of environment. final Map<String, JsonValue>_additionalProperties()final ComputerUsePreviewTool.BuildertoBuilder()final ComputerUsePreviewToolvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ComputerUsePreviewTool.Builderbuilder()Returns a mutable builder for constructing an instance of ComputerUsePreviewTool. -
-
Method Detail
-
displayHeight
final Long displayHeight()
The height of the computer display.
-
displayWidth
final Long displayWidth()
The width of the computer display.
-
environment
final ComputerUsePreviewTool.Environment environment()
The type of computer environment to control.
-
_type
final JsonValue _type()
The type of the computer use tool. Always
computer_use_preview.Expected to always return the following:
JsonValue.from("computer_use_preview")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_displayHeight
final JsonField<Long> _displayHeight()
Returns the raw JSON value of displayHeight.
Unlike displayHeight, this method doesn't throw if the JSON field has an unexpected type.
-
_displayWidth
final JsonField<Long> _displayWidth()
Returns the raw JSON value of displayWidth.
Unlike displayWidth, this method doesn't throw if the JSON field has an unexpected type.
-
_environment
final JsonField<ComputerUsePreviewTool.Environment> _environment()
Returns the raw JSON value of environment.
Unlike environment, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ComputerUsePreviewTool.Builder toBuilder()
-
validate
final ComputerUsePreviewTool validate()
-
builder
final static ComputerUsePreviewTool.Builder builder()
Returns a mutable builder for constructing an instance of ComputerUsePreviewTool.
The following fields are required:
.displayHeight() .displayWidth() .environment()
-
-
-
-