Package com.openai.models.responses
Class FunctionShellTool
-
- All Implemented Interfaces:
public final class FunctionShellToolA tool that allows the model to execute shell commands.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classFunctionShellTool.BuilderA builder for FunctionShellTool.
public final classFunctionShellTool.Environment
-
Method Summary
Modifier and Type Method Description final JsonValue_type()The type of the shell tool. final Optional<FunctionShellTool.Environment>environment()final JsonField<FunctionShellTool.Environment>_environment()Returns the raw JSON value of environment. final Map<String, JsonValue>_additionalProperties()final FunctionShellTool.BuildertoBuilder()final FunctionShellToolvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static FunctionShellTool.Builderbuilder()Returns a mutable builder for constructing an instance of FunctionShellTool. -
-
Method Detail
-
_type
final JsonValue _type()
The type of the shell tool. Always
shell.Expected to always return the following:
JsonValue.from("shell")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
environment
final Optional<FunctionShellTool.Environment> environment()
-
_environment
final JsonField<FunctionShellTool.Environment> _environment()
Returns the raw JSON value of environment.
Unlike environment, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final FunctionShellTool.Builder toBuilder()
-
validate
final FunctionShellTool validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static FunctionShellTool.Builder builder()
Returns a mutable builder for constructing an instance of FunctionShellTool.
-
-
-
-