Class FunctionShellTool.Builder
-
- All Implemented Interfaces:
public final class FunctionShellTool.BuilderA builder for FunctionShellTool.
-
-
Method Summary
-
-
Method Detail
-
type
final FunctionShellTool.Builder type(JsonValue type)
Sets the field to an arbitrary JSON value.
It is usually unnecessary to call this method because the field defaults to the following:
JsonValue.from("shell")This method is primarily for setting the field to an undocumented or not yet supported value.
-
environment
final FunctionShellTool.Builder environment(FunctionShellTool.Environment environment)
-
environment
final FunctionShellTool.Builder environment(Optional<FunctionShellTool.Environment> environment)
Alias for calling Builder.environment with
environment.orElse(null).
-
environment
final FunctionShellTool.Builder environment(JsonField<FunctionShellTool.Environment> environment)
Sets Builder.environment to an arbitrary JSON value.
You should usually call Builder.environment with a well-typed Environment value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
environment
final FunctionShellTool.Builder environment(ContainerAuto containerAuto)
Alias for calling environment with
Environment.ofContainerAuto(containerAuto).
-
environment
final FunctionShellTool.Builder environment(LocalEnvironment local)
Alias for calling environment with
Environment.ofLocal(local).
-
environment
final FunctionShellTool.Builder environment(ContainerReference containerReference)
Alias for calling environment with
Environment.ofContainerReference(containerReference).
-
containerReferenceEnvironment
final FunctionShellTool.Builder containerReferenceEnvironment(String containerId)
Alias for calling environment with the following:
ContainerReference.builder() .containerId(containerId) .build()
-
additionalProperties
final FunctionShellTool.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final FunctionShellTool.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final FunctionShellTool.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final FunctionShellTool.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final FunctionShellTool.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final FunctionShellTool build()
Returns an immutable instance of FunctionShellTool.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-