Class ResponseAudioTranscriptDeltaEvent
-
- All Implemented Interfaces:
public final class ResponseAudioTranscriptDeltaEventEmitted when there is a partial transcript of audio.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classResponseAudioTranscriptDeltaEvent.BuilderA builder for ResponseAudioTranscriptDeltaEvent.
-
Method Summary
Modifier and Type Method Description final Stringdelta()The partial transcript of the audio response. final LongsequenceNumber()The sequence number of this event. final JsonValue_type()The type of the event. final JsonField<String>_delta()Returns the raw JSON value of delta. final JsonField<Long>_sequenceNumber()Returns the raw JSON value of sequenceNumber. final Map<String, JsonValue>_additionalProperties()final ResponseAudioTranscriptDeltaEvent.BuildertoBuilder()final ResponseAudioTranscriptDeltaEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ResponseAudioTranscriptDeltaEvent.Builderbuilder()Returns a mutable builder for constructing an instance of ResponseAudioTranscriptDeltaEvent. -
-
Method Detail
-
sequenceNumber
final Long sequenceNumber()
The sequence number of this event.
-
_type
final JsonValue _type()
The type of the event. Always
response.audio.transcript.delta.Expected to always return the following:
JsonValue.from("response.audio.transcript.delta")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_delta
final JsonField<String> _delta()
Returns the raw JSON value of delta.
Unlike delta, this method doesn't throw if the JSON field has an unexpected type.
-
_sequenceNumber
final JsonField<Long> _sequenceNumber()
Returns the raw JSON value of sequenceNumber.
Unlike sequenceNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ResponseAudioTranscriptDeltaEvent.Builder toBuilder()
-
validate
final ResponseAudioTranscriptDeltaEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ResponseAudioTranscriptDeltaEvent.Builder builder()
Returns a mutable builder for constructing an instance of ResponseAudioTranscriptDeltaEvent.
The following fields are required:
.delta() .sequenceNumber()
-
-
-
-