Class ResponseAudioTranscriptDoneEvent
-
- All Implemented Interfaces:
public final class ResponseAudioTranscriptDoneEventEmitted when the full audio transcript is completed.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classResponseAudioTranscriptDoneEvent.BuilderA builder for ResponseAudioTranscriptDoneEvent.
-
Method Summary
Modifier and Type Method Description final LongsequenceNumber()The sequence number of this event. final JsonValue_type()The type of the event. final JsonField<Long>_sequenceNumber()Returns the raw JSON value of sequenceNumber. final Map<String, JsonValue>_additionalProperties()final ResponseAudioTranscriptDoneEvent.BuildertoBuilder()final ResponseAudioTranscriptDoneEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ResponseAudioTranscriptDoneEvent.Builderbuilder()Returns a mutable builder for constructing an instance of ResponseAudioTranscriptDoneEvent. -
-
Method Detail
-
sequenceNumber
final Long sequenceNumber()
The sequence number of this event.
-
_type
final JsonValue _type()
The type of the event. Always
response.audio.transcript.done.Expected to always return the following:
JsonValue.from("response.audio.transcript.done")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_sequenceNumber
final JsonField<Long> _sequenceNumber()
Returns the raw JSON value of sequenceNumber.
Unlike sequenceNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ResponseAudioTranscriptDoneEvent.Builder toBuilder()
-
validate
final ResponseAudioTranscriptDoneEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ResponseAudioTranscriptDoneEvent.Builder builder()
Returns a mutable builder for constructing an instance of ResponseAudioTranscriptDoneEvent.
The following fields are required:
.sequenceNumber()
-
-
-
-