Class ResponseComputerToolCall
-
- All Implemented Interfaces:
public final class ResponseComputerToolCallA tool call to a computer use tool. See the computer use guide for more information.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classResponseComputerToolCall.BuilderA builder for ResponseComputerToolCall.
public final classResponseComputerToolCall.PendingSafetyCheckA pending safety check for the computer call.
public final classResponseComputerToolCall.StatusThe status of the item. One of
in_progress,completed, orincomplete. Populated when items are returned via API.public final classResponseComputerToolCall.TypeThe type of the computer call. Always
computer_call.public final classResponseComputerToolCall.ActionA click action.
-
Method Summary
Modifier and Type Method Description final Stringid()The unique ID of the computer call. final StringcallId()An identifier used when responding to the tool call with output. final List<ResponseComputerToolCall.PendingSafetyCheck>pendingSafetyChecks()The pending safety checks for the computer call. final ResponseComputerToolCall.Statusstatus()The status of the item. final ResponseComputerToolCall.Typetype()The type of the computer call. final Optional<ResponseComputerToolCall.Action>action()A click action. final Optional<List<ComputerAction>>actions()Flattened batched actions for computer_use.final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_callId()Returns the raw JSON value of callId. final JsonField<List<ResponseComputerToolCall.PendingSafetyCheck>>_pendingSafetyChecks()Returns the raw JSON value of pendingSafetyChecks. final JsonField<ResponseComputerToolCall.Status>_status()Returns the raw JSON value of status. final JsonField<ResponseComputerToolCall.Type>_type()Returns the raw JSON value of type. final JsonField<ResponseComputerToolCall.Action>_action()Returns the raw JSON value of action. final JsonField<List<ComputerAction>>_actions()Returns the raw JSON value of actions. final Map<String, JsonValue>_additionalProperties()final ResponseComputerToolCall.BuildertoBuilder()final ResponseComputerToolCallvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ResponseComputerToolCall.Builderbuilder()Returns a mutable builder for constructing an instance of ResponseComputerToolCall. -
-
Method Detail
-
pendingSafetyChecks
final List<ResponseComputerToolCall.PendingSafetyCheck> pendingSafetyChecks()
The pending safety checks for the computer call.
-
status
final ResponseComputerToolCall.Status status()
The status of the item. One of
in_progress,completed, orincomplete. Populated when items are returned via API.
-
type
final ResponseComputerToolCall.Type type()
The type of the computer call. Always
computer_call.
-
action
final Optional<ResponseComputerToolCall.Action> action()
A click action.
-
actions
final Optional<List<ComputerAction>> actions()
Flattened batched actions for
computer_use. Each action includes antypediscriminator and action-specific fields.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_callId
final JsonField<String> _callId()
Returns the raw JSON value of callId.
Unlike callId, this method doesn't throw if the JSON field has an unexpected type.
-
_pendingSafetyChecks
final JsonField<List<ResponseComputerToolCall.PendingSafetyCheck>> _pendingSafetyChecks()
Returns the raw JSON value of pendingSafetyChecks.
Unlike pendingSafetyChecks, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<ResponseComputerToolCall.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<ResponseComputerToolCall.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_action
final JsonField<ResponseComputerToolCall.Action> _action()
Returns the raw JSON value of action.
Unlike action, this method doesn't throw if the JSON field has an unexpected type.
-
_actions
final JsonField<List<ComputerAction>> _actions()
Returns the raw JSON value of actions.
Unlike actions, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ResponseComputerToolCall.Builder toBuilder()
-
validate
final ResponseComputerToolCall validate()
-
builder
final static ResponseComputerToolCall.Builder builder()
Returns a mutable builder for constructing an instance of ResponseComputerToolCall.
The following fields are required:
.id() .callId() .pendingSafetyChecks() .status() .type()
-
-
-
-