Class ResponseComputerToolCallOutputItem
-
- All Implemented Interfaces:
public final class ResponseComputerToolCallOutputItem
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classResponseComputerToolCallOutputItem.BuilderA builder for ResponseComputerToolCallOutputItem.
public final classResponseComputerToolCallOutputItem.StatusThe status of the message input. One of
in_progress,completed, orincomplete. Populated when input items are returned via API.public final classResponseComputerToolCallOutputItem.AcknowledgedSafetyCheckA pending safety check for the computer call.
-
Method Summary
Modifier and Type Method Description final Stringid()The unique ID of the computer call tool output. final StringcallId()The ID of the computer tool call that produced the output. final ResponseComputerToolCallOutputScreenshotoutput()A computer screenshot image used with the computer use tool. final ResponseComputerToolCallOutputItem.Statusstatus()The status of the message input. final JsonValue_type()The type of the computer tool call output. final Optional<List<ResponseComputerToolCallOutputItem.AcknowledgedSafetyCheck>>acknowledgedSafetyChecks()The safety checks reported by the API that have been acknowledged by the developer. final Optional<String>createdBy()The identifier of the actor that created the item. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_callId()Returns the raw JSON value of callId. final JsonField<ResponseComputerToolCallOutputScreenshot>_output()Returns the raw JSON value of output. final JsonField<ResponseComputerToolCallOutputItem.Status>_status()Returns the raw JSON value of status. final JsonField<List<ResponseComputerToolCallOutputItem.AcknowledgedSafetyCheck>>_acknowledgedSafetyChecks()Returns the raw JSON value of acknowledgedSafetyChecks. final JsonField<String>_createdBy()Returns the raw JSON value of createdBy. final Map<String, JsonValue>_additionalProperties()final ResponseComputerToolCallOutputItem.BuildertoBuilder()final ResponseComputerToolCallOutputItemvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ResponseComputerToolCallOutputItem.Builderbuilder()Returns a mutable builder for constructing an instance of ResponseComputerToolCallOutputItem. -
-
Method Detail
-
output
final ResponseComputerToolCallOutputScreenshot output()
A computer screenshot image used with the computer use tool.
-
status
final ResponseComputerToolCallOutputItem.Status status()
The status of the message input. One of
in_progress,completed, orincomplete. Populated when input items are returned via API.
-
_type
final JsonValue _type()
The type of the computer tool call output. Always
computer_call_output.Expected to always return the following:
JsonValue.from("computer_call_output")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
acknowledgedSafetyChecks
final Optional<List<ResponseComputerToolCallOutputItem.AcknowledgedSafetyCheck>> acknowledgedSafetyChecks()
The safety checks reported by the API that have been acknowledged by the developer.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_callId
final JsonField<String> _callId()
Returns the raw JSON value of callId.
Unlike callId, this method doesn't throw if the JSON field has an unexpected type.
-
_output
final JsonField<ResponseComputerToolCallOutputScreenshot> _output()
Returns the raw JSON value of output.
Unlike output, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<ResponseComputerToolCallOutputItem.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_acknowledgedSafetyChecks
final JsonField<List<ResponseComputerToolCallOutputItem.AcknowledgedSafetyCheck>> _acknowledgedSafetyChecks()
Returns the raw JSON value of acknowledgedSafetyChecks.
Unlike acknowledgedSafetyChecks, this method doesn't throw if the JSON field has an unexpected type.
-
_createdBy
final JsonField<String> _createdBy()
Returns the raw JSON value of createdBy.
Unlike createdBy, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ResponseComputerToolCallOutputItem.Builder toBuilder()
-
validate
final ResponseComputerToolCallOutputItem validate()
-
builder
final static ResponseComputerToolCallOutputItem.Builder builder()
Returns a mutable builder for constructing an instance of ResponseComputerToolCallOutputItem.
The following fields are required:
.id() .callId() .output() .status()
-
-
-
-