Class ResponseComputerToolCallOutputScreenshot
-
- All Implemented Interfaces:
public final class ResponseComputerToolCallOutputScreenshotA computer screenshot image used with the computer use tool.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classResponseComputerToolCallOutputScreenshot.BuilderA builder for ResponseComputerToolCallOutputScreenshot.
-
Method Summary
Modifier and Type Method Description final JsonValue_type()Specifies the event type. final Optional<String>fileId()The identifier of an uploaded file that contains the screenshot. final Optional<String>imageUrl()The URL of the screenshot image. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final JsonField<String>_imageUrl()Returns the raw JSON value of imageUrl. final Map<String, JsonValue>_additionalProperties()final ResponseComputerToolCallOutputScreenshot.BuildertoBuilder()final ResponseComputerToolCallOutputScreenshotvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ResponseComputerToolCallOutputScreenshot.Builderbuilder()Returns a mutable builder for constructing an instance of ResponseComputerToolCallOutputScreenshot. -
-
Method Detail
-
_type
final JsonValue _type()
Specifies the event type. For a computer screenshot, this property is always set to
computer_screenshot.Expected to always return the following:
JsonValue.from("computer_screenshot")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
fileId
final Optional<String> fileId()
The identifier of an uploaded file that contains the screenshot.
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_imageUrl
final JsonField<String> _imageUrl()
Returns the raw JSON value of imageUrl.
Unlike imageUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ResponseComputerToolCallOutputScreenshot.Builder toBuilder()
-
validate
final ResponseComputerToolCallOutputScreenshot validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ResponseComputerToolCallOutputScreenshot.Builder builder()
Returns a mutable builder for constructing an instance of ResponseComputerToolCallOutputScreenshot.
-
-
-
-