Class ResponseFormatTextConfig
-
- All Implemented Interfaces:
public final class ResponseFormatTextConfigAn object specifying the format that the model must output.
Configuring
{ "type": "json_schema" }enables Structured Outputs, which ensures the model will match your supplied JSON schema. Learn more in the Structured Outputs guide.The default format is
{ "type": "text" }with no additional options.Not recommended for gpt-4o and newer models:
Setting to
{ "type": "json_object" }enables the older JSON mode, which ensures the message the model generates is valid JSON. Usingjson_schemais preferred for models that support it.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceResponseFormatTextConfig.VisitorAn interface that defines how to map each variant of ResponseFormatTextConfig to a value of type T.
-
Method Summary
Modifier and Type Method Description final Optional<ResponseFormatText>text()Default response format. final Optional<ResponseFormatTextJsonSchemaConfig>jsonSchema()JSON Schema response format. final Optional<ResponseFormatJsonObject>jsonObject()JSON object response format. final BooleanisText()final BooleanisJsonSchema()final BooleanisJsonObject()final ResponseFormatTextasText()Default response format. final ResponseFormatTextJsonSchemaConfigasJsonSchema()JSON Schema response format. final ResponseFormatJsonObjectasJsonObject()JSON object response format. final Optional<JsonValue>_json()final <T extends Any> Taccept(ResponseFormatTextConfig.Visitor<T> visitor)Maps this instance's current variant to a value of type T using the given visitor. final ResponseFormatTextConfigvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ResponseFormatTextConfigofText(ResponseFormatText text)Default response format. final static ResponseFormatTextConfigofJsonSchema(ResponseFormatTextJsonSchemaConfig jsonSchema)JSON Schema response format. final static ResponseFormatTextConfigofJsonObject(ResponseFormatJsonObject jsonObject)JSON object response format. -
-
Method Detail
-
text
final Optional<ResponseFormatText> text()
Default response format. Used to generate text responses.
-
jsonSchema
final Optional<ResponseFormatTextJsonSchemaConfig> jsonSchema()
JSON Schema response format. Used to generate structured JSON responses. Learn more about Structured Outputs.
-
jsonObject
final Optional<ResponseFormatJsonObject> jsonObject()
JSON object response format. An older method of generating JSON responses. Using
json_schemais recommended for models that support it. Note that the model will not generate JSON without a system or user message instructing it to do so.
-
isJsonSchema
final Boolean isJsonSchema()
-
isJsonObject
final Boolean isJsonObject()
-
asText
final ResponseFormatText asText()
Default response format. Used to generate text responses.
-
asJsonSchema
final ResponseFormatTextJsonSchemaConfig asJsonSchema()
JSON Schema response format. Used to generate structured JSON responses. Learn more about Structured Outputs.
-
asJsonObject
final ResponseFormatJsonObject asJsonObject()
JSON object response format. An older method of generating JSON responses. Using
json_schemais recommended for models that support it. Note that the model will not generate JSON without a system or user message instructing it to do so.
-
accept
final <T extends Any> T accept(ResponseFormatTextConfig.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import com.openai.core.JsonValue; import java.util.Optional; Optional<String> result = responseFormatTextConfig.accept(new ResponseFormatTextConfig.Visitor<Optional<String>>() { @Override public Optional<String> visitText(ResponseFormatText text) { return Optional.of(text.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final ResponseFormatTextConfig validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofText
final static ResponseFormatTextConfig ofText(ResponseFormatText text)
Default response format. Used to generate text responses.
-
ofJsonSchema
final static ResponseFormatTextConfig ofJsonSchema(ResponseFormatTextJsonSchemaConfig jsonSchema)
JSON Schema response format. Used to generate structured JSON responses. Learn more about Structured Outputs.
-
ofJsonObject
final static ResponseFormatTextConfig ofJsonObject(ResponseFormatJsonObject jsonObject)
JSON object response format. An older method of generating JSON responses. Using
json_schemais recommended for models that support it. Note that the model will not generate JSON without a system or user message instructing it to do so.
-
-
-
-