Class ResponseFunctionCallArgumentsDeltaEvent
-
- All Implemented Interfaces:
public final class ResponseFunctionCallArgumentsDeltaEventEmitted when there is a partial function-call arguments delta.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classResponseFunctionCallArgumentsDeltaEvent.BuilderA builder for ResponseFunctionCallArgumentsDeltaEvent.
-
Method Summary
Modifier and Type Method Description final Stringdelta()The function-call arguments delta that is added. final StringitemId()The ID of the output item that the function-call arguments delta is added to. final LongoutputIndex()The index of the output item that the function-call arguments delta is added to. final LongsequenceNumber()The sequence number of this event. final JsonValue_type()The type of the event. final JsonField<String>_delta()Returns the raw JSON value of delta. final JsonField<String>_itemId()Returns the raw JSON value of itemId. final JsonField<Long>_outputIndex()Returns the raw JSON value of outputIndex. final JsonField<Long>_sequenceNumber()Returns the raw JSON value of sequenceNumber. final Map<String, JsonValue>_additionalProperties()final ResponseFunctionCallArgumentsDeltaEvent.BuildertoBuilder()final ResponseFunctionCallArgumentsDeltaEventvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ResponseFunctionCallArgumentsDeltaEvent.Builderbuilder()Returns a mutable builder for constructing an instance of ResponseFunctionCallArgumentsDeltaEvent. -
-
Method Detail
-
itemId
final String itemId()
The ID of the output item that the function-call arguments delta is added to.
-
outputIndex
final Long outputIndex()
The index of the output item that the function-call arguments delta is added to.
-
sequenceNumber
final Long sequenceNumber()
The sequence number of this event.
-
_type
final JsonValue _type()
The type of the event. Always
response.function_call_arguments.delta.Expected to always return the following:
JsonValue.from("response.function_call_arguments.delta")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_delta
final JsonField<String> _delta()
Returns the raw JSON value of delta.
Unlike delta, this method doesn't throw if the JSON field has an unexpected type.
-
_itemId
final JsonField<String> _itemId()
Returns the raw JSON value of itemId.
Unlike itemId, this method doesn't throw if the JSON field has an unexpected type.
-
_outputIndex
final JsonField<Long> _outputIndex()
Returns the raw JSON value of outputIndex.
Unlike outputIndex, this method doesn't throw if the JSON field has an unexpected type.
-
_sequenceNumber
final JsonField<Long> _sequenceNumber()
Returns the raw JSON value of sequenceNumber.
Unlike sequenceNumber, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ResponseFunctionCallArgumentsDeltaEvent.Builder toBuilder()
-
validate
final ResponseFunctionCallArgumentsDeltaEvent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ResponseFunctionCallArgumentsDeltaEvent.Builder builder()
Returns a mutable builder for constructing an instance of ResponseFunctionCallArgumentsDeltaEvent.
The following fields are required:
.delta() .itemId() .outputIndex() .sequenceNumber()
-
-
-
-