Package com.openai.models.responses
Class ResponseFunctionShellCallOutputContent.Outcome.Exit
-
- All Implemented Interfaces:
public final class ResponseFunctionShellCallOutputContent.Outcome.ExitIndicates that the shell commands finished and returned an exit code.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classResponseFunctionShellCallOutputContent.Outcome.Exit.BuilderA builder for Exit.
-
Method Summary
Modifier and Type Method Description final LongexitCode()The exit code returned by the shell process. final JsonValue_type()The outcome type. final JsonField<Long>_exitCode()Returns the raw JSON value of exitCode. final Map<String, JsonValue>_additionalProperties()final ResponseFunctionShellCallOutputContent.Outcome.Exit.BuildertoBuilder()final ResponseFunctionShellCallOutputContent.Outcome.Exitvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ResponseFunctionShellCallOutputContent.Outcome.Exit.Builderbuilder()Returns a mutable builder for constructing an instance of Exit. -
-
Method Detail
-
_type
final JsonValue _type()
The outcome type. Always
exit.Expected to always return the following:
JsonValue.from("exit")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_exitCode
final JsonField<Long> _exitCode()
Returns the raw JSON value of exitCode.
Unlike exitCode, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ResponseFunctionShellCallOutputContent.Outcome.Exit.Builder toBuilder()
-
validate
final ResponseFunctionShellCallOutputContent.Outcome.Exit validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ResponseFunctionShellCallOutputContent.Outcome.Exit.Builder builder()
Returns a mutable builder for constructing an instance of Exit.
The following fields are required:
.exitCode()
-
-
-
-