Class ResponseFunctionShellToolCall.Action
-
- All Implemented Interfaces:
public final class ResponseFunctionShellToolCall.ActionThe shell commands and limits that describe how to run the tool call.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classResponseFunctionShellToolCall.Action.BuilderA builder for Action.
-
Method Summary
Modifier and Type Method Description final List<String>commands()final Optional<Long>maxOutputLength()Optional maximum number of characters to return from each command. final Optional<Long>timeoutMs()Optional timeout in milliseconds for the commands. final JsonField<List<String>>_commands()Returns the raw JSON value of commands. final JsonField<Long>_maxOutputLength()Returns the raw JSON value of maxOutputLength. final JsonField<Long>_timeoutMs()Returns the raw JSON value of timeoutMs. final Map<String, JsonValue>_additionalProperties()final ResponseFunctionShellToolCall.Action.BuildertoBuilder()final ResponseFunctionShellToolCall.Actionvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ResponseFunctionShellToolCall.Action.Builderbuilder()Returns a mutable builder for constructing an instance of Action. -
-
Method Detail
-
maxOutputLength
final Optional<Long> maxOutputLength()
Optional maximum number of characters to return from each command.
-
_commands
final JsonField<List<String>> _commands()
Returns the raw JSON value of commands.
Unlike commands, this method doesn't throw if the JSON field has an unexpected type.
-
_maxOutputLength
final JsonField<Long> _maxOutputLength()
Returns the raw JSON value of maxOutputLength.
Unlike maxOutputLength, this method doesn't throw if the JSON field has an unexpected type.
-
_timeoutMs
final JsonField<Long> _timeoutMs()
Returns the raw JSON value of timeoutMs.
Unlike timeoutMs, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ResponseFunctionShellToolCall.Action.Builder toBuilder()
-
validate
final ResponseFunctionShellToolCall.Action validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ResponseFunctionShellToolCall.Action.Builder builder()
Returns a mutable builder for constructing an instance of Action.
The following fields are required:
.commands() .maxOutputLength() .timeoutMs()
-
-
-
-