Package com.openai.models.responses
Class ResponseFunctionShellToolCall.Caller
-
- All Implemented Interfaces:
public final class ResponseFunctionShellToolCall.CallerThe execution context that produced this tool call.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceResponseFunctionShellToolCall.Caller.VisitorAn interface that defines how to map each variant of Caller to a value of type T.
public final classResponseFunctionShellToolCall.Caller.Program
-
Method Summary
Modifier and Type Method Description final Optional<JsonValue>direct()final Optional<ResponseFunctionShellToolCall.Caller.Program>program()final BooleanisDirect()final BooleanisProgram()final JsonValueasDirect()final ResponseFunctionShellToolCall.Caller.ProgramasProgram()final Optional<JsonValue>_json()final <T extends Any> Taccept(ResponseFunctionShellToolCall.Caller.Visitor<T> visitor)Maps this instance's current variant to a value of type T using the given visitor. final ResponseFunctionShellToolCall.Callervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ResponseFunctionShellToolCall.CallerofDirect()final static ResponseFunctionShellToolCall.CallerofProgram(ResponseFunctionShellToolCall.Caller.Program program)-
-
Method Detail
-
program
final Optional<ResponseFunctionShellToolCall.Caller.Program> program()
-
asProgram
final ResponseFunctionShellToolCall.Caller.Program asProgram()
-
accept
final <T extends Any> T accept(ResponseFunctionShellToolCall.Caller.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import com.openai.core.JsonValue; import java.util.Optional; Optional<String> result = caller.accept(new Caller.Visitor<Optional<String>>() { @Override public Optional<String> visitDirect(JsonValue direct) { return Optional.of(direct.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final ResponseFunctionShellToolCall.Caller validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofDirect
final static ResponseFunctionShellToolCall.Caller ofDirect()
-
ofProgram
final static ResponseFunctionShellToolCall.Caller ofProgram(ResponseFunctionShellToolCall.Caller.Program program)
-
-
-
-