Package com.openai.models.responses
Class ResponseFunctionShellToolCall.Caller.Program
-
- All Implemented Interfaces:
public final class ResponseFunctionShellToolCall.Caller.Program
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classResponseFunctionShellToolCall.Caller.Program.BuilderA builder for Program.
-
Method Summary
Modifier and Type Method Description final StringcallerId()The call ID of the program item that produced this tool call. final JsonValue_type()Expected to always return the following:
However, this method can be useful for debugging and logging (e.g.JsonValue.from("program")final JsonField<String>_callerId()Returns the raw JSON value of callerId. final Map<String, JsonValue>_additionalProperties()final ResponseFunctionShellToolCall.Caller.Program.BuildertoBuilder()final ResponseFunctionShellToolCall.Caller.Programvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ResponseFunctionShellToolCall.Caller.Program.Builderbuilder()Returns a mutable builder for constructing an instance of Program. -
-
Method Detail
-
_type
final JsonValue _type()
Expected to always return the following:
JsonValue.from("program")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_callerId
final JsonField<String> _callerId()
Returns the raw JSON value of callerId.
Unlike callerId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ResponseFunctionShellToolCall.Caller.Program.Builder toBuilder()
-
validate
final ResponseFunctionShellToolCall.Caller.Program validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ResponseFunctionShellToolCall.Caller.Program.Builder builder()
Returns a mutable builder for constructing an instance of Program.
The following fields are required:
.callerId()
-
-
-
-