Class ResponseInputFile
-
- All Implemented Interfaces:
public final class ResponseInputFileA file input to the model.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classResponseInputFile.BuilderA builder for ResponseInputFile.
public final classResponseInputFile.DetailThe detail level of the file to be sent to the model. Use
lowfor the default rendering behavior, orhighto render the file at higher quality. Defaults tolow.
-
Method Summary
Modifier and Type Method Description final JsonValue_type()The type of the input item. final Optional<ResponseInputFile.Detail>detail()The detail level of the file to be sent to the model. final Optional<String>fileData()The content of the file to be sent to the model. final Optional<String>fileId()The ID of the file to be sent to the model. final Optional<String>fileUrl()The URL of the file to be sent to the model. final Optional<String>filename()The name of the file to be sent to the model. final JsonField<ResponseInputFile.Detail>_detail()Returns the raw JSON value of detail. final JsonField<String>_fileData()Returns the raw JSON value of fileData. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final JsonField<String>_fileUrl()Returns the raw JSON value of fileUrl. final JsonField<String>_filename()Returns the raw JSON value of filename. final Map<String, JsonValue>_additionalProperties()final ResponseInputFile.BuildertoBuilder()final ResponseInputFilevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ResponseInputFile.Builderbuilder()Returns a mutable builder for constructing an instance of ResponseInputFile. -
-
Method Detail
-
_type
final JsonValue _type()
The type of the input item. Always
input_file.Expected to always return the following:
JsonValue.from("input_file")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
detail
final Optional<ResponseInputFile.Detail> detail()
The detail level of the file to be sent to the model. Use
lowfor the default rendering behavior, orhighto render the file at higher quality. Defaults tolow.
-
_detail
final JsonField<ResponseInputFile.Detail> _detail()
Returns the raw JSON value of detail.
Unlike detail, this method doesn't throw if the JSON field has an unexpected type.
-
_fileData
final JsonField<String> _fileData()
Returns the raw JSON value of fileData.
Unlike fileData, this method doesn't throw if the JSON field has an unexpected type.
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_fileUrl
final JsonField<String> _fileUrl()
Returns the raw JSON value of fileUrl.
Unlike fileUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_filename
final JsonField<String> _filename()
Returns the raw JSON value of filename.
Unlike filename, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ResponseInputFile.Builder toBuilder()
-
validate
final ResponseInputFile validate()
-
builder
final static ResponseInputFile.Builder builder()
Returns a mutable builder for constructing an instance of ResponseInputFile.
-
-
-
-