Class ResponseInputTextContent
-
- All Implemented Interfaces:
public final class ResponseInputTextContentA text input to the model.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classResponseInputTextContent.BuilderA builder for ResponseInputTextContent.
public final classResponseInputTextContent.PromptCacheBreakpointMarks the exact end of a reusable prompt prefix. The breakpoint inherits its TTL from the request's
prompt_cache_options.ttl; the boundary is not rounded to a token block.
-
Method Summary
Modifier and Type Method Description final Stringtext()The text input to the model. final JsonValue_type()The type of the input item. final Optional<ResponseInputTextContent.PromptCacheBreakpoint>promptCacheBreakpoint()Marks the exact end of a reusable prompt prefix. final JsonField<String>_text()Returns the raw JSON value of text. final JsonField<ResponseInputTextContent.PromptCacheBreakpoint>_promptCacheBreakpoint()Returns the raw JSON value of promptCacheBreakpoint. final Map<String, JsonValue>_additionalProperties()final ResponseInputTextContent.BuildertoBuilder()final ResponseInputTextContentvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ResponseInputTextContent.Builderbuilder()Returns a mutable builder for constructing an instance of ResponseInputTextContent. -
-
Method Detail
-
_type
final JsonValue _type()
The type of the input item. Always
input_text.Expected to always return the following:
JsonValue.from("input_text")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
promptCacheBreakpoint
final Optional<ResponseInputTextContent.PromptCacheBreakpoint> promptCacheBreakpoint()
Marks the exact end of a reusable prompt prefix. The breakpoint inherits its TTL from the request's
prompt_cache_options.ttl; the boundary is not rounded to a token block.
-
_text
final JsonField<String> _text()
Returns the raw JSON value of text.
Unlike text, this method doesn't throw if the JSON field has an unexpected type.
-
_promptCacheBreakpoint
final JsonField<ResponseInputTextContent.PromptCacheBreakpoint> _promptCacheBreakpoint()
Returns the raw JSON value of promptCacheBreakpoint.
Unlike promptCacheBreakpoint, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ResponseInputTextContent.Builder toBuilder()
-
validate
final ResponseInputTextContent validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ResponseInputTextContent.Builder builder()
Returns a mutable builder for constructing an instance of ResponseInputTextContent.
The following fields are required:
.text()
-
-
-
-