Class ResponsesClientEvent.PromptCacheRetention

  • All Implemented Interfaces:
    com.openai.core.Enum

    @Deprecated(message = "deprecated") 
    public final class ResponsesClientEvent.PromptCacheRetention
     implements Enum
                        

    Deprecated. Use prompt_cache_options.ttl instead.

    The retention policy for the prompt cache. Set to 24h to enable extended prompt caching, which keeps cached prefixes active for longer, up to a maximum of 24 hours. Learn more. This field expresses a maximum retention policy, while prompt_cache_options.ttl expresses a minimum cache lifetime. The two fields are independent and do not interact. For gpt-5.5, gpt-5.5-pro, and future models, only 24h is supported.

    For older models that support both in_memory and 24h, the default depends on your organization's data retention policy:

    • Organizations without ZDR enabled default to 24h.

    • Organizations with ZDR enabled default to in_memory when prompt_cache_retention is not specified.