Package com.openai.models.vectorstores
Class AutoFileChunkingStrategyParam
-
- All Implemented Interfaces:
public final class AutoFileChunkingStrategyParamThe default strategy. This strategy currently uses a
max_chunk_size_tokensof800andchunk_overlap_tokensof400.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAutoFileChunkingStrategyParam.BuilderA builder for AutoFileChunkingStrategyParam.
-
Method Summary
Modifier and Type Method Description final JsonValue_type()Always auto.final Map<String, JsonValue>_additionalProperties()final AutoFileChunkingStrategyParam.BuildertoBuilder()final AutoFileChunkingStrategyParamvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static AutoFileChunkingStrategyParam.Builderbuilder()Returns a mutable builder for constructing an instance of AutoFileChunkingStrategyParam. -
-
Method Detail
-
_type
final JsonValue _type()
Always
auto.Expected to always return the following:
JsonValue.from("auto")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final AutoFileChunkingStrategyParam.Builder toBuilder()
-
validate
final AutoFileChunkingStrategyParam validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static AutoFileChunkingStrategyParam.Builder builder()
Returns a mutable builder for constructing an instance of AutoFileChunkingStrategyParam.
-
-
-
-