Package com.openai.models.vectorstores
Class OtherFileChunkingStrategyObject
-
- All Implemented Interfaces:
public final class OtherFileChunkingStrategyObjectThis is returned when the chunking strategy is unknown. Typically, this is because the file was indexed before the
chunking_strategyconcept was introduced in the API.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classOtherFileChunkingStrategyObject.BuilderA builder for OtherFileChunkingStrategyObject.
-
Method Summary
Modifier and Type Method Description final JsonValue_type()Always other.final Map<String, JsonValue>_additionalProperties()final OtherFileChunkingStrategyObject.BuildertoBuilder()final OtherFileChunkingStrategyObjectvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static OtherFileChunkingStrategyObject.Builderbuilder()Returns a mutable builder for constructing an instance of OtherFileChunkingStrategyObject. -
-
Method Detail
-
_type
final JsonValue _type()
Always
other.Expected to always return the following:
JsonValue.from("other")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final OtherFileChunkingStrategyObject.Builder toBuilder()
-
validate
final OtherFileChunkingStrategyObject validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static OtherFileChunkingStrategyObject.Builder builder()
Returns a mutable builder for constructing an instance of OtherFileChunkingStrategyObject.
-
-
-
-