Class StaticFileChunkingStrategy
-
- All Implemented Interfaces:
public final class StaticFileChunkingStrategy
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStaticFileChunkingStrategy.BuilderA builder for StaticFileChunkingStrategy.
-
Method Summary
Modifier and Type Method Description final LongchunkOverlapTokens()The number of tokens that overlap between chunks. final LongmaxChunkSizeTokens()The maximum number of tokens in each chunk. final JsonField<Long>_chunkOverlapTokens()Returns the raw JSON value of chunkOverlapTokens. final JsonField<Long>_maxChunkSizeTokens()Returns the raw JSON value of maxChunkSizeTokens. final Map<String, JsonValue>_additionalProperties()final StaticFileChunkingStrategy.BuildertoBuilder()final StaticFileChunkingStrategyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static StaticFileChunkingStrategy.Builderbuilder()Returns a mutable builder for constructing an instance of StaticFileChunkingStrategy. -
-
Method Detail
-
chunkOverlapTokens
final Long chunkOverlapTokens()
The number of tokens that overlap between chunks. The default value is
400.Note that the overlap must not exceed half of
max_chunk_size_tokens.
-
maxChunkSizeTokens
final Long maxChunkSizeTokens()
The maximum number of tokens in each chunk. The default value is
800. The minimum value is100and the maximum value is4096.
-
_chunkOverlapTokens
final JsonField<Long> _chunkOverlapTokens()
Returns the raw JSON value of chunkOverlapTokens.
Unlike chunkOverlapTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_maxChunkSizeTokens
final JsonField<Long> _maxChunkSizeTokens()
Returns the raw JSON value of maxChunkSizeTokens.
Unlike maxChunkSizeTokens, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final StaticFileChunkingStrategy.Builder toBuilder()
-
validate
final StaticFileChunkingStrategy validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static StaticFileChunkingStrategy.Builder builder()
Returns a mutable builder for constructing an instance of StaticFileChunkingStrategy.
The following fields are required:
.chunkOverlapTokens() .maxChunkSizeTokens()
-
-
-
-