Package com.openai.models.vectorstores
Class StaticFileChunkingStrategyObjectParam
-
- All Implemented Interfaces:
public final class StaticFileChunkingStrategyObjectParamCustomize your own chunking strategy by setting chunk size and chunk overlap.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classStaticFileChunkingStrategyObjectParam.BuilderA builder for StaticFileChunkingStrategyObjectParam.
-
Method Summary
Modifier and Type Method Description final StaticFileChunkingStrategystatic_()final JsonValue_type()Always static.final JsonField<StaticFileChunkingStrategy>_static_()Returns the raw JSON value of static_. final Map<String, JsonValue>_additionalProperties()final StaticFileChunkingStrategyObjectParam.BuildertoBuilder()final StaticFileChunkingStrategyObjectParamvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static StaticFileChunkingStrategyObjectParam.Builderbuilder()Returns a mutable builder for constructing an instance of StaticFileChunkingStrategyObjectParam. -
-
Method Detail
-
static_
final StaticFileChunkingStrategy static_()
-
_type
final JsonValue _type()
Always
static.Expected to always return the following:
JsonValue.from("static")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_static_
final JsonField<StaticFileChunkingStrategy> _static_()
Returns the raw JSON value of static_.
Unlike static_, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final StaticFileChunkingStrategyObjectParam.Builder toBuilder()
-
validate
final StaticFileChunkingStrategyObjectParam validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static StaticFileChunkingStrategyObjectParam.Builder builder()
Returns a mutable builder for constructing an instance of StaticFileChunkingStrategyObjectParam.
The following fields are required:
.static_()
-
-
-
-