Package com.openai.models.vectorstores
Class VectorStore.Metadata
-
- All Implemented Interfaces:
public final class VectorStore.MetadataSet of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.
Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVectorStore.Metadata.BuilderA builder for Metadata.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final VectorStore.Metadata.BuildertoBuilder()final VectorStore.Metadatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VectorStore.Metadata.Builderbuilder()Returns a mutable builder for constructing an instance of Metadata. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VectorStore.Metadata.Builder toBuilder()
-
validate
final VectorStore.Metadata validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VectorStore.Metadata.Builder builder()
Returns a mutable builder for constructing an instance of Metadata.
-
-
-
-