Class VectorStoreCreateParams.Body
-
- All Implemented Interfaces:
public final class VectorStoreCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVectorStoreCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<FileChunkingStrategyParam>chunkingStrategy()The chunking strategy used to chunk the file(s). final Optional<String>description()A description for the vector store. final Optional<VectorStoreCreateParams.ExpiresAfter>expiresAfter()The expiration policy for a vector store. final Optional<List<String>>fileIds()A list of File IDs that the vector store should use. final Optional<VectorStoreCreateParams.Metadata>metadata()Set of 16 key-value pairs that can be attached to an object. final Optional<String>name()The name of the vector store. final JsonField<FileChunkingStrategyParam>_chunkingStrategy()Returns the raw JSON value of chunkingStrategy. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<VectorStoreCreateParams.ExpiresAfter>_expiresAfter()Returns the raw JSON value of expiresAfter. final JsonField<List<String>>_fileIds()Returns the raw JSON value of fileIds. final JsonField<VectorStoreCreateParams.Metadata>_metadata()Returns the raw JSON value of metadata. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final VectorStoreCreateParams.Body.BuildertoBuilder()final VectorStoreCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VectorStoreCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
chunkingStrategy
final Optional<FileChunkingStrategyParam> chunkingStrategy()
The chunking strategy used to chunk the file(s). If not set, will use the
autostrategy. Only applicable iffile_idsis non-empty.
-
description
final Optional<String> description()
A description for the vector store. Can be used to describe the vector store's purpose.
-
expiresAfter
final Optional<VectorStoreCreateParams.ExpiresAfter> expiresAfter()
The expiration policy for a vector store.
-
fileIds
final Optional<List<String>> fileIds()
A list of File IDs that the vector store should use. Useful for tools like
file_searchthat can access files.
-
metadata
final Optional<VectorStoreCreateParams.Metadata> metadata()
Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.
Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.
-
_chunkingStrategy
final JsonField<FileChunkingStrategyParam> _chunkingStrategy()
Returns the raw JSON value of chunkingStrategy.
Unlike chunkingStrategy, this method doesn't throw if the JSON field has an unexpected type.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_expiresAfter
final JsonField<VectorStoreCreateParams.ExpiresAfter> _expiresAfter()
Returns the raw JSON value of expiresAfter.
Unlike expiresAfter, this method doesn't throw if the JSON field has an unexpected type.
-
_fileIds
final JsonField<List<String>> _fileIds()
Returns the raw JSON value of fileIds.
Unlike fileIds, this method doesn't throw if the JSON field has an unexpected type.
-
_metadata
final JsonField<VectorStoreCreateParams.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VectorStoreCreateParams.Body.Builder toBuilder()
-
validate
final VectorStoreCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VectorStoreCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-