Class VectorStoreSearchResponse
-
- All Implemented Interfaces:
public final class VectorStoreSearchResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVectorStoreSearchResponse.BuilderA builder for VectorStoreSearchResponse.
public final classVectorStoreSearchResponse.AttributesSet of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard. Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters, booleans, or numbers.
public final classVectorStoreSearchResponse.Content
-
Method Summary
Modifier and Type Method Description final Optional<VectorStoreSearchResponse.Attributes>attributes()Set of 16 key-value pairs that can be attached to an object. final List<VectorStoreSearchResponse.Content>content()Content chunks from the file. final StringfileId()The ID of the vector store file. final Stringfilename()The name of the vector store file. final Doublescore()The similarity score for the result. final JsonField<VectorStoreSearchResponse.Attributes>_attributes()Returns the raw JSON value of attributes. final JsonField<List<VectorStoreSearchResponse.Content>>_content()Returns the raw JSON value of content. final JsonField<String>_fileId()Returns the raw JSON value of fileId. final JsonField<String>_filename()Returns the raw JSON value of filename. final JsonField<Double>_score()Returns the raw JSON value of score. final Map<String, JsonValue>_additionalProperties()final VectorStoreSearchResponse.BuildertoBuilder()final VectorStoreSearchResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VectorStoreSearchResponse.Builderbuilder()Returns a mutable builder for constructing an instance of VectorStoreSearchResponse. -
-
Method Detail
-
attributes
final Optional<VectorStoreSearchResponse.Attributes> attributes()
Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard. Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters, booleans, or numbers.
-
content
final List<VectorStoreSearchResponse.Content> content()
Content chunks from the file.
-
_attributes
final JsonField<VectorStoreSearchResponse.Attributes> _attributes()
Returns the raw JSON value of attributes.
Unlike attributes, this method doesn't throw if the JSON field has an unexpected type.
-
_content
final JsonField<List<VectorStoreSearchResponse.Content>> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_fileId
final JsonField<String> _fileId()
Returns the raw JSON value of fileId.
Unlike fileId, this method doesn't throw if the JSON field has an unexpected type.
-
_filename
final JsonField<String> _filename()
Returns the raw JSON value of filename.
Unlike filename, this method doesn't throw if the JSON field has an unexpected type.
-
_score
final JsonField<Double> _score()
Returns the raw JSON value of score.
Unlike score, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VectorStoreSearchResponse.Builder toBuilder()
-
validate
final VectorStoreSearchResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VectorStoreSearchResponse.Builder builder()
Returns a mutable builder for constructing an instance of VectorStoreSearchResponse.
The following fields are required:
.attributes() .content() .fileId() .filename() .score()
-
-
-
-