Class VectorStoreUpdateParams.Body
-
- All Implemented Interfaces:
public final class VectorStoreUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVectorStoreUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<VectorStoreUpdateParams.ExpiresAfter>expiresAfter()The expiration policy for a vector store. final Optional<VectorStoreUpdateParams.Metadata>metadata()Set of 16 key-value pairs that can be attached to an object. final Optional<String>name()The name of the vector store. final JsonField<VectorStoreUpdateParams.ExpiresAfter>_expiresAfter()Returns the raw JSON value of expiresAfter. final JsonField<VectorStoreUpdateParams.Metadata>_metadata()Returns the raw JSON value of metadata. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final VectorStoreUpdateParams.Body.BuildertoBuilder()final VectorStoreUpdateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VectorStoreUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
expiresAfter
final Optional<VectorStoreUpdateParams.ExpiresAfter> expiresAfter()
The expiration policy for a vector store.
-
metadata
final Optional<VectorStoreUpdateParams.Metadata> metadata()
Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard.
Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.
-
_expiresAfter
final JsonField<VectorStoreUpdateParams.ExpiresAfter> _expiresAfter()
Returns the raw JSON value of expiresAfter.
Unlike expiresAfter, this method doesn't throw if the JSON field has an unexpected type.
-
_metadata
final JsonField<VectorStoreUpdateParams.Metadata> _metadata()
Returns the raw JSON value of metadata.
Unlike metadata, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VectorStoreUpdateParams.Body.Builder toBuilder()
-
validate
final VectorStoreUpdateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VectorStoreUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-