Class VectorStoreFile.Attributes
-
- All Implemented Interfaces:
public final class VectorStoreFile.AttributesSet of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard. Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters, booleans, or numbers.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVectorStoreFile.Attributes.BuilderA builder for Attributes.
-
Method Summary
Modifier and Type Method Description final Map<String, JsonValue>_additionalProperties()final VectorStoreFile.Attributes.BuildertoBuilder()final VectorStoreFile.Attributesvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VectorStoreFile.Attributes.Builderbuilder()Returns a mutable builder for constructing an instance of Attributes. -
-
Method Detail
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VectorStoreFile.Attributes.Builder toBuilder()
-
validate
final VectorStoreFile.Attributes validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VectorStoreFile.Attributes.Builder builder()
Returns a mutable builder for constructing an instance of Attributes.
-
-
-
-