Class VectorStoreFileDeleted
-
- All Implemented Interfaces:
public final class VectorStoreFileDeleted
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVectorStoreFileDeleted.BuilderA builder for VectorStoreFileDeleted.
-
Method Summary
Modifier and Type Method Description final Stringid()final Booleandeleted()final JsonValue_object_()Expected to always return the following:
However, this method can be useful for debugging and logging (e.g.JsonValue.from("vector_store.file.deleted")final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Boolean>_deleted()Returns the raw JSON value of deleted. final Map<String, JsonValue>_additionalProperties()final VectorStoreFileDeleted.BuildertoBuilder()final VectorStoreFileDeletedvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static VectorStoreFileDeleted.Builderbuilder()Returns a mutable builder for constructing an instance of VectorStoreFileDeleted. -
-
Method Detail
-
_object_
final JsonValue _object_()
Expected to always return the following:
JsonValue.from("vector_store.file.deleted")However, this method can be useful for debugging and logging (e.g. if the server responded with an unexpected value).
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_deleted
final JsonField<Boolean> _deleted()
Returns the raw JSON value of deleted.
Unlike deleted, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final VectorStoreFileDeleted.Builder toBuilder()
-
validate
final VectorStoreFileDeleted validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static VectorStoreFileDeleted.Builder builder()
Returns a mutable builder for constructing an instance of VectorStoreFileDeleted.
The following fields are required:
.id() .deleted()
-
-
-
-