Package com.openai.models.webhooks
Class ResponseIncompleteWebhookEvent.Data
-
- All Implemented Interfaces:
public final class ResponseIncompleteWebhookEvent.DataEvent data payload.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classResponseIncompleteWebhookEvent.Data.BuilderA builder for Data.
-
Method Summary
Modifier and Type Method Description final Stringid()The unique ID of the model response. final JsonField<String>_id()Returns the raw JSON value of id. final Map<String, JsonValue>_additionalProperties()final ResponseIncompleteWebhookEvent.Data.BuildertoBuilder()final ResponseIncompleteWebhookEvent.Datavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ResponseIncompleteWebhookEvent.Data.Builderbuilder()Returns a mutable builder for constructing an instance of Data. -
-
Method Detail
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ResponseIncompleteWebhookEvent.Data.Builder toBuilder()
-
validate
final ResponseIncompleteWebhookEvent.Data validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ResponseIncompleteWebhookEvent.Data.Builder builder()
Returns a mutable builder for constructing an instance of Data.
The following fields are required:
.id()
-
-
-
-