Package com.openai.services.async
Interface AudioServiceAsync
-
- All Implemented Interfaces:
public interface AudioServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAudioServiceAsync.WithRawResponseA view of AudioServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AudioServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract AudioServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract TranscriptionServiceAsynctranscriptions()Turn audio into text or text into audio. abstract TranslationServiceAsynctranslations()Turn audio into text or text into audio. abstract SpeechServiceAsyncspeech()Turn audio into text or text into audio. -
-
Method Detail
-
withRawResponse
abstract AudioServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AudioServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
transcriptions
abstract TranscriptionServiceAsync transcriptions()
Turn audio into text or text into audio.
-
translations
abstract TranslationServiceAsync translations()
Turn audio into text or text into audio.
-
speech
abstract SpeechServiceAsync speech()
Turn audio into text or text into audio.
-
-
-
-