Package com.openai.services.async
Class AudioServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.openai.services.async.AudioServiceAsync
public final class AudioServiceAsyncImpl implements AudioServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAudioServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AudioServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AudioServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. TranscriptionServiceAsynctranscriptions()Turn audio into text or text into audio. TranslationServiceAsynctranslations()Turn audio into text or text into audio. SpeechServiceAsyncspeech()Turn audio into text or text into audio. -
-
Method Detail
-
withRawResponse
AudioServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AudioServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
transcriptions
TranscriptionServiceAsync transcriptions()
Turn audio into text or text into audio.
-
translations
TranslationServiceAsync translations()
Turn audio into text or text into audio.
-
speech
SpeechServiceAsync speech()
Turn audio into text or text into audio.
-
-
-
-