Interface EmbeddingServiceAsync

  • All Implemented Interfaces:

    
    public interface EmbeddingServiceAsync
    
                        

    Get a vector representation of a given input that can be easily consumed by machine learning models and algorithms.