Class EmbeddingServiceAsyncImpl

  • All Implemented Interfaces:
    com.openai.services.async.EmbeddingServiceAsync

    
    public final class EmbeddingServiceAsyncImpl
     implements EmbeddingServiceAsync
                        

    Get a vector representation of a given input that can be easily consumed by machine learning models and algorithms.