Interface VideoServiceAsync
-
- All Implemented Interfaces:
public interface VideoServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceVideoServiceAsync.WithRawResponseA view of VideoServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract VideoServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract VideoServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Video> create(VideoCreateParams params)
Create a new video generation job from a prompt and optional reference assets.
-
create
abstract CompletableFuture<Video> create(VideoCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Video> retrieve(String videoId)
Fetch the latest metadata for a generated video.
-
retrieve
CompletableFuture<Video> retrieve(String videoId, VideoRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Video> retrieve(String videoId, VideoRetrieveParams params)
-
retrieve
abstract CompletableFuture<Video> retrieve(VideoRetrieveParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Video> retrieve(VideoRetrieveParams params)
-
retrieve
CompletableFuture<Video> retrieve(String videoId, RequestOptions requestOptions)
-
list
CompletableFuture<VideoListPageAsync> list()
List recently generated videos for the current project.
-
list
abstract CompletableFuture<VideoListPageAsync> list(VideoListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<VideoListPageAsync> list(VideoListParams params)
-
list
CompletableFuture<VideoListPageAsync> list(RequestOptions requestOptions)
-
delete
CompletableFuture<VideoDeleteResponse> delete(String videoId)
Permanently delete a completed or failed video and its stored assets.
-
delete
CompletableFuture<VideoDeleteResponse> delete(String videoId, VideoDeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<VideoDeleteResponse> delete(String videoId, VideoDeleteParams params)
-
delete
abstract CompletableFuture<VideoDeleteResponse> delete(VideoDeleteParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<VideoDeleteResponse> delete(VideoDeleteParams params)
-
delete
CompletableFuture<VideoDeleteResponse> delete(String videoId, RequestOptions requestOptions)
-
createCharacter
CompletableFuture<VideoCreateCharacterResponse> createCharacter(VideoCreateCharacterParams params)
Create a character from an uploaded video.
-
createCharacter
abstract CompletableFuture<VideoCreateCharacterResponse> createCharacter(VideoCreateCharacterParams params, RequestOptions requestOptions)
-
downloadContent
CompletableFuture<HttpResponse> downloadContent(String videoId)
Download the generated video bytes or a derived preview asset.
Streams the rendered video content for the specified video job.
-
downloadContent
CompletableFuture<HttpResponse> downloadContent(String videoId, VideoDownloadContentParams params, RequestOptions requestOptions)
-
downloadContent
CompletableFuture<HttpResponse> downloadContent(String videoId, VideoDownloadContentParams params)
-
downloadContent
abstract CompletableFuture<HttpResponse> downloadContent(VideoDownloadContentParams params, RequestOptions requestOptions)
-
downloadContent
CompletableFuture<HttpResponse> downloadContent(VideoDownloadContentParams params)
-
downloadContent
CompletableFuture<HttpResponse> downloadContent(String videoId, RequestOptions requestOptions)
-
edit
CompletableFuture<Video> edit(VideoEditParams params)
Create a new video generation job by editing a source video or existing generated video.
-
edit
abstract CompletableFuture<Video> edit(VideoEditParams params, RequestOptions requestOptions)
-
extend
CompletableFuture<Video> extend(VideoExtendParams params)
Create an extension of a completed video.
-
extend
abstract CompletableFuture<Video> extend(VideoExtendParams params, RequestOptions requestOptions)
-
getCharacter
CompletableFuture<VideoGetCharacterResponse> getCharacter(String characterId)
Fetch a character.
-
getCharacter
CompletableFuture<VideoGetCharacterResponse> getCharacter(String characterId, VideoGetCharacterParams params, RequestOptions requestOptions)
-
getCharacter
CompletableFuture<VideoGetCharacterResponse> getCharacter(String characterId, VideoGetCharacterParams params)
-
getCharacter
abstract CompletableFuture<VideoGetCharacterResponse> getCharacter(VideoGetCharacterParams params, RequestOptions requestOptions)
-
getCharacter
CompletableFuture<VideoGetCharacterResponse> getCharacter(VideoGetCharacterParams params)
-
getCharacter
CompletableFuture<VideoGetCharacterResponse> getCharacter(String characterId, RequestOptions requestOptions)
-
remix
CompletableFuture<Video> remix(String videoId, VideoRemixParams params)
Create a remix of a completed video using a refreshed prompt.
-
remix
CompletableFuture<Video> remix(String videoId, VideoRemixParams params, RequestOptions requestOptions)
-
remix
CompletableFuture<Video> remix(VideoRemixParams params)
-
remix
abstract CompletableFuture<Video> remix(VideoRemixParams params, RequestOptions requestOptions)
-
-
-
-