Package com.openai.services.async
Class VideoServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.openai.services.async.VideoServiceAsync
public final class VideoServiceAsyncImpl implements VideoServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVideoServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class com.openai.services.async.VideoServiceAsync
create, createCharacter, delete, delete, delete, delete, delete, downloadContent, downloadContent, downloadContent, downloadContent, downloadContent, edit, extend, getCharacter, getCharacter, getCharacter, getCharacter, getCharacter, list, list, list, remix, remix, remix, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
VideoServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
VideoServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
CompletableFuture<Video> create(VideoCreateParams params, RequestOptions requestOptions)
-
retrieve
CompletableFuture<Video> retrieve(VideoRetrieveParams params, RequestOptions requestOptions)
-
list
CompletableFuture<VideoListPageAsync> list(VideoListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<VideoDeleteResponse> delete(VideoDeleteParams params, RequestOptions requestOptions)
-
createCharacter
CompletableFuture<VideoCreateCharacterResponse> createCharacter(VideoCreateCharacterParams params, RequestOptions requestOptions)
-
downloadContent
CompletableFuture<HttpResponse> downloadContent(VideoDownloadContentParams params, RequestOptions requestOptions)
-
edit
CompletableFuture<Video> edit(VideoEditParams params, RequestOptions requestOptions)
-
extend
CompletableFuture<Video> extend(VideoExtendParams params, RequestOptions requestOptions)
-
getCharacter
CompletableFuture<VideoGetCharacterResponse> getCharacter(VideoGetCharacterParams params, RequestOptions requestOptions)
-
remix
CompletableFuture<Video> remix(VideoRemixParams params, RequestOptions requestOptions)
-
-
-
-