Class ThreadServiceAsyncImpl

  • All Implemented Interfaces:
    com.openai.services.async.beta.ThreadServiceAsync

    @Deprecated(message = "The Assistants API is deprecated in favor of the Responses API") 
    public final class ThreadServiceAsyncImpl
     implements ThreadServiceAsync
                        

    Build Assistants that can call models and use tools.