Package com.openai.services.blocking
Interface AudioService
-
- All Implemented Interfaces:
public interface AudioService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceAudioService.WithRawResponseA view of AudioService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract AudioService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract AudioServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. abstract TranscriptionServicetranscriptions()Turn audio into text or text into audio. abstract TranslationServicetranslations()Turn audio into text or text into audio. abstract SpeechServicespeech()Turn audio into text or text into audio. -
-
Method Detail
-
withRawResponse
abstract AudioService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract AudioService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
transcriptions
abstract TranscriptionService transcriptions()
Turn audio into text or text into audio.
-
translations
abstract TranslationService translations()
Turn audio into text or text into audio.
-
speech
abstract SpeechService speech()
Turn audio into text or text into audio.
-
-
-
-