Package com.openai.services.blocking
Class AudioServiceImpl
-
- All Implemented Interfaces:
-
com.openai.services.blocking.AudioService
public final class AudioServiceImpl implements AudioService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classAudioServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description AudioService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. AudioServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. TranscriptionServicetranscriptions()Turn audio into text or text into audio. TranslationServicetranslations()Turn audio into text or text into audio. SpeechServicespeech()Turn audio into text or text into audio. -
-
Method Detail
-
withRawResponse
AudioService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
AudioService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
transcriptions
TranscriptionService transcriptions()
Turn audio into text or text into audio.
-
translations
TranslationService translations()
Turn audio into text or text into audio.
-
speech
SpeechService speech()
Turn audio into text or text into audio.
-
-
-
-