Class EmbeddingServiceImpl

  • All Implemented Interfaces:
    com.openai.services.blocking.EmbeddingService

    
    public final class EmbeddingServiceImpl
     implements EmbeddingService
                        

    Get a vector representation of a given input that can be easily consumed by machine learning models and algorithms.