Package com.openai.services.blocking
Class VideoServiceImpl
-
- All Implemented Interfaces:
-
com.openai.services.blocking.VideoService
public final class VideoServiceImpl implements VideoService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classVideoServiceImpl.WithRawResponseImpl
-
Method Summary
-
Methods inherited from class com.openai.services.blocking.VideoService
create, createCharacter, delete, delete, delete, delete, delete, downloadContent, downloadContent, downloadContent, downloadContent, downloadContent, edit, extend, getCharacter, getCharacter, getCharacter, getCharacter, getCharacter, list, list, list, remix, remix, remix, retrieve, retrieve, retrieve, retrieve, retrieve -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
VideoService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
VideoService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
Video create(VideoCreateParams params, RequestOptions requestOptions)
-
retrieve
Video retrieve(VideoRetrieveParams params, RequestOptions requestOptions)
-
list
VideoListPage list(VideoListParams params, RequestOptions requestOptions)
-
delete
VideoDeleteResponse delete(VideoDeleteParams params, RequestOptions requestOptions)
-
createCharacter
VideoCreateCharacterResponse createCharacter(VideoCreateCharacterParams params, RequestOptions requestOptions)
-
downloadContent
HttpResponse downloadContent(VideoDownloadContentParams params, RequestOptions requestOptions)
-
edit
Video edit(VideoEditParams params, RequestOptions requestOptions)
-
extend
Video extend(VideoExtendParams params, RequestOptions requestOptions)
-
getCharacter
VideoGetCharacterResponse getCharacter(VideoGetCharacterParams params, RequestOptions requestOptions)
-
remix
Video remix(VideoRemixParams params, RequestOptions requestOptions)
-
-
-
-