Class ThreadServiceImpl
-
- All Implemented Interfaces:
-
com.openai.services.blocking.beta.ThreadService
@Deprecated(message = "The Assistants API is deprecated in favor of the Responses API") public final class ThreadServiceImpl implements ThreadService
Build Assistants that can call models and use tools.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classThreadServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description ThreadService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. ThreadServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. RunServiceruns()Build Assistants that can call models and use tools. MessageServicemessages()Build Assistants that can call models and use tools. Threadcreate(ThreadCreateParams params, RequestOptions requestOptions)Threadretrieve(ThreadRetrieveParams params, RequestOptions requestOptions)Threadupdate(ThreadUpdateParams params, RequestOptions requestOptions)ThreadDeleteddelete(ThreadDeleteParams params, RequestOptions requestOptions)RuncreateAndRun(ThreadCreateAndRunParams params, RequestOptions requestOptions)StreamResponse<AssistantStreamEvent>createAndRunStreaming(ThreadCreateAndRunParams params, RequestOptions requestOptions)-
Methods inherited from class com.openai.services.blocking.beta.ThreadService
create, create, create, createAndRun, createAndRunStreaming, delete, delete, delete, delete, delete, retrieve, retrieve, retrieve, retrieve, retrieve, update, update, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
ThreadService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
ThreadService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
runs
@Deprecated(message = "The Assistants API is deprecated in favor of the Responses API") RunService runs()
Build Assistants that can call models and use tools.
-
messages
@Deprecated(message = "The Assistants API is deprecated in favor of the Responses API") MessageService messages()
Build Assistants that can call models and use tools.
-
create
@Deprecated(message = "The Assistants API is deprecated in favor of the Responses API") Thread create(ThreadCreateParams params, RequestOptions requestOptions)
-
retrieve
@Deprecated(message = "The Assistants API is deprecated in favor of the Responses API") Thread retrieve(ThreadRetrieveParams params, RequestOptions requestOptions)
-
update
@Deprecated(message = "The Assistants API is deprecated in favor of the Responses API") Thread update(ThreadUpdateParams params, RequestOptions requestOptions)
-
delete
@Deprecated(message = "The Assistants API is deprecated in favor of the Responses API") ThreadDeleted delete(ThreadDeleteParams params, RequestOptions requestOptions)
-
createAndRun
@Deprecated(message = "The Assistants API is deprecated in favor of the Responses API") Run createAndRun(ThreadCreateAndRunParams params, RequestOptions requestOptions)
-
createAndRunStreaming
@Deprecated(message = "The Assistants API is deprecated in favor of the Responses API") StreamResponse<AssistantStreamEvent> createAndRunStreaming(ThreadCreateAndRunParams params, RequestOptions requestOptions)
-
-
-
-