Interface SessionService
-
- All Implemented Interfaces:
public interface SessionService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceSessionService.WithRawResponseA view of SessionService that provides access to raw HTTP responses for each method.
-
Method Summary
Modifier and Type Method Description abstract SessionService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. abstract SessionServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. ChatSessioncreate(SessionCreateParams params)Create a ChatKit session. abstract ChatSessioncreate(SessionCreateParams params, RequestOptions requestOptions)ChatSessioncancel(String sessionId)Cancel an active ChatKit session and return its most recent metadata. ChatSessioncancel(String sessionId, SessionCancelParams params, RequestOptions requestOptions)ChatSessioncancel(String sessionId, SessionCancelParams params)abstract ChatSessioncancel(SessionCancelParams params, RequestOptions requestOptions)ChatSessioncancel(SessionCancelParams params)ChatSessioncancel(String sessionId, RequestOptions requestOptions)-
-
Method Detail
-
withRawResponse
abstract SessionService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract SessionService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
create
ChatSession create(SessionCreateParams params)
Create a ChatKit session.
-
create
abstract ChatSession create(SessionCreateParams params, RequestOptions requestOptions)
-
cancel
ChatSession cancel(String sessionId)
Cancel an active ChatKit session and return its most recent metadata.
Cancelling prevents new requests from using the issued client secret.
-
cancel
ChatSession cancel(String sessionId, SessionCancelParams params, RequestOptions requestOptions)
-
cancel
ChatSession cancel(String sessionId, SessionCancelParams params)
-
cancel
abstract ChatSession cancel(SessionCancelParams params, RequestOptions requestOptions)
-
cancel
ChatSession cancel(SessionCancelParams params)
-
cancel
ChatSession cancel(String sessionId, RequestOptions requestOptions)
-
-
-
-